(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    189448,       5693]
NotebookOptionsPosition[     92642,       3547]
NotebookOutlinePosition[    181072,       5460]
CellTagsIndexPosition[    179236,       5407]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Computational Physics", "OnlineHeader"],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Title"],
 ". Dynamical Systems and Chaos "
}], "Title",
 CounterAssignments->{{"Title", 0}}],

Cell["Paul Abbott", "Author"],

Cell[TextData[{
 "School of Physics, M013\nUniversity of Western Australia\n35 Stirling \
Highway\nCrawley WA 6009, Australia\n",
 ButtonBox["paul@physics.uwa.edu.au",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["mailto:paul@physics.uwa.edu.au"], None}],
 "\n",
 ButtonBox["physics.uwa.edu.au/~paul",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://physics.uwa.edu.au/~paul"], None}]
}], "Address"],

Cell[CellGroupData[{

Cell["Pre-requisites", "Subsubsection"],

Cell[TextData[{
 "To improve the appearance of graphics, ",
 StyleBox["TraditionalForm", "InlineInputTraditionalForm"],
 " will be used as the default format type for text that appears in \
graphics,"
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"$FormatType", "=", "TraditionalForm"}], ";"}], 
  TraditionalForm]], "Input",
 InitializationCell->True],

Cell["\<\
and the default style for text in graphics is set as follows.\
\>", "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"$TextStyle", "=", 
    RowBox[{"{", 
     RowBox[{"FontSize", "\[Rule]", "10"}], "}"}]}], ";"}], 
  TraditionalForm]], "Input",
 InitializationCell->True],

Cell[TextData[{
 "The following options for ",
 StyleBox["ParametricPlot", "InlineInputTraditionalForm"],
 ", ",
 StyleBox["DensityPlot", "InlineInputTraditionalForm"],
 ", and ",
 StyleBox["ListPlot", "InlineInputTraditionalForm"],
 " are desirable."
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"SetOptions", "[", 
    RowBox[{"ParametricPlot", ",", 
     RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}], ";"}], 
  TraditionalForm]], "Input",
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"SetOptions", "[", 
    RowBox[{"DensityPlot", ",", 
     RowBox[{"PlotPoints", "\[Rule]", "100"}], ",", 
     RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
     RowBox[{"Compiled", "\[Rule]", "False"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "Hue"}]}], "]"}], ";"}], 
  TraditionalForm]], "Input",
 InitializationCell->True,
 AspectRatioFixed->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"SetOptions", "[", 
    RowBox[{"ListPlot", ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"AbsolutePointSize", "(", "0.002", ")"}]}]}], "]"}], ";"}], 
  TraditionalForm]], "Input",
 InitializationCell->True,
 AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Title"],
 ".",
 
 CounterBox["Section"],
 " Planar Pendulum"
}], "SectionFirst",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell[TextData[{
 "Consider a particle of mass ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]]],
 " that is constrained by a rigid and massless rod to move in a vertical \
circle of radius ",
 Cell[BoxData[
  FormBox["l", TraditionalForm]]],
 ".  The equation of motion is"
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      OverscriptBox["\[Theta]", "\[DoubleDot]"], "(", "t", ")"}], "+", 
     RowBox[{
      SuperscriptBox["\[Omega]", "2"], " ", 
      RowBox[{"sin", "(", 
       RowBox[{"\[Theta]", "(", "t", ")"}], ")"}]}]}], "=", "0"}], ",", " ", 
   RowBox[{"\[Omega]", "=", 
    FractionBox["g", "l"]}], ","}], TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox["\[Theta]", TraditionalForm]]],
 StyleBox[" ",
  FontFamily->"Symbol",
  FontSlant->"Italic"],
 "is the angle measured from the vertical direction with clockwise positive."
}], "Text"],

Cell[TextData[{
 "Usually, only the ",
 StyleBox["harmonic approximation",
  FontSlant->"Italic"],
 " (",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"sin", "(", "\[Theta]", ")"}], TraditionalForm]]],
 " is replaced by ",
 Cell[BoxData[
  FormBox["\[Theta]", TraditionalForm]]],
 ") of this equation is considered:"
}], "Text",
 CellTags->"harmonic approximation"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     OverscriptBox["\[Theta]", "\[DoubleDot]"], "(", "t", ")"}], "+", 
    RowBox[{
     SuperscriptBox["\[Omega]", "2"], " ", 
     RowBox[{"\[Theta]", "(", "t", ")"}]}]}], "=", "0."}], 
  TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
 "Here, the more general equation (which includes ",
 StyleBox["damping",
  FontSlant->"Italic"],
 " when ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Beta]", " ", "\[NotEqual]", " ", "0"}], TraditionalForm]]],
 " and a ",
 StyleBox["sinusoidal driving term",
  FontSlant->"Italic"],
 " when ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Alpha]", " ", "\[NotEqual]", " ", "0"}], TraditionalForm]]],
 ")"
}], "Text",
 CellTags->{"damping", "sinusoidal driving term"}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     OverscriptBox["\[Theta]", "\[DoubleDot]"], "(", "t", ")"}], "+", 
    RowBox[{"\[Beta]", " ", 
     RowBox[{
      OverscriptBox["\[Theta]", "."], "(", "t", ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["\[Omega]", "2"], " ", 
     RowBox[{"sin", "(", 
      RowBox[{"\[Theta]", "(", "t", ")"}], ")"}]}]}], "=", 
   RowBox[{"\[Alpha]", " ", 
    RowBox[{"sin", "(", 
     RowBox[{
      SubscriptBox["\[Omega]", "d"], " ", "t"}], ")"}]}]}], 
  TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
 "will be examined. The units of mass, length, and time are chosen so that \
they are all equal to unity, ",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", we are working with ",
 StyleBox["dimensionless variables",
  FontSlant->"Italic"],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Title"],
 ".",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 " Undamped pendulum"
}], "Subsection"],

Cell[TextData[{
 "The dimensionless equation for the undamped pendulum in ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " notation reads"
}], "Text",
 CellTags->"undamped pendulum"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ScriptCapitalP]", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
        MultilineFunction->None], "(", "t", ")"}], "+", 
      RowBox[{"sin", "(", 
       RowBox[{"\[Theta]", "(", "t", ")"}], ")"}]}], "==", "0"}]}], ";"}], 
  TraditionalForm]], "Input"],

Cell[TextData[{
 
 CounterBox["Exercise"],
 ". Use ",
 StyleBox["NDSolve", "InlineInputTraditionalForm"],
 " to numerically solve ",
 StyleBox["\[ScriptCapitalP]", "InlineInputTraditionalForm"],
 " for ",
 Cell[BoxData[
  FormBox["\[Theta]", TraditionalForm]]],
 " for 10 units of time (\"seconds\") with the initial conditions, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Theta]", "(", "0", ")"}], "==", "0"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Theta]", "\[Prime]"], "(", "0", ")"}], "\[Equal]", 
    "1"}], TraditionalForm]]],
 " and call the result ",
 StyleBox["\[ScriptU]", "InlineInputTraditionalForm"],
 ". (NB. It is more convenient to solve for \[Theta] rather than ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Theta]", "(", "t", ")"}], TraditionalForm]]],
 "). Display a ",
 StyleBox["phase-space plot",
  FontSlant->"Italic"],
 " by pairing up the angle and angular velocity values using ",
 StyleBox[Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Theta]", "(", "t", ")"}], ",", 
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "(", "t", ")"}]}], "}"}], "/.", 
    "\[InvisibleSpace]", 
    RowBox[{"First", "[", "\[ScriptU]", "]"}]}], TraditionalForm]], 
  "InlineInputTraditionalForm"], "InlineInputTraditionalForm"],
 " and visualize the motion using ",
 StyleBox["ParametricPlot", "InlineInputTraditionalForm"],
 ". Describe the trajectory that results. ",
 StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion",
 CellTags->"phase-space plot"],

Cell[CellGroupData[{

Cell[" Answer", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"u", "=", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"sin", "(", 
          RowBox[{"\[Theta]", "(", "t", ")"}], ")"}], "+", 
         RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
           MultilineFunction->None], "(", "t", ")"}]}], "\[LongEqual]", "0"}],
        ",", 
       RowBox[{
        RowBox[{"\[Theta]", "(", "0", ")"}], "\[LongEqual]", "0"}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "(", "0", ")"}], "\[LongEqual]", "1"}]}], 
      "}"}], ",", "\[Theta]", ",", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "10"}], "}"}]}], "]"}]}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{"\[Theta]", "\[Rule]", 
     TagBox[
      RowBox[{"InterpolatingFunction", "[", 
       RowBox[{
        RowBox[{"(", "\[NoBreak]", GridBox[{
           {"0.`", "10.`"}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.7]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
            "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], 
        ",", "\<\"<>\"\>"}], "]"}],
      False,
      Editable->False]}], "}"}], "}"}], TraditionalForm]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"ParametricPlot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Theta]", "(", "t", ")"}], ",", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "(", "t", ")"}]}], "}"}], "/.", 
     "\[InvisibleSpace]", 
     RowBox[{"First", "[", "u", "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "10"}], "}"}]}], "]"}], 
  TraditionalForm]], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95493 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 9  scalefont  setfont
% Scaling calculations
0.499998 0.45473 0.47746 0.45473 [
[.04527 .46496 -7.9375 -13.25 ]
[.04527 .46496 7.9375 0 ]
[.27263 .46496 -11.6875 -13.25 ]
[.27263 .46496 11.6875 0 ]
[.72736 .46496 -8.25 -13.25 ]
[.72736 .46496 8.25 0 ]
[.95473 .46496 -4.5 -13.25 ]
[.95473 .46496 4.5 0 ]
[.4875 .02273 -15.875 -6.625 ]
[.4875 .02273 0 6.625 ]
[.4875 .25009 -23.375 -6.625 ]
[.4875 .25009 0 6.625 ]
[.4875 .70483 -16.5 -6.625 ]
[.4875 .70483 0 6.625 ]
[.4875 .93219 -9 -6.625 ]
[.4875 .93219 0 6.625 ]
[ 0 0 0 0 ]
[ 1 .95493 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.04527 .47746 m
.04527 .48371 L
s
gsave
.04527 .46496 -68.9375 -17.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.27263 .47746 m
.27263 .48371 L
s
gsave
.27263 .46496 -72.6875 -17.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.72736 .47746 m
.72736 .48371 L
s
gsave
.72736 .46496 -69.25 -17.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.95473 .47746 m
.95473 .48371 L
s
gsave
.95473 .46496 -65.5 -17.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.09074 .47746 m
.09074 .48121 L
s
.13621 .47746 m
.13621 .48121 L
s
.18169 .47746 m
.18169 .48121 L
s
.22716 .47746 m
.22716 .48121 L
s
.31811 .47746 m
.31811 .48121 L
s
.36358 .47746 m
.36358 .48121 L
s
.40905 .47746 m
.40905 .48121 L
s
.45453 .47746 m
.45453 .48121 L
s
.54547 .47746 m
.54547 .48121 L
s
.59094 .47746 m
.59094 .48121 L
s
.63642 .47746 m
.63642 .48121 L
s
.68189 .47746 m
.68189 .48121 L
s
.77284 .47746 m
.77284 .48121 L
s
.81831 .47746 m
.81831 .48121 L
s
.86378 .47746 m
.86378 .48121 L
s
.90926 .47746 m
.90926 .48121 L
s
.25 Mabswid
0 .47746 m
1 .47746 L
s
.5 .02273 m
.50625 .02273 L
s
gsave
.4875 .02273 -76.875 -10.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.5 .25009 m
.50625 .25009 L
s
gsave
.4875 .25009 -84.375 -10.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Mathematica1
%%IncludeFont: Mathematica1
/Mathematica1 findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
69.875 13.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .70483 m
.50625 .70483 L
s
gsave
.4875 .70483 -77.5 -10.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.5 .93219 m
.50625 .93219 L
s
gsave
.4875 .93219 -70 -10.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.25 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.875 moveto
%%IncludeResource: font Times-Roman
%%IncludeFont: Times-Roman
/Times-Roman findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.5 .0682 m
.50375 .0682 L
s
.5 .11368 m
.50375 .11368 L
s
.5 .15915 m
.50375 .15915 L
s
.5 .20462 m
.50375 .20462 L
s
.5 .29557 m
.50375 .29557 L
s
.5 .34104 m
.50375 .34104 L
s
.5 .38651 m
.50375 .38651 L
s
.5 .43199 m
.50375 .43199 L
s
.5 .52293 m
.50375 .52293 L
s
.5 .56841 m
.50375 .56841 L
s
.5 .61388 m
.50375 .61388 L
s
.5 .65935 m
.50375 .65935 L
s
.5 .7503 m
.50375 .7503 L
s
.5 .79577 m
.50375 .79577 L
s
.5 .84124 m
.50375 .84124 L
s
.5 .88672 m
.50375 .88672 L
s
.25 Mabswid
.5 0 m
.5 .95493 L
s
0 0 m
1 0 L
1 .95493 L
0 .95493 L
closepath
clip
newpath
.5 Mabswid
.5 .93219 m
.50561 .93216 L
.51072 .93206 L
.51661 .93189 L
.52218 .93165 L
.53207 .93106 L
.54279 .93017 L
.55457 .92891 L
.56702 .92723 L
.58922 .92338 L
.6119 .91828 L
.63289 .91248 L
.67949 .89576 L
.72488 .87398 L
.76408 .85026 L
.80656 .8185 L
.84242 .78563 L
.8974 .71965 L
.92094 .68212 L
.9416 .64062 L
.95701 .59959 L
.96373 .57612 L
.96865 .55436 L
.97195 .53517 L
.97341 .52424 L
.97449 .51402 L
.97497 .50848 L
.97535 .50322 L
.97563 .49845 L
.97587 .49337 L
.97597 .49075 L
.97605 .48785 L
.97616 .48275 L
.97618 .47989 L
.97619 .47679 L
.97617 .47388 L
.97614 .4712 L
.97602 .46592 L
.97584 .46094 L
.97563 .45646 L
.97534 .45161 L
.97448 .44074 L
.97341 .43072 L
.97081 .4125 L
.96714 .39328 L
.95635 .35327 L
.94839 .33083 L
.93975 .3101 L
.91924 .26982 L
.89578 .23296 L
Mistroke
.84182 .16869 L
.80911 .13856 L
.77111 .10945 L
.73281 .08535 L
.69563 .06625 L
.65008 .04797 L
.6254 .04025 L
.59894 .03358 L
.57559 .02904 L
.55364 .0259 L
.54097 .02458 L
.52941 .02368 L
.523 .02331 L
.51962 .02315 L
.51604 .02301 L
.51291 .02291 L
.50945 .02283 L
.50337 .02274 L
.49754 .02274 L
.49212 .0228 L
.48617 .02294 L
.48284 .02305 L
.47983 .02318 L
.47371 .02349 L
.4671 .02392 L
.45513 .02495 L
.444 .02619 L
.43227 .02779 L
.41138 .03142 L
.38744 .03681 L
.36537 .04296 L
.3165 .06085 L
.27201 .08264 L
.23224 .10714 L
.16526 .1617 L
.13491 .19374 L
.10632 .23 L
.06512 .29957 L
.04946 .33652 L
.04269 .35624 L
.03667 .37721 L
.03233 .39576 L
.02859 .41618 L
.02728 .42518 L
.02612 .43482 L
.02531 .4431 L
.02462 .45222 L
.0243 .45773 L
.02408 .46289 L
.02391 .46834 L
Mistroke
.02385 .4714 L
.02382 .4742 L
.02381 .47918 L
.02387 .48461 L
.024 .48973 L
.02417 .49449 L
.02448 .50049 L
.02485 .50613 L
.02576 .51667 L
.02706 .52801 L
.02883 .54024 L
.03275 .56115 L
.03811 .58311 L
.05079 .62194 L
.06705 .65932 L
.08855 .69821 L
.1375 .76415 L
.16998 .79771 L
.20918 .83108 L
.24603 .85685 L
.28949 .8815 L
.33389 .90113 L
.37726 .91542 L
.40171 .92148 L
.42437 .92587 L
.43736 .92786 L
.44948 .92938 L
.46217 .93061 L
.46889 .93113 L
.47607 .93156 L
.48196 .93183 L
.48534 .93195 L
.48844 .93204 L
.4917 .93211 L
.4952 .93217 L
.49845 .93219 L
.50153 .93219 L
.50736 .93213 L
.51277 .93201 L
.51869 .93181 L
.525 .9315 L
.53188 .93107 L
.53931 .93049 L
.55273 .92913 L
.56576 .92742 L
.57767 .92552 L
.62333 .91525 L
.64585 .90838 L
.67008 .89958 L
.75274 .85763 L
Mistroke
.79482 .82798 L
.82997 .79776 L
.88794 .73278 L
.91466 .69292 L
.93524 .65459 L
.95128 .61639 L
.96276 .57988 L
.96776 .55874 L
.97132 .53928 L
.97288 .5285 L
.97423 .51672 L
.97473 .51132 L
.97519 .50557 L
.97553 .50021 L
.97579 .4952 L
.97599 .49008 L
.97607 .48736 L
.97613 .48445 L
.97617 .48139 L
.97619 .4785 L
.97617 .47307 L
.97608 .46801 L
.97594 .46332 L
.97572 .45818 L
.97541 .45271 L
.97454 .44146 L
.97343 .4309 L
.97189 .41934 L
.96984 .4069 L
.96548 .38595 L
.95968 .36403 L
.94622 .32534 L
.9291 .28795 L
.90674 .24924 L
.85633 .1839 L
.82297 .15068 L
.78294 .11791 L
.74543 .09276 L
.70143 .06897 L
.66791 .05449 L
.63071 .04179 L
.60976 .03611 L
.59038 .03177 L
.55195 .0257 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 275},
 ImageMargins->{{30, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 359}, {342.75, 0}} -> {-1.1006, -1.05079, 0.00766438, \
0.00766438}}],

Cell[BoxData[
 FormBox[
  TagBox[
   RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
   False,
   Editable->False], TraditionalForm]], "Output"]
}, Closed]],

Cell[TextData[{
 "Note that we are using the first (in this case there is only one) numerical \
solution to the differential equation and computing its derivative (",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Theta]", "\[Prime]",
     MultilineFunction->None], "(", "t", ")"}], TraditionalForm]]],
 ") ",
 StyleBox["numerically",
  FontSlant->"Italic"],
 "."
}], "Warning"],

Cell[TextData[{
 
 CounterBox["Exercise"],
 ". Increase the initial velocity, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Theta]", "\[Prime]",
     MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
 ", to something slightly less than 2 and redo ",
 
 CounterBox["Exercise", "phase-space plot"],
 ". Explain what is happening here. ",
 StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
 
 CounterBox["Exercise"],
 ". Set ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Theta]", "\[Prime]",
     MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
 " to 2 and redo ",
 
 CounterBox["Exercise", "phase-space plot"],
 ", but over a longer time interval. Explain what is happening here. ",
 StyleBox["[2 Marks]", "MarkersComment"],
 " "
}], "BeginEndQuestion"],

Cell[" ", "Answer"],

Cell[TextData[{
 
 CounterBox["Exercise"],
 ". Explain the critical value of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Theta]", "\[Prime]",
     MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
 " from an energy viewpoint (",
 StyleBox["Hint",
  FontSlant->"Italic"],
 ": the kinetic energy is proportional to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "(", "t", ")"}], "2"]}], TraditionalForm]]],
 " and the initial potential energy is 0. What is the total energy at the top \
of the loop?). ",
 StyleBox["[3 Marks]", "MarkersComment"],
 " "
}], "BeginEndQuestion"],

Cell[" ", "Answer"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Title"],
 ".",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 " Damped pendulum"
}], "Subsection"],

Cell[TextData[{
 "The equation for the ",
 StyleBox["damped pendulum",
  FontSlant->"Italic"],
 " (where the damping is proportional to the velocity) can be written"
}], "Text",
 CellTags->"damped pendulum"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ScriptCapitalP]", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
        MultilineFunction->None], "(", "t", ")"}], "+", 
      RowBox[{"\[Beta]", " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "(", "t", ")"}]}], "+", 
      RowBox[{"sin", "(", 
       RowBox[{"\[Theta]", "(", "t", ")"}], ")"}]}], "==", "0"}]}], ";"}], 
  TraditionalForm]], "Input"],

Cell[TextData[{
 
 CounterBox["Exercise"],
 ". Solve the equation numerically for the damped pendulum with damping ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    FormBox[
     RowBox[{"\[Beta]", "\[Rule]", "0.2"}],
     TraditionalForm]}], TraditionalForm]]],
 " and initial conditions ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Theta]", "(", "0", ")"}], "==", "0"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Theta]", "\[Prime]",
      MultilineFunction->None], "(", "0", ")"}], "==", "1"}], 
   TraditionalForm]]],
 " for 20 seconds. Display a phase-space plot and interpret the result. ",
 StyleBox["[3 Marks]", "MarkersComment"],
 " "
}], "BeginEndQuestion"],

Cell[" ", "Answer"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Title"],
 ".",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 " Damped driven pendulum"
}], "Subsection"],

Cell[TextData[{
 "The equation for the ",
 StyleBox["damped driven pendulum",
  FontSlant->"Italic"],
 " can be written"
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[ScriptCapitalP]", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
        MultilineFunction->None], "(", "t", ")"}], "+", 
      RowBox[{"\[Beta]", " ", 
       RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
         MultilineFunction->None], "(", "t", ")"}]}], "+", 
      RowBox[{"sin", "(", 
       RowBox[{"\[Theta]", "(", "t", ")"}], ")"}]}], "==", 
     RowBox[{"\[Alpha]", " ", 
      RowBox[{"cos", "(", 
       RowBox[{"\[Omega]", " ", "t"}], ")"}]}]}]}], ";"}], 
  TraditionalForm]], "Input"],

Cell[TextData[{
 
 CounterBox["Exercise"],
 ". Solve the equation numerically for the damped driven pendulum with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Beta]", "\[Rule]", "0.2"}], ",", 
     RowBox[{"\[Alpha]", "\[Rule]", "0.52"}], ",", 
     RowBox[{"\[Omega]", "\[Rule]", "0.694"}]}], "}"}], TraditionalForm]]],
 " and initial conditions ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Theta]", "(", "0", ")"}], "==", "0.8"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "(", "0", ")"}], "\[Equal]", "0.8"}]}], 
    "}"}], TraditionalForm]]],
 " for 400 seconds and call the result ",
 StyleBox["\[ScriptD]", "InlineInputTraditionalForm"],
 ". You will need to increase the number of time-steps by playing with the ",
 StyleBox["MaxSteps", "InlineInputTraditionalForm"],
 " option of ",
 StyleBox["NDSolve", "InlineInputTraditionalForm"],
 ". Display a phase-space plot of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\[Theta]", "(", "t", ")"}], ",", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "(", "t", ")"}]}], "}"}], 
   TraditionalForm]]],
 " using ",
 StyleBox["ParametricPlot", "InlineInputTraditionalForm"],
 " with ",
 StyleBox["AspectRatio \[Rule] 1/4", "InlineInputTraditionalForm"],
 " and interpret the result. ",
 StyleBox["[3 Marks]", "MarkersComment"],
 " "
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
 
 CounterBox["Exercise"],
 ". Physically, since the angle ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Theta]", "\[Element]", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"-", "\[Pi]"}], ",", "\[Pi]"}], "]"}]}], TraditionalForm]]],
 ", it makes more sense to examine ",
 Cell[BoxData[
  FormBox[
   InterpretationBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Theta]", "-", "\[Pi]"}], ")"}], " ", "mod", " ", 
     RowBox[{"(", 
      RowBox[{"2", " ", "\[Pi]"}], ")"}]}],
    Mod[\[Theta][t] - Pi, 2 Pi]], TraditionalForm]]],
 ". Display a phase-space plot of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Theta]", "(", "t", ")"}], "-", "\[Pi]"}], ")"}], " ", 
       "mod", " ", 
       RowBox[{"(", 
        RowBox[{"2", " ", "\[Pi]"}], ")"}]}],
      Mod[\[Theta][t] - Pi, 2 Pi]], ",", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "(", "t", ")"}]}], "}"}], 
   TraditionalForm]]],
 " and interpret the result. ",
 StyleBox["[3 Marks]", "MarkersComment"],
 " "
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
 "You should see that the resulting phase-space diagram is ",
 StyleBox["periodic",
  FontSlant->"Italic"],
 " (in the language of chaos it shows a ",
 StyleBox["period-3 limit cycle",
  FontSlant->"Italic"],
 ")."
}], "Text",
 CellTags->{"period-3 limit cycle", "periodic"}],

Cell[TextData[{
 "The ",
 StyleBox["Poincar\[EAcute] section",
  FontSlant->"Italic"],
 " provides a simplification of the phase diagram by sampling at time \
intervals equal to the period of the driving frequency.  "
}], "Text",
 CellTags->{"Poincar\[EAcute] section", "driving frequency"}],

Cell[TextData[{
 
 CounterBox["Exercise"],
 ". Compute the period using ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Tau]", "=", 
    FractionBox[
     RowBox[{"2", " ", "\[Pi]"}], "\[Omega]"]}], TraditionalForm]]],
 ". How many cycles were present in the first 100 seconds? ",
 StyleBox["[2 Marks]", "MarkersComment"],
 " "
}], "BeginEndQuestion"],

Cell["\<\
To avoid transient effects, the data for the first few cycles should be \
discarded.\
\>", "Text",
 CellTags->"transient effects"],

Cell[TextData[{
 
 CounterBox["Exercise"],
 ". Visualize the Poincar\[EAcute] section by applying ",
 StyleBox["ListPlot", "InlineInputTraditionalForm"],
 " to a table of values of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"\[Theta]", "(", "t", ")"}], "-", "\[Pi]"}], ")"}], " ", 
       "mod", " ", 
       RowBox[{"(", 
        RowBox[{"2", " ", "\[Pi]"}], ")"}]}],
      Mod[\[Theta][t] - Pi, 2 Pi]], ",", 
     RowBox[{
      SuperscriptBox["\[Theta]", "\[Prime]",
       MultilineFunction->None], "(", "t", ")"}]}], "}"}], 
   TraditionalForm]]],
 " between ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "=", 
    RowBox[{"10", "\[Tau]"}]}], TraditionalForm]]],
 " (",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", discarding the first 10 cycles) and 400 in steps of \[Tau]. Interpret the \
result. ",
 StyleBox["[3 Marks]", "MarkersComment"],
 " "
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Title"],
 ".",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 " Series solution"
}], "Subsection"],

Cell[TextData[{
 "The easiest way to get ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " to solve differential equations such as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["y", "\[Prime]\[Prime]",
       MultilineFunction->None], "(", "x", ")"}], "+", 
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      RowBox[{"y", "(", "x", ")"}]}]}], "=", "0"}], TraditionalForm]]],
 " using series methods is direct expansion of the equation, ",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ","
}], "Text",
 CellTags->"series solution"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"eqn", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["y", "\[Prime]\[Prime]",
       MultilineFunction->None], "(", "x", ")"}], "+", 
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      RowBox[{"y", "(", "x", ")"}]}], "+", 
     SuperscriptBox[
      RowBox[{"O", "(", "x", ")"}], "7"]}], "==", "0"}]}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{
   InterpretationBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"y", "(", "0", ")"}], " ", 
        SuperscriptBox["k", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["y", "\[Prime]\[Prime]",
         MultilineFunction->None], "(", "0", ")"}]}], ")"}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["y", "\[Prime]",
           MultilineFunction->None], "(", "0", ")"}], " ", 
         SuperscriptBox["k", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["y", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "(", "0", ")"}]}], ")"}], " ", "x"}], "+",
      
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{
          SuperscriptBox["y", "\[Prime]\[Prime]",
           MultilineFunction->None], "(", "0", ")"}], " ", 
         SuperscriptBox["k", "2"]}], "+", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{
          SuperscriptBox["y", 
           TagBox[
            RowBox[{"(", "4", ")"}],
            Derivative],
           MultilineFunction->None], "(", "0", ")"}]}]}], ")"}], " ", 
      SuperscriptBox["x", "2"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "6"], " ", 
         RowBox[{
          SuperscriptBox["y", 
           TagBox[
            RowBox[{"(", "3", ")"}],
            Derivative],
           MultilineFunction->None], "(", "0", ")"}], " ", 
         SuperscriptBox["k", "2"]}], "+", 
        RowBox[{
         FractionBox["1", "6"], " ", 
         RowBox[{
          SuperscriptBox["y", 
           TagBox[
            RowBox[{"(", "5", ")"}],
            Derivative],
           MultilineFunction->None], "(", "0", ")"}]}]}], ")"}], " ", 
      SuperscriptBox["x", "3"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "24"], " ", 
         RowBox[{
          SuperscriptBox["y", 
           TagBox[
            RowBox[{"(", "4", ")"}],
            Derivative],
           MultilineFunction->None], "(", "0", ")"}], " ", 
         SuperscriptBox["k", "2"]}], "+", 
        RowBox[{
         FractionBox["1", "24"], " ", 
         RowBox[{
          SuperscriptBox["y", 
           TagBox[
            RowBox[{"(", "6", ")"}],
            Derivative],
           MultilineFunction->None], "(", "0", ")"}]}]}], ")"}], " ", 
      SuperscriptBox["x", "4"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "120"], " ", 
         RowBox[{
          SuperscriptBox["y", 
           TagBox[
            RowBox[{"(", "5", ")"}],
            Derivative],
           MultilineFunction->None], "(", "0", ")"}], " ", 
         SuperscriptBox["k", "2"]}], "+", 
        RowBox[{
         FractionBox["1", "120"], " ", 
         RowBox[{
          SuperscriptBox["y", 
           TagBox[
            RowBox[{"(", "7", ")"}],
            Derivative],
           MultilineFunction->None], "(", "0", ")"}]}]}], ")"}], " ", 
      SuperscriptBox["x", "5"]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "720"], " ", 
         RowBox[{
          SuperscriptBox["y", 
           TagBox[
            RowBox[{"(", "6", ")"}],
            Derivative],
           MultilineFunction->None], "(", "0", ")"}], " ", 
         SuperscriptBox["k", "2"]}], "+", 
        RowBox[{
         FractionBox["1", "720"], " ", 
         RowBox[{
          SuperscriptBox["y", 
           TagBox[
            RowBox[{"(", "8", ")"}],
            Derivative],
           MultilineFunction->None], "(", "0", ")"}]}]}], ")"}], " ", 
      SuperscriptBox["x", "6"]}], "+", 
     InterpretationBox[
      RowBox[{"O", "(", 
       SuperscriptBox["x", "7"], ")"}],
      SeriesData[x, 0, {}, 0, 7, 1]]}],
    SeriesData[
    x, 0, {k^2 y[0] + Derivative[2][y][0], k^2 Derivative[1][y][0] + 
      Derivative[3][y][0], Rational[1, 2] k^2 Derivative[2][y][0] + 
      Rational[1, 2] Derivative[4][y][0], 
      Rational[1, 6] k^2 Derivative[3][y][0] + 
      Rational[1, 6] Derivative[5][y][0], 
      Rational[1, 24] k^2 Derivative[4][y][0] + 
      Rational[1, 24] Derivative[6][y][0], 
      Rational[1, 120] k^2 Derivative[5][y][0] + 
      Rational[1, 120] Derivative[7][y][0], 
      Rational[1, 720] k^2 Derivative[6][y][0] + 
      Rational[1, 720] Derivative[8][y][0]}, 0, 7, 1]], "==", "0"}], 
  TraditionalForm]], "Output"]
}, Closed]],

Cell[TextData[{
 "This is equivalent to expanding ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "(", "x", ")"}], TraditionalForm]]],
 " (and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["y", "\[Prime]\[Prime]",
     MultilineFunction->None], "(", "x", ")"}], TraditionalForm]]],
 ") into a power series."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"yseries", "=", 
   RowBox[{
    RowBox[{"y", "(", "x", ")"}], "+", 
    SuperscriptBox[
     RowBox[{"O", "(", "x", ")"}], "7"]}]}], TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    RowBox[{"y", "(", "0", ")"}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["y", "\[Prime]",
       MultilineFunction->None], "(", "0", ")"}], " ", "x"}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{
      SuperscriptBox["y", "\[Prime]\[Prime]",
       MultilineFunction->None], "(", "0", ")"}], " ", 
     SuperscriptBox["x", "2"]}], "+", 
    RowBox[{
     FractionBox["1", "6"], " ", 
     RowBox[{
      SuperscriptBox["y", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "(", "0", ")"}], " ", 
     SuperscriptBox["x", "3"]}], "+", 
    RowBox[{
     FractionBox["1", "24"], " ", 
     RowBox[{
      SuperscriptBox["y", 
       TagBox[
        RowBox[{"(", "4", ")"}],
        Derivative],
       MultilineFunction->None], "(", "0", ")"}], " ", 
     SuperscriptBox["x", "4"]}], "+", 
    RowBox[{
     FractionBox["1", "120"], " ", 
     RowBox[{
      SuperscriptBox["y", 
       TagBox[
        RowBox[{"(", "5", ")"}],
        Derivative],
       MultilineFunction->None], "(", "0", ")"}], " ", 
     SuperscriptBox["x", "5"]}], "+", 
    RowBox[{
     FractionBox["1", "720"], " ", 
     RowBox[{
      SuperscriptBox["y", 
       TagBox[
        RowBox[{"(", "6", ")"}],
        Derivative],
       MultilineFunction->None], "(", "0", ")"}], " ", 
     SuperscriptBox["x", "6"]}], "+", 
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox["x", "7"], ")"}],
     SeriesData[x, 0, {}, 0, 7, 1]]}],
   SeriesData[x, 0, {
     y[0], 
     Derivative[1][y][0], Rational[1, 2] Derivative[2][y][0], Rational[1, 6] 
     Derivative[3][y][0], Rational[1, 24] Derivative[4][y][0], 
     Rational[1, 120] Derivative[5][y][0], Rational[1, 720] 
     Derivative[6][y][0]}, 0, 7, 1]], TraditionalForm]], "Output"]
}, Closed]],

Cell[TextData[{
 "You can see that the expression multiplying each power of ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " in the expansion of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["y", "\[Prime]\[Prime]",
      MultilineFunction->None], "(", "x", ")"}], "+", 
    RowBox[{
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"y", "(", "x", ")"}]}]}], TraditionalForm]]],
 " must vanish identically, ",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"y", "(", "0", ")"}], " ", 
      SuperscriptBox["k", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["y", "\[Prime]\[Prime]",
       MultilineFunction->None], "(", "0", ")"}]}], "=", "0"}], 
   TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["y", "\[Prime]",
        MultilineFunction->None], "(", "0", ")"}], " ", 
      SuperscriptBox["k", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["y", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "(", "0", ")"}]}], "=", "0"}], 
   TraditionalForm]]],
 ", \[Ellipsis]   To see the equations generated you can use ",
 Cell[BoxData[
  FormBox[
   StyleBox["LogicalExpand", "Input"], TraditionalForm]]],
 " (this step is not required). "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"LogicalExpand", "[", "eqn", "]"}], TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"y", "(", "0", ")"}], " ", 
      SuperscriptBox["k", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["y", "\[Prime]\[Prime]",
       MultilineFunction->None], "(", "0", ")"}]}], "==", "0"}], "\[And]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["y", "\[Prime]",
        MultilineFunction->None], "(", "0", ")"}], " ", 
      SuperscriptBox["k", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["y", 
       TagBox[
        RowBox[{"(", "3", ")"}],
        Derivative],
       MultilineFunction->None], "(", "0", ")"}]}], "==", "0"}], "\[And]", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{
       SuperscriptBox["y", "\[Prime]\[Prime]",
        MultilineFunction->None], "(", "0", ")"}], " ", 
      SuperscriptBox["k", "2"]}], "+", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{
       SuperscriptBox["y", 
        TagBox[
         RowBox[{"(", "4", ")"}],
         Derivative],
        MultilineFunction->None], "(", "0", ")"}]}]}], "==", "0"}], "\[And]", 
   
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{
       SuperscriptBox["y", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "(", "0", ")"}], " ", 
      SuperscriptBox["k", "2"]}], "+", 
     RowBox[{
      FractionBox["1", "6"], " ", 
      RowBox[{
       SuperscriptBox["y", 
        TagBox[
         RowBox[{"(", "5", ")"}],
         Derivative],
        MultilineFunction->None], "(", "0", ")"}]}]}], "==", "0"}], "\[And]", 
   
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", "24"], " ", 
      RowBox[{
       SuperscriptBox["y", 
        TagBox[
         RowBox[{"(", "4", ")"}],
         Derivative],
        MultilineFunction->None], "(", "0", ")"}], " ", 
      SuperscriptBox["k", "2"]}], "+", 
     RowBox[{
      FractionBox["1", "24"], " ", 
      RowBox[{
       SuperscriptBox["y", 
        TagBox[
         RowBox[{"(", "6", ")"}],
         Derivative],
        MultilineFunction->None], "(", "0", ")"}]}]}], "==", "0"}], "\[And]", 
   
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", "120"], " ", 
      RowBox[{
       SuperscriptBox["y", 
        TagBox[
         RowBox[{"(", "5", ")"}],
         Derivative],
        MultilineFunction->None], "(", "0", ")"}], " ", 
      SuperscriptBox["k", "2"]}], "+", 
     RowBox[{
      FractionBox["1", "120"], " ", 
      RowBox[{
       SuperscriptBox["y", 
        TagBox[
         RowBox[{"(", "7", ")"}],
         Derivative],
        MultilineFunction->None], "(", "0", ")"}]}]}], "==", "0"}], "\[And]", 
   
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox["1", "720"], " ", 
      RowBox[{
       SuperscriptBox["y", 
        TagBox[
         RowBox[{"(", "6", ")"}],
         Derivative],
        MultilineFunction->None], "(", "0", ")"}], " ", 
      SuperscriptBox["k", "2"]}], "+", 
     RowBox[{
      FractionBox["1", "720"], " ", 
      RowBox[{
       SuperscriptBox["y", 
        TagBox[
         RowBox[{"(", "8", ")"}],
         Derivative],
        MultilineFunction->None], "(", "0", ")"}]}]}], "==", "0"}]}], 
  TraditionalForm]], "Output"]
}, Closed]],

Cell[TextData[{
 "Note that the initial conditions, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "(", "0", ")"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["y", "\[Prime]",
     MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
 " are ",
 StyleBox["not",
  FontSlant->"Italic"],
 " determined but that you can solve for the undetermined coefficients (",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["y", "\[Prime]\[Prime]",
     MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["y", 
     TagBox[
      RowBox[{"(", "3", ")"}],
      Derivative],
     MultilineFunction->None], "(", "0", ")"}], TraditionalForm]]],
 ", \[Ellipsis]) in terms of the initial conditions."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"Solve", "[", 
   RowBox[{"eqn", ",", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       SuperscriptBox["y", 
        TagBox[
         RowBox[{"(", "n", ")"}],
         Derivative],
        MultilineFunction->None], "(", "0", ")"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "2", ",", "8"}], "}"}]}], "]"}]}], "]"}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["y", 
        TagBox[
         RowBox[{"(", "7", ")"}],
         Derivative],
        MultilineFunction->None], "(", "0", ")"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["k", "6"]}], " ", 
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "(", "0", ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["y", 
        TagBox[
         RowBox[{"(", "8", ")"}],
         Derivative],
        MultilineFunction->None], "(", "0", ")"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["k", "8"], " ", 
       RowBox[{"y", "(", "0", ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["y", 
        TagBox[
         RowBox[{"(", "5", ")"}],
         Derivative],
        MultilineFunction->None], "(", "0", ")"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["k", "4"], " ", 
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "(", "0", ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["y", 
        TagBox[
         RowBox[{"(", "6", ")"}],
         Derivative],
        MultilineFunction->None], "(", "0", ")"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["k", "6"]}], " ", 
       RowBox[{"y", "(", "0", ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["y", 
        TagBox[
         RowBox[{"(", "4", ")"}],
         Derivative],
        MultilineFunction->None], "(", "0", ")"}], "\[Rule]", 
      RowBox[{
       SuperscriptBox["k", "4"], " ", 
       RowBox[{"y", "(", "0", ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["y", "\[Prime]\[Prime]",
        MultilineFunction->None], "(", "0", ")"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["k", "2"]}], " ", 
       RowBox[{"y", "(", "0", ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["y", 
        TagBox[
         RowBox[{"(", "3", ")"}],
         Derivative],
        MultilineFunction->None], "(", "0", ")"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["k", "2"]}], " ", 
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "(", "0", ")"}]}]}]}], "}"}], "}"}], 
  TraditionalForm]], "Output"]
}, Closed]],

Cell[TextData[{
 "To obtain the series solution to the original equation you substitute these \
coefficients into the series expansion of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "(", "x", ")"}], TraditionalForm]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"yseries", "/.", 
   RowBox[{"First", "[", "%", "]"}]}], TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    RowBox[{"y", "(", "0", ")"}], "+", 
    RowBox[{
     RowBox[{
      SuperscriptBox["y", "\[Prime]",
       MultilineFunction->None], "(", "0", ")"}], " ", "x"}], "-", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "2"], " ", 
       RowBox[{"y", "(", "0", ")"}]}], ")"}], " ", 
     SuperscriptBox["x", "2"]}], "-", 
    RowBox[{
     FractionBox["1", "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "2"], " ", 
       RowBox[{
        SuperscriptBox["y", "\[Prime]",
         MultilineFunction->None], "(", "0", ")"}]}], ")"}], " ", 
     SuperscriptBox["x", "3"]}], "+", 
    RowBox[{
     FractionBox["1", "24"], " ", 
     SuperscriptBox["k", "4"], " ", 
     RowBox[{"y", "(", "0", ")"}], " ", 
     SuperscriptBox["x", "4"]}], "+", 
    RowBox[{
     FractionBox["1", "120"], " ", 
     SuperscriptBox["k", "4"], " ", 
     RowBox[{
      SuperscriptBox["y", "\[Prime]",
       MultilineFunction->None], "(", "0", ")"}], " ", 
     SuperscriptBox["x", "5"]}], "-", 
    RowBox[{
     FractionBox["1", "720"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "6"], " ", 
       RowBox[{"y", "(", "0", ")"}]}], ")"}], " ", 
     SuperscriptBox["x", "6"]}], "+", 
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox["x", "7"], ")"}],
     SeriesData[x, 0, {}, 0, 7, 1]]}],
   SeriesData[x, 0, {
     y[0], 
     Derivative[1][y][0], Rational[-1, 2] k^2 y[0], Rational[-1, 6] k^2 
     Derivative[1][y][0], Rational[1, 24] k^4 y[0], Rational[1, 120] k^4 
     Derivative[1][y][0], Rational[-1, 720] k^6 y[0]}, 0, 7, 1]], 
  TraditionalForm]], "Output"]
}, Closed]],

Cell[TextData[{
 "If you now supply the initial conditions \[LongDash] say ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"y", "(", "0", ")"}], "=", "1"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["y", "\[Prime]",
      MultilineFunction->None], "(", "0", ")"}], "=", "0"}], 
   TraditionalForm]]],
 " \[LongDash] you get "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"%", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"y", "(", "0", ")"}], "\[Rule]", "1"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["y", "\[Prime]",
        MultilineFunction->None], "(", "0", ")"}], "\[Rule]", "0"}]}], 
    "}"}]}], TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{"1", "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      SuperscriptBox["x", "2"]}], "2"], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["k", "4"], " ", 
      SuperscriptBox["x", "4"]}], "24"], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["k", "6"], " ", 
      SuperscriptBox["x", "6"]}], "720"], "+", 
    InterpretationBox[
     RowBox[{"O", "(", 
      SuperscriptBox["x", "7"], ")"}],
     SeriesData[x, 0, {}, 0, 7, 1]]}],
   SeriesData[
   x, 0, {1, 0, Rational[-1, 2] k^2, 0, Rational[1, 24] k^4, 0, 
     Rational[-1, 720] k^6}, 0, 7, 1]], TraditionalForm]], "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Title"],
 ".",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 " Series solution for the undamped pendulum"
}], "Subsection"],

Cell["We would like to analytically solve the equation", "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
      MultilineFunction->None], "(", "t", ")"}], "+", 
    RowBox[{
     SuperscriptBox["\[Omega]", "2"], " ", 
     RowBox[{"sin", "(", 
      RowBox[{"\[Theta]", "(", "t", ")"}], ")"}]}]}], "=", "0."}], 
  TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
 
 CounterBox["Exercise"],
 ". Obtain the series solution to equation (",
 
 CounterBox["Title"],
 ".",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Equation"],
 ") up to tenth order using the method of \[Section]",
 
 CounterBox["Title"],
 ".",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection", "series solution"],
 " for the initial conditions, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Theta]", "(", "0", ")"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Theta]", "\[Prime]",
        MultilineFunction->None], "(", "0", ")"}], "\[Rule]", 
      SubscriptBox["\[Omega]", "0"]}]}], "}"}], TraditionalForm]]],
 ". (",
 StyleBox["Hint",
  FontSlant->"Italic"],
 ": it is a good idea to find the series solution to lower order first to \
check that you are doing the right thing.) ",
 StyleBox["[5 Marks]", "MarkersComment"],
 " "
}], "BeginEndQuestion"],

Cell[TextData[{
 "The ",
 StyleBox["linearized equation",
  FontSlant->"Italic"],
 " results by replacing ",
 Cell[BoxData[
  FormBox[
   RowBox[{"sin", "(", "\[Theta]", ")"}], TraditionalForm]]],
 " by ",
 Cell[BoxData[
  FormBox["\[Theta]", TraditionalForm]]],
 ". "
}], "Text",
 CellTags->"linearized equation"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
      MultilineFunction->None], "(", "t", ")"}], "+", 
    RowBox[{
     SuperscriptBox["\[Omega]", "2"], " ", 
     RowBox[{"\[Theta]", "(", "t", ")"}]}]}], "=", "0."}], 
  TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
 
 CounterBox["Exercise"],
 ". Solve the linearized ",
 "equation",
 " (",
 
 CounterBox["Title"],
 ".",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Equation"],
 ") taking into account the initial conditions. To what order do these \
solutions agree? (",
 StyleBox["Hint",
  FontSlant->"Italic"],
 ": you can take the difference between the series solution and the exact \
solution to the linearized equation and simplify.)",
 " What does the difference say about the behaviour over a long period of \
time?",
 " ",
 StyleBox["[6 Marks]", "MarkersComment"],
 " "
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Title"],
 ".",
 
 CounterBox["Section"],
 " ",
 "Iterative Operations"
}], "Section"],

Cell["\<\
This section presents four examples of visualizing iterative operations.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Title"],
 ".",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 " Julia set"
}], "Subsection"],

Cell[TextData[{
 "The ",
 StyleBox["Julia set",
  FontSlant->"Italic"],
 " associated to a fixed complex number ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]]],
 " is found by iterating the map ",
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "\[RightTeeArrow]", 
    RowBox[{
     SuperscriptBox["z", "2"], "+", "c"}]}], TraditionalForm]]],
 ". The set of points, ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]]],
 ", that do not escape to infinity (",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", their absolute value remains bounded, say ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[LeftBracketingBar]", "z", "\[RightBracketingBar]"}], "<", 
    "2"}], TraditionalForm]]],
 ", after ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]]],
 " iterations have been carried out) is the Julia set. "
}], "Text",
 CellTags->{"Iterated mapping", "Bounded absolute value"}],

Cell[TextData[{
 
 CounterBox["Exercise"],
 ". Enter the function ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "[", "z_", "]"}], ":=", 
    RowBox[{
     SuperscriptBox["z", "2"], "+", 
     RowBox[{"0.5", "\[ImaginaryI]"}]}]}], TraditionalForm]]],
 ", ",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", starting at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", " ", "=", " ", 
    RowBox[{"0.5", " ", "\[ImaginaryI]"}]}], TraditionalForm]]],
 ". ",
 StyleBox["Using ",
  FontSlant->"Plain"],
 StyleBox["NestList", "InlineInputTraditionalForm",
  FontSlant->"Plain"],
 StyleBox[", iterate ",
  FontSlant->"Plain"],
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 StyleBox[" ten times, starting at ",
  FontSlant->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", " ", "=", " ", "0.1"}], TraditionalForm]]],
 ". Compute the absolute value of these complex numbers. Are they remaining \
bounded? ",
 StyleBox["Try ",
  FontSlant->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", " ", "=", " ", "0.5"}], TraditionalForm]]],
 StyleBox[" and ",
  FontSlant->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", " ", "=", " ", "1"}], TraditionalForm]]],
 StyleBox[" and comment.",
  FontSlant->"Plain"],
 " ",
 StyleBox["[5 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
 "The following ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " procedural code (",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", similar in style to Fortran, C, Pascal, Basic,\[Ellipsis]) iterates ",
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", 
    RowBox[{
     SuperscriptBox["z", "2"], "+", "c"}]}], TraditionalForm]]],
 " for a particular value of ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]]],
 ".  Either the value of ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]]],
 " escapes to \[Infinity] which can be tested using ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[LeftBracketingBar]", "z", "\[RightBracketingBar]"}], "<", 
    "2.0"}], TraditionalForm]]],
 " or it hops around a finite number of times, bounded above by ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]]],
 "."
}], "Text",
 CellTags->"Module"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"JuliaModule", "(", 
     RowBox[{"w_", ",", "c_", ",", "m_"}], ")"}], ":=", 
    RowBox[{"Module", "(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"z", "=", "w"}], ",", 
        RowBox[{"n", "=", "0"}]}], "}"}], ",", 
      RowBox[{
       RowBox[{"While", "(", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"\[LeftBracketingBar]", "z", "\[RightBracketingBar]"}], 
           "<", "2"}], "\[And]", 
          RowBox[{"n", "<", "m"}]}], ",", 
         RowBox[{
          RowBox[{"z", "=", 
           RowBox[{
            SuperscriptBox["z", "2"], "+", "c"}]}], ";", 
          RowBox[{"++", "n"}]}]}], ")"}], ";", "n"}]}], ")"}]}], ";"}], 
  TraditionalForm]], "Input"],

Cell[TextData[{
 "Alternatively, we can implement this as a pure function (using ",
 StyleBox["Function", "InlineInputTraditionalForm"],
 ") with ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"{", 
     RowBox[{"w", ",", "c", ",", "m"}], "}"}], "InlineInputTraditionalForm"], 
   TraditionalForm]]],
 " as ",
 StyleBox["dummy arguments",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellTags->{"pure function", "Function"}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"JuliaFunction", "=", 
    RowBox[{"Function", "(", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"w", ",", "c", ",", "m"}], "}"}], ",", 
      RowBox[{"Module", "(", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"z", "=", "w"}], ",", 
          RowBox[{"n", "=", "0"}]}], "}"}], ",", 
        RowBox[{
         RowBox[{"While", "(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"\[LeftBracketingBar]", "z", "\[RightBracketingBar]"}], 
             "<", "2"}], "\[And]", 
            RowBox[{"n", "<", "m"}]}], ",", 
           RowBox[{
            RowBox[{"z", "=", 
             RowBox[{
              SuperscriptBox["z", "2"], "+", "c"}]}], ";", 
            RowBox[{"++", "n"}]}]}], ")"}], ";", "n"}]}], ")"}]}], ")"}]}], 
   ";"}], TraditionalForm]], "Input"],

Cell["\<\
A table of values using either implementation is somewhat slow:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"JuliaModule", "(", 
        RowBox[{
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ",", 
         RowBox[{"1", "+", 
          RowBox[{"0.3", " ", "\[ImaginaryI]"}]}], ",", "35"}], ")"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1.5"}], ",", "1.5", ",", "0.1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "1.5"}], ",", "1.5", ",", "0.1"}], "}"}]}], "]"}], 
     ";"}], "//", "Timing"}], "//", "First"}], TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"0.41666666666606034`", " ", "Second"}], TraditionalForm]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"JuliaFunction", "(", 
        RowBox[{
         RowBox[{"x", "+", 
          RowBox[{"\[ImaginaryI]", " ", "y"}]}], ",", 
         RowBox[{"1", "+", 
          RowBox[{"0.3", " ", "\[ImaginaryI]"}]}], ",", "35"}], ")"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1.5"}], ",", "1.5", ",", "0.1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "1.5"}], ",", "1.5", ",", "0.1"}], "}"}]}], "]"}], 
     ";"}], "//", "Timing"}], "//", "First"}], TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"0.43333333333339397`", " ", "Second"}], TraditionalForm]], "Output"]
}, Closed]],

Cell[TextData[{
 "Numerical function compilation, using ",
 StyleBox["Compile", "InlineInputTraditionalForm"],
 ", is a useful way of speeding up a computation. The following code expects \
three arguments: the point ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]]],
 ", the point ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]]],
 ", and the maximum number of iterations."
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"JuliaCompile", "=", 
    RowBox[{"Compile", "[", 
     RowBox[{
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"w", "_Complex"},
         {"c", "_Complex"},
         {"m", "_Integer"}
        }], "\[NoBreak]", ")"}], ",", 
      RowBox[{"Module", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"z", "=", "w"}], ",", 
          RowBox[{"n", "=", "0"}]}], "}"}], ",", 
        RowBox[{
         RowBox[{"While", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"\[LeftBracketingBar]", "z", "\[RightBracketingBar]"}], 
             "<", "2"}], "\[And]", 
            RowBox[{"n", "<", "m"}]}], ",", 
           RowBox[{
            RowBox[{"z", "=", 
             RowBox[{
              SuperscriptBox["z", "2"], "+", "c"}]}], ";", 
            RowBox[{"n", "++"}]}]}], "]"}], ";", "n"}]}], "]"}]}], "]"}]}], 
   ";"}], TraditionalForm]], "Input",
 AspectRatioFixed->True],

Cell[TextData[{
 
 CounterBox["Exercise"],
 ". Compare the speed of ",
 StyleBox["JuliaCompile", "InlineInputTraditionalForm"],
 " and ",
 StyleBox["JuliaFunction", "InlineInputTraditionalForm"],
 ". ",
 StyleBox["[1 Mark]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
 "I don't expect you to get into the details of ",
 StyleBox["Compile", "InlineInputTraditionalForm"],
 " \[LongDash] just know that it can make code faster. For numerical \
functions, it is often advantageous writing them using ",
 Cell[BoxData[
  FormBox[
   StyleBox["Function", "Input"], TraditionalForm]]],
 " because it is straightforward to \"compile\" a function: usually it is \
only a matter of replacing ",
 Cell[BoxData[
  FormBox[
   StyleBox["Function", "Input"], TraditionalForm]]],
 " with ",
 Cell[BoxData[
  FormBox[
   StyleBox["Compile", "Input"], TraditionalForm]]],
 " and \"typing\" the arguments. "
}], "Warning",
 CellTags->{
  "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
   "Compile", "argument typing"}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   StyleBox["Compile", "Input"], TraditionalForm]]],
 " assumes its arguments should be compiled as ",
 ButtonBox["machine-precision",
  BaseStyle->"MainBookLink",
  ButtonData:>{"3.1.6"}],
 " real numbers unless it is directed to do otherwise by variable \
declarations such as ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"{", 
     RowBox[{"w", ",", "_Complex"}], "}"}], "Input"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"{", 
     RowBox[{"m", ",", "_Integer"}], "}"}], "Input"], TraditionalForm]]],
 "."
}], "Warning",
 CellTags->{
  "Compile", "machine-precision numbers", "variable declarations", "_Complex",
    "_Integer"}],

Cell[TextData[{
 "The first argument of ",
 Cell[BoxData[
  FormBox[
   StyleBox["Compile", "Input"], TraditionalForm]]],
 " is a list of lists (",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", a rank-2 tensor or matrix) and is typeset in ",
 Cell[BoxData[
  FormBox[
   StyleBox["TraditionalForm", "Input"], TraditionalForm]]],
 " as a matrix. You can either enter it as an ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "\[Times]", "2"}], TraditionalForm]]],
 " matrix:"
}], "Warning"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", GridBox[{
     {"w", "_Complex"},
     {"c", "_Complex"},
     {"m", "_Integer"}
    }], ")"}], TraditionalForm]], "Input"],

Cell["or as a list of lists:", "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"w", ",", "_Complex"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"c", ",", "_Complex"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"m", ",", "_Integer"}], "}"}]}], "}"}], 
  TraditionalForm]], "Input"],

Cell[TextData[{
 "The variable types appearing in the ",
 Cell[BoxData[
  FormBox[
   StyleBox["Module", "Input"], TraditionalForm]]],
 " part of ",
 Cell[BoxData[
  FormBox[
   StyleBox["JuliaCompile", "Input"], TraditionalForm]]],
 " are guessed based on the first time they are set. Since the local variable \
",
 Cell[BoxData[
  FormBox[
   StyleBox["z", "Input"], TraditionalForm]]],
 " is first initialized to ",
 Cell[BoxData[
  FormBox[
   StyleBox["w", "Input"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   StyleBox["Compile", "Input"], TraditionalForm]]],
 " knows it is a complex variable. Similarly, the statement ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"n", "=", "0"}], "Input"], TraditionalForm]]],
 " indicates to ",
 Cell[BoxData[
  FormBox[
   StyleBox["Compile", "Input"], TraditionalForm]]],
 " that ",
 StyleBox["n", "InlineInputTraditionalForm",
  FontSlant->"Italic"],
 " is an integer. "
}], "Warning",
 CellTags->{"Guessing variable types", "local variable", "JuliaCompile"}],

Cell[TextData[{
 
 CounterBox["Exercise"],
 ". ",
 StyleBox["Use ",
  FontSlant->"Plain"],
 StyleBox["DensityPlot", "InlineInputTraditionalForm"],
 StyleBox[" to visualize the Julia set over ",
  FontSlant->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"[", 
     RowBox[{
      RowBox[{"-", "1.5"}], ",", " ", "1.5"}], "]"}], " ", "\[Times]", " ", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"-", "1.3"}], ",", " ", "1.3"}], "]"}]}], TraditionalForm]]],
 StyleBox[" in the complex plane for ",
  FontSlant->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{"c", " ", "=", " ", "\[ImaginaryI]"}], TraditionalForm]]],
 ". ",
 StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
 "Algorithms for computing fractal sets often involve iterating a formula \
until a specified condition is met. By default, ",
 StyleBox["FixedPoint", "InlineInputTraditionalForm"],
 " and ",
 StyleBox["FixedPointList", "InlineInputTraditionalForm"],
 " stop iterating when two successive calculations give the same result. To \
specify our own stopping condition, we can use the ",
 StyleBox["SameTest", "InlineInputTraditionalForm"],
 " option. This option takes a pure function of two arguments that returns ",
 StyleBox["True", "InlineInputTraditionalForm"],
 " if the two arguments can be considered \[OpenCurlyDoubleQuote]the same\
\[CloseCurlyDoubleQuote]. For example, here we iterate the square root \
function, applied to 10, and stop when two successive values are within 0.1 \
of each other."
}], "Text",
 CellTags->{
  "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
   "SameTest", "pure function", "True"}],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"FixedPoint", "(", 
   RowBox[{"Sqrt", ",", "10.0", ",", 
    RowBox[{"SameTest", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"\[LeftBracketingBar]", 
         RowBox[{"#1", "-", "#2"}], "\[RightBracketingBar]"}], "<", "0.1"}], 
       "&"}], ")"}]}]}], ")"}], TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox["1.0746078283213176`", TraditionalForm]], "Output"]
}, Closed]],

Cell[TextData[{
 
 CounterBox["Exercise"],
 ". ",
 StyleBox["Find a ",
  FontSlant->"Plain"],
 StyleBox["FixedPoint", "InlineInputTraditionalForm"],
 " of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"cos", "(", "x", ")"}], TraditionalForm]]],
 ", stopping when two successive values are within ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"-", "5"}]], TraditionalForm]]],
 " of each other. ",
 StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
 "Here is an elegant alternative implementation of ",
 StyleBox["JuliaCompile", "InlineInputTraditionalForm"],
 " using a ",
 StyleBox["fixed",
  FontSlant->"Italic"],
 " number of iterations (here 35)."
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"JuliaCompile", "=", 
    RowBox[{"Compile", "(", 
     RowBox[{
      RowBox[{"(", GridBox[{
         {"z", "_Complex"},
         {"c", "_Complex"}
        }], ")"}], ",", 
      RowBox[{"Length", "(", 
       RowBox[{"FixedPointList", "(", 
        RowBox[{
         RowBox[{
          RowBox[{
           SuperscriptBox["#", "2"], "+", "c"}], "&"}], ",", "z", ",", "35", 
         ",", 
         RowBox[{"SameTest", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"\[LeftBracketingBar]", "#2", "\[RightBracketingBar]"}], 
             ">", "2.0"}], "&"}], ")"}]}]}], ")"}], ")"}]}], ")"}]}], ";"}], 
  TraditionalForm]], "Input"],

Cell[TextData[{
 "Using ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"SameTest", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"\[LeftBracketingBar]", "#2", "\[RightBracketingBar]"}], ">", 
        "2.0"}], "&"}], ")"}]}], "Input"], TraditionalForm]]],
 " ",
 "tests whether the last value (",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", ",
 StyleBox["#2", "InlineInputTraditionalForm"],
 ") generated by ",
 StyleBox["FixedPointList", "InlineInputTraditionalForm"],
 " remains bounded (",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", \[LeftBracketingBar]z\[RightBracketingBar]<2). The length of the result \
of ",
 StyleBox["FixedPointList", "InlineInputTraditionalForm"],
 " is the number of iterations."
}], "Text"],

Cell[TextData[{
 
 CounterBox["Exercise"],
 ". Plot the Julia set associated with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "=", 
    RowBox[{"0.27334", "+", 
     RowBox[{"0.00742", " ", "\[ImaginaryI]"}]}]}], TraditionalForm]]],
 " ",
 StyleBox["over ",
  FontSlant->"Plain"],
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "\[Element]", 
    RowBox[{
     RowBox[{"[", 
      RowBox[{
       RowBox[{"-", "1.2"}], ",", " ", "1.2"}], "]"}], " ", "\[Times]", " ", 
     RowBox[{"[", 
      RowBox[{
       RowBox[{"-", "1.2"}], ",", " ", "1.2"}], "]"}]}]}], 
   TraditionalForm]]],
 StyleBox[".",
  FontSlant->"Plain"],
 " ",
 StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion",
 CellTags->"Julia set"],

Cell[TextData[{
 
 CounterBox["Exercise"],
 ". Interact with the plot of exercise ",
 
 CounterBox["Exercise", "Julia set"],
 " to find a point that is in the Julia set, ",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", click on the graphic, hold down the Apple key (",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", \[CloverLeaf]) on a Macintosh or the Control key (",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", \[ControlKey]) under Windows, and move the mouse around.  The \
mouse-coordinates will appear in the status box (bottom left corner of the \
Notebook).  Click at an appropriate point and copy the coordinate value(s) \
using Copy (\[CloverLeaf]-C or \[ControlKey]-V). Paste this value into the \
Notebook (in a new cell) and check that it is in the Julia set by applying ",
 StyleBox["JuliaComplie", "InlineInputTraditionalForm"],
 " to it. (Note that ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"Complex", " ", "@@", " ", 
     RowBox[{"{", 
      RowBox[{"a", ",", " ", "b"}], "}"}]}], "Input"], TraditionalForm]]],
 " yields the complex number ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"Complex", "[", 
     RowBox[{"a", ",", " ", "b"}], "]"}], "Input"], TraditionalForm]]],
 "). ",
 StyleBox["[2 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell[TextData[{
 "For fun, run the following code to produce an array of plots with ",
 Cell[BoxData[
  FormBox[
   RowBox[{"z", " ", "\[Element]", " ", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "1.1"}], "-", 
       RowBox[{"1.1", "\[ImaginaryI]"}]}], ",", 
      RowBox[{"1.1", "+", 
       RowBox[{"1.1", "\[ImaginaryI]"}]}]}], "]"}]}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "=", 
    RowBox[{
     RowBox[{"a", "+", 
      RowBox[{"b", " ", "\[ImaginaryI]"}]}], " ", 
     SubscriptBox["\[Element]", " "], 
     RowBox[{"[", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], "-", "\[ImaginaryI]"}], ",", 
       RowBox[{"1", "+", "\[ImaginaryI]"}]}], "]"}]}]}], TraditionalForm]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"GraphicsGrid", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"DensityPlot", "[", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"JuliaCompile", "[", 
         RowBox[{
          RowBox[{"x", "+", 
           RowBox[{"\[ImaginaryI]", " ", "y"}]}], ",", 
          RowBox[{"a", "+", 
           RowBox[{"b", " ", "\[ImaginaryI]"}]}]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"-", "1.1`"}], ",", "1.1`"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", 
         RowBox[{"-", "1.1`"}], ",", "1.1`"}], "}"}], ",", 
       RowBox[{"Frame", "\[Rule]", "False"}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}], ",", 
       RowBox[{"PlotPoints", "\[Rule]", "20"}], ",", 
       RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", 
       RowBox[{"-", "1"}], ",", "1", ",", 
       FractionBox["1", "3"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", 
       RowBox[{"-", "2"}], ",", "1", ",", 
       FractionBox["1", "3"]}], "}"}]}], "]"}], "]"}], "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Title"],
 ".",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 " The Mandelbrot set"
}], "Subsection"],

Cell[TextData[{
 "For each ",
 Cell[BoxData[
  FormBox["c", TraditionalForm]]],
 " in the complex plane, those points that remain bounded upon iterating the \
map ",
 Cell[BoxData[
  FormBox[
   RowBox[{"c", "\[RightTeeArrow]", 
    RowBox[{
     SuperscriptBox["c", "2"], "+", "c"}]}], TraditionalForm]]],
 " generate the ",
 StyleBox["Mandelbrot set",
  FontSlant->"Italic"],
 ". It turns out that points in the Mandelbrot set have connected Julia sets. \
"
}], "Text",
 CellTags->{"Iterated mapping", "connected Julia sets", "Mandelbrot set"}],

Cell[TextData[{
 
 CounterBox["Exercise"],
 ". Modify the Julia code to compute and visualize the Mandlebrot set. ",
 StyleBox["[6 Marks]", "MarkersComment"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Title"],
 ".",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 " Newton's Method"
}], "Subsection"],

Cell[TextData[{
 "Consider using Newton's method to compute the (complex) argument of the ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 "-th roots of unity, ",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", the roots of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", "z", ")"}], "=", 
    RowBox[{
     SuperscriptBox["z", "n"], "-", "1"}]}], TraditionalForm]]],
 ". The Newton iteration, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "\[Rule]", 
    RowBox[{"z", "-", 
     FractionBox[
      RowBox[{"f", "(", "z", ")"}], 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "(", "z", ")"}]]}]}], TraditionalForm]]],
 ", becomes"
}], "Text",
 CellTags->{
  "complex argument", "n-th roots of unity", "Newton iteration", 
   "Newton's method"}],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"z", "-", 
     FractionBox[
      RowBox[{"f", "(", "z", ")"}], 
      RowBox[{
       SuperscriptBox["f", "\[Prime]",
        MultilineFunction->None], "(", "z", ")"}]]}], "/.", 
    RowBox[{"f", "\[Rule]", 
     RowBox[{"Function", "(", 
      RowBox[{"z", ",", 
       RowBox[{
        SuperscriptBox["z", "n"], "-", "1"}]}], ")"}]}]}], "//", "Simplify"}],
   TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{"z", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["z", 
       RowBox[{"-", "n"}]], "+", "n", "-", "1"}], ")"}]}], "n"], 
  TraditionalForm]], "Output"]
}, Closed]],

Cell[TextData[{
 "To evaluate both ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"f", "(", "z", ")"}], "Input"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     SuperscriptBox["f", "\[Prime]",
      MultilineFunction->None], 
     RowBox[{"(", "z", ")"}]}], "Input"], TraditionalForm]]],
 " we use a pure function replacement rule for ",
 Cell[BoxData[
  FormBox[
   StyleBox["f", "Input"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"f", "\[Rule]", 
     RowBox[{"Function", "(", 
      RowBox[{"z", ",", 
       RowBox[{
        SuperscriptBox["z", "n"], "-", "1"}]}], ")"}]}], "Input"], 
   TraditionalForm]]],
 "."
}], "BrightIdea",
 CellTags->"pure function replacement rule"],

Cell["The compiled function", "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"NewtonIteration", "=", 
    RowBox[{"Compile", "(", 
     RowBox[{
      RowBox[{"(", GridBox[{
         {"n", "_Integer"},
         {"c", "_Complex"}
        }], ")"}], ",", 
      RowBox[{"Arg", "(", 
       RowBox[{"FixedPoint", "(", 
        RowBox[{
         RowBox[{"Function", "(", 
          RowBox[{"z", ",", 
           FractionBox[
            RowBox[{"z", " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["z", 
                RowBox[{"-", "n"}]], "+", "n", "-", "1"}], ")"}]}], "n"]}], 
          ")"}], ",", "c", ",", "35"}], ")"}], ")"}]}], ")"}]}], ";"}], 
  TraditionalForm]], "Input"],

Cell[TextData[{
 "can be used to show the convergence of points in the complex plane for \
specific ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 ". "
}], "Text",
 CellTags->"attracting root"],

Cell[TextData[{
 
 CounterBox["Exercise"],
 ". For ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "4"}], TraditionalForm]]],
 ", visualize to which \[OpenCurlyDoubleQuote]attracting\
\[CloseCurlyDoubleQuote] root (out of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[PlusMinus]", "1"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"\[PlusMinus]", "\[ImaginaryI]"}], "Input"], TraditionalForm]]],
 ") the Newton iteration converges. Note that the color of each point is \
determined by the ",
 Cell[BoxData[
  FormBox[
   StyleBox["Arg", "Input"], TraditionalForm]]],
 " of the attracting root ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"Arg", "(", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"+", "1"}], ",", 
       RowBox[{"-", "1"}], ",", 
       RowBox[{"+", "\[ImaginaryI]"}], ",", 
       RowBox[{"-", "\[ImaginaryI]"}]}], "}"}], ")"}], 
    "InlineInputTraditionalForm"], TraditionalForm]]],
 ". Interpret the result. ",
 StyleBox["[4 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
 "For fun, run the following code to produce an array of graphics (generated \
using ",
 Cell[BoxData[
  FormBox[
   StyleBox["GraphicsArray", "Input"], TraditionalForm]]],
 ") that show the convergence of points in the complex plane, for ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " ranging from 5 to 13."
}], "Text"],

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"GraphicsGrid", "[", 
   RowBox[{
    RowBox[{"Partition", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"DensityPlot", "[", 
         RowBox[{
          RowBox[{"NewtonIteration", "[", 
           RowBox[{"n", ",", 
            RowBox[{"x", "+", 
             RowBox[{"\[ImaginaryI]", " ", "y"}]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "1.1`", ",", 
            RowBox[{"-", "1.1`"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"y", ",", 
            RowBox[{"-", "1.1`"}], ",", "1.1`"}], "}"}], ",", 
          RowBox[{"PlotPoints", "\[Rule]", "30"}], ",", 
          RowBox[{"Compiled", "\[Rule]", "False"}], ",", 
          RowBox[{"Frame", "\[Rule]", "False"}], ",", 
          RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "5", ",", "13"}], "}"}]}], "]"}], ",", "3"}], 
     "]"}], ",", 
    RowBox[{"Spacings", "\[Rule]", 
     RowBox[{"Scaled", "[", "0.05`", "]"}]}]}], "]"}], "]"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Title"],
 ".",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Subsection"],
 " Feigenbaum Bifurcation Diagram"
}], "Subsection"],

Cell[TextData[{
 "The ",
 StyleBox["Feigenbaum bifurcation diagram",
  FontSlant->"Italic"],
 " shows the behavior of iterates of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "\[RightTeeArrow]", 
    RowBox[{"\[Lambda]", " ", "x", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", "x"}], ")"}]}]}], TraditionalForm]]],
 " and displays the ",
 StyleBox["period-doubling route to chaos",
  FontSlant->"Italic"],
 ". The following code iterates this mapping 300 times using ",
 Cell[BoxData[
  FormBox[
   StyleBox["NestList", "Input"], TraditionalForm]]],
 " and then deletes the first 100 iterations (during which time the iteration \
\[OpenCurlyDoubleQuote]settles down\[CloseCurlyDoubleQuote])."
}], "Text",
 CellTags->{
  "NestList", "period-doubling route to chaos", 
   "Feigenbaum bifurcation diagram"}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Feigenbaum", "=", 
    RowBox[{"Compile", "[", 
     RowBox[{
      RowBox[{"(", "\[NoBreak]", GridBox[{
         {"\[Lambda]", "_Real"}
        }], "\[NoBreak]", ")"}], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"\[Lambda]", ",", "#"}], "}"}], "&"}], ")"}], "/@", 
       RowBox[{"Drop", "[", 
        RowBox[{
         RowBox[{"NestList", "[", 
          RowBox[{
           RowBox[{"Function", "[", 
            RowBox[{"x", ",", 
             RowBox[{"\[Lambda]", " ", "x", " ", 
              RowBox[{"(", 
               RowBox[{"1", "-", "x"}], ")"}]}]}], "]"}], ",", "0.2", ",", 
           "300"}], "]"}], ",", "100"}], "]"}]}]}], "]"}]}], ";"}], 
  TraditionalForm]], "Input",
 CellTags->"Feigenbaum"],

Cell[TextData[{
 
 CounterBox["Exercise"],
 ". ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     RowBox[{"\[Lambda]values", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Feigenbaum", "[", "\[Lambda]", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Lambda]", ",", "1.0", ",", "4.0", ",", "0.005"}], 
           "}"}]}], "]"}], ",", "1"}], "]"}]}], ";"}],
    FontWeight->"Bold"], TraditionalForm]]],
 " generates a table of iterated values for ",
 Cell[BoxData[
  FormBox[
   StyleBox["\[Lambda]", "InlineInputTraditionalForm"], TraditionalForm]]],
 " ranging from 1 to 4 in steps of 0.005.  Visualize ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"Union", "[", "\[Lambda]values", "]"}], "Input"], 
   TraditionalForm]]],
 " using ",
 StyleBox["ListPlot", "InlineInputTraditionalForm"],
 ". (",
 StyleBox["Union", "InlineInputTraditionalForm"],
 " eliminates duplicates.) Where does period-doubling commence? ",
 StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
 
 CounterBox["Exercise"],
 ". Use ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     RowBox[{"Fvalues", "=", 
      RowBox[{"Last", "/@", "\[Lambda]values"}]}], ";"}], 
    "InlineInputTraditionalForm"], TraditionalForm]]],
 " to obtain a list of ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"Feigenbaum", "[", "\[Lambda]", "]"}], 
    "InlineInputTraditionalForm"], TraditionalForm]]],
 " values. Listen to ",
 StyleBox["Fvalues", "InlineInputTraditionalForm"],
 " using ",
 StyleBox["ListPlay", "InlineInputTraditionalForm"],
 ". Describe what you hear. ",
 StyleBox["[3 Marks]", "MarkersComment"]
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]]
}, Closed]]
}, Open  ]]
},
AutoGeneratedPackage->None,
WindowToolbars->{"RulerBar", "EditBar"},
CellGrouping->Automatic,
WindowSize->{923, 828},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.25,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (April 9, 2007)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell[
      "Style Definitions for \nComputational Physics", "Subtitle", 
       CellMargins -> {{0, Inherited}, {Inherited, 0}}, 
       CellFrameMargins -> {{20, 4}, {8, 20}}, FontSize -> 36, FontWeight -> 
       "Bold", FontColor -> GrayLevel[1], Background -> GrayLevel[0]], 
      Cell[
       CellGroupData[{
         Cell[
         "Style Environment Names", "Section", CellFrame -> False, 
          CellDingbat -> None, ShowCellBracket -> True, 
          CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
          StyleData[All, "Working"], ScreenStyleEnvironment -> "Working", 
          PrintingStyleEnvironment -> "Printout", 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.115343, 0.350561, 0.362966]}, ShowCellLabel -> 
          True, CellFrameLabelMargins -> 6, ScriptMinSize -> 9], 
         Cell[
          StyleData[All, "Presentation"], ScreenStyleEnvironment -> 
          "Presentation", PrintingStyleEnvironment -> "Printout", 
          CellFrameMargins -> {{30, 4}, {8, 8}}, Magnification -> 1.25], 
         Cell[
          StyleData[All, "Printout"], ScreenStyleEnvironment -> "Printout", 
          PrintingStyleEnvironment -> "Printout", PageWidth -> PaperWidth, 
          PrintingOptions -> {
           "FacingPages" -> True, "FirstPageHeader" -> False, 
            "PrintRegistrationMarks" -> False, 
            "PrintingMargins" -> {{24, 74}, {72, 72}}}, ShowCellBracket -> 
          False], 
         Cell[
          StyleData[All, "Production"], ScreenStyleEnvironment -> 
          "Production", PrintingStyleEnvironment -> "Production", PageWidth -> 
          PaperWidth, 
          PrintingOptions -> {
           "FacingPages" -> True, "FirstPageHeader" -> False, 
            "PageSize" -> {486, 711}, "PrintRegistrationMarks" -> True, 
            "PrintingMargins" -> {{0, 0}, {82, 56}}}, 
          CellLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          ScriptMinSize -> 5]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Notebook Options", "Section", CellFrame -> False, CellDingbat -> 
          None, ShowCellBracket -> True, CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
         "The options defined for the style below will be used at the \
Notebook level.", "Text"], 
         Cell[
          StyleData["Notebook"], PageHeaders -> {{
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"], Inherited, 
             Cell["Paul Abbott", "Header"]}, {
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"], Inherited, 
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"]}}, PageFooters -> {{
             Cell[
              TextData[{"Computational Physics ", 
                CounterBox["Page"]}], "Footer"], Inherited, Inherited}, {
             Cell[
              TextData[{"Computational Physics ", 
                CounterBox["Page"]}], "Footer"], Inherited, Inherited}}, 
          CellFrameLabelMargins -> 6, 
          CommonDefaultFormatTypes -> {
           "Input" -> TraditionalForm, "Output" -> TraditionalForm}, 
          HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
          StyleMenuListing -> None]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Styles for Headings", "Section", CellFrame -> False, CellDingbat -> 
          None, ShowCellBracket -> True, CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
         "Each notebook should contain at least one title cell. Title resets \
all cell CounterBox values to zero (except Title).", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], ShowCellBracket -> False, 
             CellMargins -> {{0, 25}, {Inherited, 0}}, 
             CellGroupingRules -> {"TitleGrouping", 0}, PageBreakBelow -> 
             False, CellFrameMargins -> {{55, 4}, {8, 20}}, 
             LineSpacing -> {1.125, 0}, CounterIncrements -> "Title", 
             CounterAssignments -> {{"Subtitle", 0}, {"Section", 0}, {
               "Subsection", 0}, {"Subsubsection", 0}, {"List", 0}, {
               "NumberedFigure", 0}, {"NumberedTable", 0}, {
               "NumberedProgram", 0}, {"Equation", 0}, {"Text", 0}, {
               "SmallText", 0}, {"Reference", 0}, {"Exercise", 0}}, 
             FontFamily -> "Times", FontSize -> 36, FontSlant -> "Italic", 
             FontColor -> GrayLevel[1], Background -> 
             RGBColor[0.699931, 0.198672, 0.198672]], 
            Cell[
             StyleData["Title", "Presentation"], LineSpacing -> {0.95, 0}, 
             FontSize -> 40, FontSlant -> "Italic", Background -> 
             RGBColor[0.699931, 0.198672, 0.198672]], 
            Cell[
             StyleData["Title", "Printout"], 
             CellMargins -> {{54, 0}, {Inherited, Inherited}}, 
             CellFrameMargins -> False, LineSpacing -> {0.95, 0}, FontColor -> 
             GrayLevel[0], Background -> None], 
            Cell[
             StyleData["Title", "Production"], 
             CellMargins -> {{72, 72}, {14, 0}}, CellFrameMargins -> False, 
             FontFamily -> "Janson Text", 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}, FontColor -> 
             GrayLevel[0], Background -> None]}, Closed]], 
         Cell[
         "Subtitle is an optional cell. Used for Tech Support column, \
Subtitle states topics in current issue.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], CellMargins -> {{54, 25}, {0, 10}}, 
             CellGroupingRules -> {"TitleGrouping", 10}, PageBreakBelow -> 
             False, LineSpacing -> {1, 0}, CounterIncrements -> "Subtitle", 
             FontFamily -> "Times", FontSize -> 24, FontSlant -> "Italic"], 
            Cell[
             StyleData["Subtitle", "Presentation"]], 
            Cell[
             StyleData["Subtitle", "Printout"], 
             CellMargins -> {{54, 0}, {10, 10}}, FontSize -> 12], 
            Cell[
             StyleData["Subtitle", "Production"], 
             CellMargins -> {{72, 72}, {12, 2}}, FontFamily -> "Janson Text", 
             FontSize -> 12, FontSlant -> "Italic", 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], CellMargins -> {{54, 25}, {0, 10}}, 
             CellGroupingRules -> {"TitleGrouping", 10}, PageBreakBelow -> 
             False, LineSpacing -> {1, 0}, CounterIncrements -> "Subtitle", 
             FontFamily -> "Times", FontSize -> 18, FontSlant -> "Italic"], 
            Cell[
             StyleData["Subsubtitle", "Presentation"]], 
            Cell[
             StyleData["Subsubtitle", "Printout"], 
             CellMargins -> {{54, 0}, {Inherited, Inherited}}, FontSize -> 
             16], 
            Cell[
             StyleData["Subsubtitle", "Production"], 
             CellMargins -> {{72, 72}, {6, 2}}, FontFamily -> "Janson Text", 
             FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
         "SectionFirst should be used for the first Section level heading in \
a notebook. Sets the following counter values to zero: Subsection and \
Subsubsection. Sets Section counter value to 1.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SectionFirst"], CellFrame -> {{0, 0}, {0, 2}}, 
             CellDingbat -> "\[FilledSquare]", 
             CellMargins -> {{54, 25}, {10, 30}}, 
             CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
             False, CellFrameMargins -> 2, CellFrameColor -> 
             RGBColor[0.668009, 0.669383, 0.345068], CounterIncrements -> 
             "Section", 
             CounterAssignments -> {{"Section", 0}, {"Subsection", 0}, {
               "Subsubsection", 0}}, FontFamily -> "Helvetica", FontSize -> 
             18, FontWeight -> "Bold"], 
            Cell[
             StyleData["SectionFirst", "Presentation"], 
             CellFrame -> {{0, 0}, {0, 3}}, 
             CellFrameMargins -> {{0, 0}, {0, 4}}, CellFrameColor -> 
             RGBColor[0.668009, 0.669383, 0.345068], FontSize -> 18], 
            Cell[
             StyleData["SectionFirst", "Printout"], 
             CellFrame -> {{0, 0}, {0, 3}}, 
             CellMargins -> {{54, 24}, {15, 15}}, 
             CellFrameMargins -> {{0, 0}, {0, 5}}, CellFrameColor -> 
             GrayLevel[0], FontSize -> 14], 
            Cell[
             StyleData["SectionFirst", "Production"], CellFrame -> False, 
             CellMargins -> {{72, 72}, {2, 30}}, FontFamily -> 
             "CXB Futura CondExtraBold", FontSize -> 12, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
         "Section should be used for subsequent Section level headings. Sets \
counter values Subsection and Subsubsection to zero.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> {{0, 0}, {0, 0.5}}, 
             CellDingbat -> "\[FilledSquare]", 
             CellMargins -> {{54, 25}, {10, 30}}, 
             CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
             False, CellFrameMargins -> 2, CellFrameColor -> 
             RGBColor[0.668009, 0.669383, 0.345068], CounterIncrements -> 
             "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}}, 
             FontFamily -> "Helvetica", FontSize -> 18, FontWeight -> "Bold"],
             
            Cell[
             StyleData["Section", "Presentation"], 
             CellFrameMargins -> {{0, 0}, {0, 4}}, FontSize -> 18], 
            Cell[
             StyleData["Section", "Printout"], 
             CellMargins -> {{54, 24}, {3, 15}}, 
             CellFrameMargins -> {{0, 0}, {0, 5}}, CellFrameColor -> 
             GrayLevel[0], FontSize -> 14], 
            Cell[
             StyleData["Section", "Production"], CellFrame -> False, 
             CellMargins -> {{72, 72}, {2, 30}}, FontFamily -> 
             "CXB Futura CondExtraBold", FontSize -> 12, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
         "Subsection is an optional style. Sets counter Subsubsection to \
zero.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> "\[GraySquare]", 
             CellMargins -> {{54, 25}, {10, 26}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsection", 
             CounterAssignments -> {{"Subsubsection", 0}}, FontFamily -> 
             "Helvetica", FontSize -> 14, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsection", "Presentation"]], 
            Cell[
             StyleData["Subsection", "Printout"], 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, FontSize -> 
             12], 
            Cell[
             StyleData["Subsection", "Production"], 
             CellMargins -> {{72, 72}, {2, Inherited}}, FontFamily -> 
             "CXB Futura CondExtraBold", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
         "SubsectionNoSpace is an optional style, it is to be used if a \
subsection level heading directly follows a section level heading. Sets \
counter Subsubsection to zero.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubsectionNoSpace"], CellDingbat -> "\[GraySquare]", 
             CellMargins -> {{54, 25}, {2, 2}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsection", 
             CounterAssignments -> {{"Subsubsection", 0}}, FontFamily -> 
             "Helvetica", FontSize -> 14, FontWeight -> "Bold"], 
            Cell[
             StyleData["SubsectionNoSpace", "Presentation"]], 
            Cell[
             StyleData["SubsectionNoSpace", "Printout"], 
             CellMargins -> {{54, 24}, {2, 2}}, FontSize -> 12], 
            Cell[
             StyleData["SubsectionNoSpace", "Production"], 
             CellMargins -> {{72, 72}, {2, 2}}, FontFamily -> 
             "CXB Futura CondExtraBold", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellDingbat -> 
             "\[FilledSmallSquare]", CellMargins -> {{54, 25}, {6, 20}}, 
             CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsubsection", FontFamily -> 
             "Helvetica", FontSize -> 12, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsubsection", "Presentation"]], 
            Cell[
             StyleData["Subsubsection", "Printout"], 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, FontSize -> 
             10], 
            Cell[
             StyleData["Subsubsection", "Production"], CellDingbat -> None, 
             CellMargins -> {{72, 72}, {-4, 2}}, FontFamily -> "Futura Book", 
             FontSize -> 9, FontWeight -> "Plain", FontSlant -> "Italic", 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
         "NoDingbat versions of headings for use in print published \
frontmatter.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SectionNoDingbat"], CellFrame -> {{0, 0}, {0, 0.5}}, 
             CellDingbat -> None, CellMargins -> {{54, 25}, {10, 30}}, 
             CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
             False, CellFrameMargins -> 2, CellFrameColor -> 
             RGBColor[0.668009, 0.669383, 0.345068], CounterIncrements -> 
             "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
             18, FontWeight -> "Bold"], 
            Cell[
             StyleData["SectionNoDingbat", "Presentation"], 
             CellFrameMargins -> {{0, 0}, {0, 4}}], 
            Cell[
             StyleData["SectionNoDingbat", "Printout"], 
             CellMargins -> {{54, 24}, {3, 15}}, 
             CellFrameMargins -> {{0, 0}, {0, 5}}, CellFrameColor -> 
             GrayLevel[0], FontSize -> 14], 
            Cell[
             StyleData["SectionNoDingbat", "Production"], CellFrame -> False, 
             CellMargins -> {{72, 72}, {2, 30}}, FontFamily -> 
             "CXB Futura CondExtraBold", FontSize -> 12, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubsectionNoDingbat"], CellDingbat -> None, 
             CellMargins -> {{54, 25}, {10, 26}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsection", 
             CounterAssignments -> {{"Subsubsection", 0}}, StyleMenuListing -> 
             None, FontFamily -> "Helvetica", FontSize -> 14, FontWeight -> 
             "Bold"], 
            Cell[
             StyleData["SubsectionNoDingbat", "Presentation"]], 
            Cell[
             StyleData["SubsectionNoDingbat", "Printout"], 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, FontSize -> 
             12], 
            Cell[
             StyleData["SubsectionNoDingbat", "Production"], 
             CellMargins -> {{72, 72}, {2, Inherited}}, FontFamily -> 
             "CXB Futura CondExtraBold", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubsectionNoSpaceNoDingbat"], 
             CellMargins -> {{54, 25}, {2, 2}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsection", 
             CounterAssignments -> {{"Subsubsection", 0}}, StyleMenuListing -> 
             None, FontFamily -> "Helvetica", FontSize -> 14, FontWeight -> 
             "Bold"], 
            Cell[
             StyleData["SubsectionNoSpaceNoDingbat", "Presentation"]], 
            Cell[
             StyleData["SubsectionNoSpaceNoDingbat", "Printout"], 
             CellMargins -> {{54, 24}, {2, 2}}, FontSize -> 12], 
            Cell[
             StyleData["SubsectionNoSpaceNoDingbat", "Production"], 
             CellMargins -> {{72, 72}, {2, 2}}, FontFamily -> 
             "CXB Futura CondExtraBold", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubsubsectionNoDingbat"], 
             CellMargins -> {{54, 25}, {6, 20}}, 
             CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsubsection", StyleMenuListing -> 
             None, FontFamily -> "Helvetica", FontSize -> 12, FontWeight -> 
             "Bold"], 
            Cell[
             StyleData["SubsubsectionNoDingbat", "Presentation"]], 
            Cell[
             StyleData["SubsubsectionNoDingbat", "Printout"], 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, FontSize -> 
             10], 
            Cell[
             StyleData["SubsubsectionNoDingbat", "Production"], 
             CellMargins -> {{72, 72}, {-4, 2}}, FontFamily -> "Futura Book", 
             FontSize -> 9, FontWeight -> "Plain", FontSlant -> "Italic", 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Styles for Body Text", "Section", CellFrame -> False, CellDingbat -> 
          None, ShowCellBracket -> True, CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 4}, CounterIncrements -> "Text", FontFamily -> 
             "Times", FontSize -> 12], 
            Cell[
             StyleData["Text", "Presentation"], FontSize -> 14], 
            Cell[
             StyleData["Text", "Printout"], 
             CellMargins -> {{54, 24}, {Inherited, 0}}, LineSpacing -> {1, 3},
              FontSize -> 10], 
            Cell[
             StyleData["Text", "Production"], 
             CellMargins -> {{72, 72}, {2, 4}}, TextJustification -> 1, 
             Hyphenation -> True, LineSpacing -> {0, 12}, FontFamily -> 
             "Janson Text", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SmallText"], 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 4}, CounterIncrements -> "SmallText", 
             FontFamily -> "Times", FontSize -> 10], 
            Cell[
             StyleData["SmallText", "Presentation"], 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, FontSize -> 
             12], 
            Cell[
             StyleData["SmallText", "Printout"], 
             CellMargins -> {{54, 24}, {Inherited, 0}}, LineSpacing -> {1, 3},
              FontSize -> 9], 
            Cell[
             StyleData["SmallText", "Production"], 
             CellMargins -> {{72, 72}, {2, 4}}, TextJustification -> 1, 
             Hyphenation -> True, LineSpacing -> {0, 11}, FontFamily -> 
             "Janson Text", FontSize -> 9, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
         "BeginQuestion is used directly after a section cell. Followed by \
either Question or Input/Output etc. Last paragraph of the question should be \
in EndQuestion cell style.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["BeginQuestion"], CellFrame -> {{0, 0}, {0, 1}}, 
             CellMargins -> {{54, 34}, {8, 8}}, 
             CellFrameMargins -> {{0, 0}, {2, 4}}, CounterIncrements -> 
             "Exercise", FontColor -> RGBColor[0.115511, 0.321752, 0.580118]],
             
            Cell[
             StyleData["BeginQuestion", "Presentation"], 
             LineSpacing -> {1, 4}, FontSize -> 16, FontColor -> 
             RGBColor[0.115511, 0.321752, 0.580118]], 
            Cell[
             StyleData["BeginQuestion", "Printout"], 
             CellMargins -> {{72, 34}, {Inherited, Inherited}}, FontSize -> 
             10, FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["BeginQuestion", "Production"], PageWidth -> 
             PaperWidth, CellFrame -> {{0, 0}, {0, 2}}, 
             CellMargins -> {{72, 72}, {2, 4}}, TextJustification -> 1, 
             Hyphenation -> True, LineSpacing -> {0, 12}, FontFamily -> 
             "Janson Text", FontSize -> 10, FontWeight -> "Plain", FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
         "EndQuestion used as the last paragraph of the question.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["EndQuestion"], CellFrame -> {{0, 0}, {1, 0}}, 
             CellMargins -> {{54, 34}, {8, 8}}, FontColor -> 
             RGBColor[0.115511, 0.321752, 0.580118]], 
            Cell[
             StyleData["EndQuestion", "Presentation"], LineSpacing -> {1, 4}, 
             FontSize -> 16, FontColor -> 
             RGBColor[0.115511, 0.321752, 0.580118]], 
            Cell[
             StyleData["EndQuestion", "Printout"], 
             CellMargins -> {{70, 35}, {Inherited, Inherited}}, FontSize -> 
             10, FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["EndQuestion", "Production"], 
             CellFrame -> {{0, 0}, {2, 0}}, CellMargins -> {{72, 72}, {2, 0}},
              TextJustification -> 1, Hyphenation -> True, 
             LineSpacing -> {0, 12}, FontFamily -> "Janson Text", FontSize -> 
             10, FontWeight -> "Plain", 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
         "BeginEndQuestion is used in the In and Out column directly after a \
section cell. Used if the question is a single text paragraph.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["BeginEndQuestion"], CellFrame -> {{0, 0}, {1, 1}}, 
             CellMargins -> {{54, 35}, {8, 8}}, CounterIncrements -> 
             "Exercise", StyleMenuListing -> Automatic, FontColor -> 
             RGBColor[0.115511, 0.321752, 0.580118]], 
            Cell[
             StyleData["BeginEndQuestion", "Presentation"], 
             LineSpacing -> {1, 4}, FontSize -> 16, FontColor -> 
             RGBColor[0.115511, 0.321752, 0.580118]], 
            Cell[
             StyleData["BeginEndQuestion", "Printout"], 
             CellMargins -> {{70, 35}, {Inherited, Inherited}}, FontSize -> 
             10, FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["BeginEndQuestion", "Production"], 
             CellMargins -> {{72, 72}, {2, 4}}, TextJustification -> 1, 
             Hyphenation -> True, LineSpacing -> {0, 12}, FontFamily -> 
             "Janson Text", FontSize -> 10, FontWeight -> "Plain", FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
         "BeginAnswer is used directly after an EndQuestion or \
BeginEndQuestion cell style to begin the answer portion. Followed by Text or \
Input/Output etc.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Answer"], CellDingbat -> "Answer: ", 
             CellMargins -> {{54, 35}, {8, 8}}, LineSpacing -> {1, 4}], 
            Cell[
             StyleData["Answer", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["Answer", "Printout"], 
             CellMargins -> {{70, 35}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 3}, FontSize -> 10], 
            Cell[
             StyleData["Answer", "Production"], 
             CellMargins -> {{72, 72}, {2, 4}}, TextJustification -> 1, 
             Hyphenation -> True, LineSpacing -> {0, 12}, FontFamily -> 
             "Janson Text", FontSize -> 10]}, Closed]], 
         Cell[
         "Quote should be used when displaying text previously published \
elsewhere (and appropriately cited).", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Quote"], 
             CellMargins -> {{70, 40}, {Inherited, Inherited}}, 
             TextJustification -> 0, LineSpacing -> {1, 3}, FontFamily -> 
             "Times", FontSize -> 12], 
            Cell[
             StyleData["Quote", "Presentation"], FontSize -> 14], 
            Cell[
             StyleData["Quote", "Printout"], 
             CellMargins -> {{70, 40}, {Inherited, Inherited}}, FontSize -> 
             10], 
            Cell[
             StyleData["Quote", "Production"], 
             CellMargins -> {{96, 96}, {2, 4}}, TextJustification -> 1, 
             Hyphenation -> True, LineSpacing -> {0, 12}, FontFamily -> 
             "Janson Text", FontSize -> 10, FontSlant -> "Plain", 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Styles for Input/Output", "Section", CellFrame -> False, 
          CellDingbat -> None, ShowCellBracket -> True, 
          CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
         "The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], CellMargins -> {{76, 24}, {4, 4}}, 
             Evaluatable -> True, CellGroupingRules -> "InputGrouping", 
             CellHorizontalScrolling -> True, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, 
             AutoItalicWords -> {}, FormatType -> InputForm, 
             ShowStringCharacters -> True, NumberMarks -> True, 
             CounterIncrements -> "Input", FontWeight -> "Bold"], 
            Cell[
             StyleData["Input", "Presentation"]], 
            Cell[
             StyleData["Input", "Printout"], 
             CellMargins -> {{96, 72}, {2, 4}}, FontSize -> 9], 
            Cell[
             StyleData["Input", "Production"], CellFrame -> False, 
             CellMargins -> {{96, 72}, {2, 4}}, 
             PrivateEvaluationOptions -> {"OutputFormPageWidth" -> 342}, 
             CellFrameMargins -> False, LineSpacing -> {1.25, 0}, FontFamily -> 
             "WriCMTT9", FontSize -> 9, FontWeight -> "Bold", 
             FontProperties -> {
              "FontMonospaced" -> True, "FontSerifed" -> True}, Background -> 
             None]}, Closed]], 
         Cell[
         "Output cell style is usually generated by the Mathematica kernel. ",
           "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], CellMargins -> {{76, 24}, {4, 4}}, 
             CellEditDuplicate -> True, CellGroupingRules -> "OutputGrouping",
              CellHorizontalScrolling -> True, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, 
             AutoItalicWords -> {}, FormatType -> InputForm, 
             CounterIncrements -> "Output"], 
            Cell[
             StyleData["Output", "Presentation"]], 
            Cell[
             StyleData["Output", "Printout"], 
             CellMargins -> {{96, 72}, {2, 4}}, FontSize -> 9], 
            Cell[
             StyleData["Output", "Production"], CellFrame -> False, 
             CellMargins -> {{96, 72}, {2, 4}}, 
             CellLabelMargins -> {{72, Inherited}, {Inherited, Inherited}}, 
             LineSpacing -> {1.25, 0}, FontFamily -> "WriCMTT9", FontSize -> 
             9, FontProperties -> {
              "FontMonospaced" -> True, "FontSerifed" -> True}, Background -> 
             None]}, Closed]], 
         Cell[
          TextData[{"Message cells are usually generated by the ", 
            StyleBox["Mathematica", FontSlant -> "Italic"], 
            " kernel, typically messages emitted during evaluation."}], 
          "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Message"], CellDingbat -> "\[WarningSign]", 
             CellMargins -> {{78, 24}, {2, 2}}, CellGroupingRules -> 
             "OutputGrouping", PageBreakWithin -> False, GroupPageBreakWithin -> 
             False, GeneratedCell -> True, CellAutoOverwrite -> True, 
             ShowCellLabel -> False, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, 
             AutoItalicWords -> {}, CounterIncrements -> "Message", 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
             10, FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["Message", "Presentation"], FontSize -> 12], 
            Cell[
             StyleData["Message", "Printout"], 
             CellMargins -> {{72, 24}, {2, 2}}, FontSize -> 8, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["Message", "Production"], CellFrame -> True, 
             CellDingbat -> None, CellMargins -> {{96, 72}, {2, 4}}, 
             PrivateEvaluationOptions -> {"OutputFormPageWidth" -> 342}, 
             CellFrameMargins -> 4, LineSpacing -> {0, 10}, FontFamily -> 
             "WriCMTT9", FontSize -> 8, 
             FontProperties -> {
              "FontMonospaced" -> True, "FontSerifed" -> True}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          TextData[{"Print cells are usually generated by the ", 
            StyleBox["Mathematica", FontSlant -> "Italic"], 
            " kernel, typically from such commands as ?Plot."}], "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], CellFrame -> True, 
             CellMargins -> {{78, 24}, {1, 6}}, CellGroupingRules -> 
             "OutputGrouping", CellHorizontalScrolling -> True, 
             PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, ShowCellLabel -> 
             False, CellLabelMargins -> {{23, Inherited}, {
               Inherited, Inherited}}, CellFrameColor -> 
             RGBColor[0.718318, 0.694575, 0.474449], DefaultFormatType -> 
             DefaultOutputFormatType, AutoItalicWords -> {}, 
             CounterIncrements -> "Print", StyleMenuListing -> None, FontSize -> 
             10], 
            Cell[
             StyleData["Print", "Presentation"], CellFrame -> 2, FontSize -> 
             12, Background -> None], 
            Cell[
             StyleData["Print", "Printout"], 
             CellMargins -> {{54, 24}, {2, 6}}, CellFrameColor -> 
             GrayLevel[0], FontSize -> 8], 
            Cell[
             StyleData["Print", "Production"], CellFrame -> True, 
             CellMargins -> {{96, 72}, {2, 4}}, 
             PrivateEvaluationOptions -> {"OutputFormPageWidth" -> 342}, 
             CellFrameMargins -> 4, CellFrameColor -> GrayLevel[0], 
             LineSpacing -> {0, 11}, FontFamily -> "WriCMTT9", FontSize -> 9, 
             FontProperties -> {
              "FontMonospaced" -> True, "FontSerifed" -> True}, Background -> 
             None]}, Closed]], 
         Cell[
         "Graphics cell usually output by kernel. To be preceded by Input \
cell, not followed by Output cell.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Graphics"], CellMargins -> {{54, 24}, {10, 0}}, 
             CellGroupingRules -> "GraphicsGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             CellLabelAutoDelete -> True, DefaultFormatType -> 
             DefaultOutputFormatType, CounterIncrements -> "Graphics", 
             ImageMargins -> {{30, 0}, {0, 0}}], 
            Cell[
             StyleData["Graphics", "Presentation"]], 
            Cell[
             StyleData["Graphics", "Printout"], 
             CellMargins -> {{54, 24}, {10, 0}}, ImageSize -> {266, 266}, 
             ImageMargins -> {{40, Inherited}, {Inherited, Inherited}}, 
             Background -> None], 
            Cell[
             StyleData["Graphics", "Production"], CellFrame -> False, 
             CellMargins -> {{96, 72}, {8, 10}}, LineSpacing -> {0, 12}, 
             ImageSize -> {144, 144}, FontFamily -> "Janson Text", FontSize -> 
             10, Background -> None]}, Closed]], 
         Cell[
         "CellLabel style definition controls how labels appear when a cell \
has ShowCellLabels->True.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 9, FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["CellLabel", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["CellLabel", "Printout"], FontSize -> 9, FontSlant -> 
             "Italic", FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["CellLabel", "Production"], LineSpacing -> {1, 0}, 
             FontFamily -> "CLO Futura CondLightOblique", FontSize -> 6, 
             FontSlant -> "Oblique", 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}, 
             PrivateFontOptions -> {
              "FontPostScriptName" -> "Futura-CondensedLightOblique"}, 
             FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
         "InlineInputTraditionalForm is for TraditionalForm input cells \
embedded within another cell.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["InlineInputTraditionalForm"], Evaluatable -> True, 
             CellGroupingRules -> "InputGrouping", CellHorizontalScrolling -> 
             True, AutoItalicWords -> {}, FormatType -> TraditionalForm, 
             ShowStringCharacters -> True, NumberMarks -> True, 
             SingleLetterItalics -> True, CounterIncrements -> "Input", 
             FontFamily -> "Times", FontWeight -> "Bold"], 
            Cell[
             StyleData["InlineInputTraditionalForm", "Presentation"]], 
            Cell[
             StyleData["InlineInputTraditionalForm", "Printout"]], 
            Cell[
             StyleData["InlineInputTraditionalForm", "Production"], 
             CounterIncrements -> "Input", FontFamily -> "Janson Text", 
             FontWeight -> "Bold", 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Styles for Automatic Numbering", "Section", CellFrame -> False, 
          CellDingbat -> None, ShowCellBracket -> True, 
          CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
         "NumberedEquation is for DisplayFormula-type cells that you want to \
number sequentially throughout a notebook.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedEquation"], 
             CellMargins -> {{100, 10}, {Inherited, Inherited}}, 
             CellFrameLabels -> {{None, 
                Cell[
                 TextData[{"(", 
                   CounterBox["Title"], ".", 
                   CounterBox["Section"], ".", 
                   CounterBox["Equation"], ")"}]]}, {None, None}}, 
             DefaultFormatType -> DefaultInputFormatType, CounterIncrements -> 
             "Equation", FormatTypeAutoConvert -> False], 
            Cell[
             StyleData["NumberedEquation", "Presentation"], FontSize -> 14], 
            Cell[
             StyleData["NumberedEquation", "Printout"], 
             CellMargins -> {{Inherited, Inherited}, {10, Inherited}}, 
             FontSize -> 10], 
            Cell[
             StyleData["NumberedEquation", "Production"], 
             CellMargins -> {{72, 72}, {2, 4}}, 
             PrivateEvaluationOptions -> {"OutputFormPageWidth" -> 342}, 
             FontFamily -> "Janson Text", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
         "NumberedFigureCaption to be used directly after a PlacedGraphic \
cell. Use the TMJAuthorPalette.nb palette to begin the cell and paste in the \
word Figure and the NumberedFigure counter value. Allows for a descriptive \
caption.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedFigureCaption"], CellDingbat -> 
             "\[FilledUpTriangle]", CellMargins -> {{54, 24}, {5, 10}}, 
             CellLabelPositioning -> Left, 
             CellFrameLabels -> {{None, None}, {None, None}}, TextAlignment -> 
             Left, HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
             CounterIncrements -> "NumberedFigure", FormatTypeAutoConvert -> 
             False, FontFamily -> "Helvetica"], 
            Cell[
             StyleData["NumberedFigureCaption", "Presentation"], 
             CellMargins -> {{54, 24}, {2, 10}}, FontSize -> 14], 
            Cell[
             StyleData["NumberedFigureCaption", "Printout"], 
             CellFrameLabels -> {{None, None}, {None, None}}, FontSize -> 8], 
            
            Cell[
             StyleData["NumberedFigureCaption", "Production"], CellDingbat -> 
             None, CellMargins -> {{72, 72}, {2, 4}}, TextJustification -> 1, 
             FontFamily -> "Futura Book", FontSize -> 9, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
         "NumberedTableCaption to be used directly after a Table cell. Use \
the TMJAuthorPalette.nb palette to begin the cell and paste in the word Table \
and the NumberedTable counter value. Allows for a descriptive caption.", 
          "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedTableCaption"], CellDingbat -> 
             "\[FilledUpTriangle]", CellMargins -> {{54, 24}, {5, 10}}, 
             HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
             CounterIncrements -> "NumberedTable", FontFamily -> "Helvetica", 
             FontSize -> 10], 
            Cell[
             StyleData["NumberedTableCaption", "Presentation"], 
             CellMargins -> {{54, 24}, {2, 10}}, FontSize -> 12], 
            Cell[
             StyleData["NumberedTableCaption", "Printout"], 
             CellFrameLabels -> {{None, None}, {None, None}}, FontSize -> 8], 
            
            Cell[
             StyleData["NumberedTableCaption", "Production"], CellDingbat -> 
             None, CellMargins -> {{72, 72}, {2, 4}}, TextJustification -> 1, 
             Hyphenation -> True, FontFamily -> "Futura Book", FontSize -> 9, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
         "NumberedProgramCaption to be used directly after a Program cell. \
Use the TMJAuthorPalette.nb palette to begin the cell and paste in the word \
Listing and the NumberedProgram counter value. Allows for a descriptive \
caption.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedProgramCaption"], CellDingbat -> 
             "\[FilledUpTriangle]", CellMargins -> {{54, 24}, {5, 10}}, 
             CellFrameLabels -> {{None, None}, {None, None}}, 
             HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
             CounterIncrements -> "NumberedProgram", FormatTypeAutoConvert -> 
             False, FontFamily -> "Helvetica", FontSize -> 10], 
            Cell[
             StyleData["NumberedProgramCaption", "Presentation"], 
             CellMargins -> {{54, 24}, {2, 10}}, FontSize -> 12], 
            Cell[
             StyleData["NumberedProgramCaption", "Printout"], 
             CellFrameLabels -> {{None, None}, {None, None}}, FontSize -> 8], 
            
            Cell[
             StyleData["NumberedProgramCaption", "Production"], CellDingbat -> 
             None, CellMargins -> {{72, 72}, {2, 4}}, TextJustification -> 1, 
             FontFamily -> "Futura Book", FontSize -> 9, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
         "BulletedList is an optional style. Adds a CellDingbat of \
FilledSmallCircle. Text indents left a little more.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["BulletedList"], CellDingbat -> "\[FilledSmallCircle]",
              CellMargins -> {{86, 10}, {Inherited, Inherited}}, FontFamily -> 
             "Times", FontSize -> 12], 
            Cell[
             StyleData["BulletedList", "Presentation"], FontSize -> 14], 
            Cell[
             StyleData["BulletedList", "Printout"], FontSize -> 10], 
            Cell[
             StyleData["BulletedList", "Production"], 
             CellMargins -> {{96, 72}, {2, Inherited}}, TextJustification -> 
             1, Hyphenation -> True, FontFamily -> "Janson Text", FontSize -> 
             10]}, Closed]], 
         Cell[
         "BeginNumberedList to be used as the first item in a numbered list \
sequence. Use the TMJAuthorPalette.nb palette to begin the cell and paste in \
the List counter value.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["BeginNumberedList"], 
             CellMargins -> {{74, 10}, {Inherited, Inherited}}, 
             CounterIncrements -> "List", CounterAssignments -> {{"List", 0}},
              FontFamily -> "Times", FontSize -> 12], 
            Cell[
             StyleData["BeginNumberedList", "Presentation"], FontSize -> 14], 
            
            Cell[
             StyleData["BeginNumberedList", "Printout"], FontSize -> 10], 
            Cell[
             StyleData["BeginNumberedList", "Production"], 
             CellMargins -> {{84, 72}, {2, Inherited}}, Hyphenation -> True, 
             ParagraphIndent -> -13, FontFamily -> "Janson Text", FontSize -> 
             10, FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
         "NumberedList to be used for subsequent items in a numbered list \
sequence with a single digit. Use the TMJAuthorPalette.nb palette to begin \
the cell and paste in the List counter value.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedList"], 
             CellMargins -> {{74, 10}, {Inherited, Inherited}}, 
             CellFrameLabels -> {{None, None}, {None, None}}, 
             CounterIncrements -> "List", FontFamily -> "Times", FontSize -> 
             12], 
            Cell[
             StyleData["NumberedList", "Presentation"], FontSize -> 14], 
            Cell[
             StyleData["NumberedList", "Printout"], FontSize -> 10], 
            Cell[
             StyleData["NumberedList", "Production"], 
             CellMargins -> {{84, 72}, {2, Inherited}}, TextJustification -> 
             1, Hyphenation -> True, ParagraphIndent -> -13, FontFamily -> 
             "Janson Text", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
         "NumberedListTwo to be used for subsequent items in a numbered list \
sequence with two digits. Use the TMJAuthorPalette.nb palette to begin the \
cell and paste in the List counter value.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedListTwo"], 
             CellMargins -> {{74, 10}, {Inherited, Inherited}}, 
             CounterIncrements -> "List", FontFamily -> "Times", FontSize -> 
             12], 
            Cell[
             StyleData["NumberedListTwo", "Presentation"], FontSize -> 14], 
            Cell[
             StyleData["NumberedListTwo", "Printout"], FontSize -> 10], 
            Cell[
             StyleData["NumberedListTwo", "Production"], 
             CellMargins -> {{84, 72}, {2, Inherited}}, TextJustification -> 
             1, Hyphenation -> True, ParagraphIndent -> -17, FontFamily -> 
             "Janson Text", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
         "Reference style to be used in the bibliography portion of a \
notebook. One cell for each bibliography entry. Use the TMJAuthorPalette.nb \
palette to begin cell and paste in the Reference counter value.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Reference"], 
             CellMargins -> {{54, 25}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 3}, CounterIncrements -> "Reference", 
             FontFamily -> "Helvetica", FontSize -> 10], 
            Cell[
             StyleData["Reference", "Presentation"], FontFamily -> 
             "Helvetica", FontSize -> 12], 
            Cell[
             StyleData["Reference", "Printout"], FontSize -> 8], 
            Cell[
             StyleData["Reference", "Production"], 
             CellMargins -> {{84, 72}, {2, 4}}, TextJustification -> 1, 
             Hyphenation -> True, LineSpacing -> {0, 10}, 
             ParagraphIndent -> -14, FontFamily -> "Futura Book", FontSize -> 
             8, FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ReferenceTwo"], 
             CellMargins -> {{54, 25}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 3}, CounterIncrements -> "Reference", 
             FontFamily -> "Helvetica", FontSize -> 10], 
            Cell[
             StyleData["ReferenceTwo", "Presentation"], FontFamily -> 
             "Helvetica", FontSize -> 12], 
            Cell[
             StyleData["ReferenceTwo", "Printout"], FontSize -> 8], 
            Cell[
             StyleData["ReferenceTwo", "Production"], 
             CellMargins -> {{84, 72}, {2, 4}}, TextJustification -> 1, 
             Hyphenation -> True, LineSpacing -> {0, 10}, 
             ParagraphIndent -> -18, FontFamily -> "Futura Book", FontSize -> 
             8, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Unique Styles", "Section", CellFrame -> False, CellDingbat -> None, 
          ShowCellBracket -> True, CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
         "OnlineHeader to be used at the beginning of a notebook. Precedes \
the Title cell.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OnlineHeader"], ShowCellBracket -> False, 
             CellMargins -> {{0, 25}, {0, 0}}, 
             CellGroupingRules -> {"TitleGrouping", 30}, PageBreakBelow -> 
             False, CellFrameMargins -> {{54, 4}, {2, 8}}, 
             LineSpacing -> {1, 1}, FontFamily -> "Times", FontSize -> 12, 
             FontWeight -> "Plain", FontSlant -> "Italic", FontTracking -> 
             "Wide", FontVariations -> {
              "CompatibilityType" -> 0, "Masked" -> False, "Outline" -> False,
                "RotationAngle" -> 0, "Shadow" -> False, "StrikeThrough" -> 
               False, "Underline" -> False}, FontColor -> GrayLevel[1], 
             Background -> GrayLevel[0]], 
            Cell[
             StyleData["OnlineHeader", "Presentation"], 
             CellFrameMargins -> {{54, 25}, {8, 8}}, FontSize -> 14], 
            Cell[
             StyleData["OnlineHeader", "Printout"], CellFrame -> False, 
             CellMargins -> {{54, 24}, {10, 10}}, FontFamily -> "Times", 
             FontSize -> 10, FontColor -> GrayLevel[0], Background -> None], 
            Cell[
             StyleData["OnlineHeader", "Production"], PageWidth -> PaperWidth,
              CellFrame -> False, CellMargins -> {{72, 72}, {0, 0}}, 
             CellElementSpacings -> {"CellMinHeight" -> 2}, FontFamily -> 
             "Janson Text", FontSize -> 10, Background -> None]}, Closed]], 
         Cell[
         "Author to be used after the Title cell with author name(s). Author \
name(s) may be preced by \"Edited by \" for certain columns. Text in author \
cell to be used as the left page header. Usually followed by an Address \
cell.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Author"], 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, 
             CellGroupingRules -> {"TitleGrouping", 20}, PageBreakBelow -> 
             False, FontFamily -> "Helvetica", FontSize -> 14, FontWeight -> 
             "Bold", FontSlant -> "Plain"], 
            Cell[
             StyleData["Author", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["Author", "Printout"], 
             CellMargins -> {{54, 24}, {2, 15}}, FontSize -> 12], 
            Cell[
             StyleData["Author", "Production"], 
             CellMargins -> {{72, 72}, {4, 4}}, LineSpacing -> {0, 14}, 
             FontFamily -> "CXB Futura CondExtraBold", FontSize -> 12, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
         "Address to be used after Author or SecondAuthor. Contains contact \
information for article (section) author.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Address"], 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, 
             CellGroupingRules -> {"TitleGrouping", 30}, PageBreakBelow -> 
             False, LineSpacing -> {1, 1}, FontFamily -> "Times", FontSize -> 
             12, FontWeight -> "Plain", FontSlant -> "Italic"], 
            Cell[
             StyleData["Address", "Presentation"], FontSize -> 14], 
            Cell[
             StyleData["Address", "Printout"], 
             CellMargins -> {{54, 24}, {2, 2}}, FontSize -> 10], 
            Cell[
             StyleData["Address", "Production"], 
             CellMargins -> {{72, 72}, {22, 4}}, LineSpacing -> {0, 12}, 
             FontFamily -> "I Janson Text Italic", FontSize -> 8, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
         "Abstract to be used after the Address cell. Contains a short \
descriptive summary of the article.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Abstract"], 
             CellMargins -> {{54, 24}, {Inherited, 30}}, 
             LineSpacing -> {1, 3}, FontFamily -> "Times", FontSize -> 14, 
             FontWeight -> "Bold", FontSlant -> "Italic"], 
            Cell[
             StyleData["Abstract", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["Abstract", "Printout"], 
             CellMargins -> {{54, 24}, {20, 30}}, FontSize -> 12, FontSlant -> 
             "Italic"], 
            Cell[
             StyleData["Abstract", "Production"], 
             CellMargins -> {{72, 72}, {Inherited, 2}}, TextJustification -> 
             1, Hyphenation -> True, LineSpacing -> {0, 12}, FontFamily -> 
             "BI Janson Text Bold Italic", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
         "PictureGroup style definitions included for compatability with the \
Help Browser.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["PictureGroup"], CellFrame -> {{1, 0}, {0, 1}}, 
             CellMargins -> {{54, 25}, {0, 0}}, CellGroupingRules -> 
             "GraphicsGrouping", CellHorizontalScrolling -> True, 
             PageBreakWithin -> False, ShowCellLabel -> False, 
             CounterIncrements -> "Graphics", 
             ImageMargins -> {{35, Inherited}, {Inherited, 0}}, 
             StyleMenuListing -> None], 
            Cell[
             StyleData["PictureGroup", "Presentation"], CounterIncrements -> 
             "Graphics", ImageMargins -> {{35, Inherited}, {Inherited, 0}}, 
             StyleMenuListing -> None], 
            Cell[
             StyleData["PictureGroup", "Printout"], 
             CellMargins -> {{54, Inherited}, {0, 0}}, 
             ImageSize -> {0.0625, 0.0625}], 
            Cell[
             StyleData["PictureGroup", "Production"], CellFrame -> False, 
             CellMargins -> {{72, 72}, {8, 10}}, LineSpacing -> {0, 12}, 
             FontFamily -> "Janson Text", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MarkersComment"], CellFrame -> False, CellDingbat -> 
             "\[FilledCircle]", 
             CellMargins -> {{54, 25}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 3}, CounterIncrements -> "Text", FontColor -> 
             RGBColor[1, 0, 0], Background -> GrayLevel[1]], 
            Cell[
             StyleData["MarkersComment", "Printout"], 
             CellMargins -> {{18, 4}, {Inherited, 0}}, LineSpacing -> {1, 3}, 
             FontSize -> 10], 
            Cell[
             StyleData["MarkersComment", "Production"], 
             CellMargins -> {{24, 0}, {Inherited, 0}}, LineSpacing -> {1, 3}, 
             FontFamily -> "Janson Text", FontSize -> 10]}, Closed]], 
         Cell[
         "Table cell style to be used for cells containing displayed tabular \
material. Can be followed by NumberedTableCaption cell.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Table"], CellMargins -> {{54, 24}, {5, 10}}, 
             TextAlignment -> Center, FontFamily -> "Times", FontSize -> 12, 
             Background -> GrayLevel[0.899001]], 
            Cell[
             StyleData["Table", "Presentation"], FontSize -> 14], 
            Cell[
             StyleData["Table", "Printout"], FontSize -> 10, Background -> 
             None], 
            Cell[
             StyleData["Table", "Production"], 
             CellMargins -> {{72, 72}, {0, 4}}, FontFamily -> "Janson Text", 
             FontSize -> 10, Background -> None]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Menu"], 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 4}, ParagraphSpacing -> {0, 12}, FontFamily -> 
             "Charcoal"], 
            Cell[
             StyleData["Menu", "Presentation"]], 
            Cell[
             StyleData["Menu", "Printout"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Warning"], CellDingbat -> "\[WarningSign]", 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 4}, ParagraphSpacing -> {0, 12}, FontSize -> 
             12], 
            Cell[
             StyleData["Warning", "Presentation"], LineSpacing -> {1, 5}, 
             ParagraphSpacing -> {0, 12}], 
            Cell[
             StyleData["Warning", "Printout"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["BrightIdea"], CellDingbat -> "\[LightBulb]", 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, FontFamily -> 
             "Times"], 
            Cell[
             StyleData["BrightIdea", "Presentation"]], 
            Cell[
             StyleData["BrightIdea", "Printout"], TextJustification -> 1]}, 
           Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Formulas and Programming", "Section", CellFrame -> False, 
          CellDingbat -> None, ShowCellBracket -> True, 
          CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], CellMargins -> {{54, 25}, {2, 10}}, 
             CellHorizontalScrolling -> True, DefaultFormatType -> 
             DefaultInputFormatType, TextAlignment -> Center, ScriptLevel -> 
             0, SingleLetterItalics -> True, FontFamily -> "Times", FontSize -> 
             12, UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
            Cell[
             StyleData["DisplayFormula", "Presentation"], FontSize -> 14], 
            Cell[
             StyleData["DisplayFormula", "Printout"], 
             CellMargins -> {{54, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 10], 
            Cell[
             StyleData["DisplayFormula", "Production"], 
             CellMargins -> {{72, 72}, {2, 4}}, 
             PrivateEvaluationOptions -> {"OutputFormPageWidth" -> 342}, 
             LineSpacing -> {1.25, 0}, FontFamily -> "Janson Text", FontSize -> 
             10, FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ChemicalFormula"], CellMargins -> {{54, 25}, {2, 10}},
              DefaultFormatType -> DefaultInputFormatType, AutoSpacing -> 
             False, ScriptBaselineShifts -> {0.6, Automatic}, ScriptLevel -> 
             1, SingleLetterItalics -> False, ZeroWidthTimes -> True, 
             FontFamily -> "Times", FontSize -> 12], 
            Cell[
             StyleData["ChemicalFormula", "Presentation"], FontSize -> 14], 
            Cell[
             StyleData["ChemicalFormula", "Printout"], 
             CellMargins -> {{54, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 10], 
            Cell[
             StyleData["ChemicalFormula", "Production"], 
             CellMargins -> {{72, 72}, {2, 4}}, LineSpacing -> {0, 12}, 
             FontFamily -> "Janson Text", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"], CellMargins -> {{54, 25}, {Inherited, 6}}, 
             FontFamily -> "Courier", FontSize -> 10], 
            Cell[
             StyleData["Program", "Presentation"], FontFamily -> "Courier", 
             FontSize -> 12], 
            Cell[
             StyleData["Program", "Printout"], 
             CellMargins -> {{54, 30}, {Inherited, 4}}, FontSize -> 9], 
            Cell[
             StyleData["Program", "Production"], 
             CellMargins -> {{72, 72}, {2, 4}}, LineSpacing -> {0, 11}, 
             FontFamily -> "WriCMTT9", FontSize -> 9, 
             FontProperties -> {
              "FontMonospaced" -> True, "FontSerifed" -> True}]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Styles for Headers and Footers", "Section", CellFrame -> False, 
          CellDingbat -> None, ShowCellBracket -> True, 
          CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Header"], CellMargins -> {{54, 24}, {0, 0}}, 
             StyleMenuListing -> None, FontFamily -> "Times", FontSize -> 9, 
             FontSlant -> "Italic"], 
            Cell[
             StyleData["Header", "Presentation"]], 
            Cell[
             StyleData["Header", "Printout"]], 
            Cell[
             StyleData["Header", "Production"], PageWidth -> PaperWidth, 
             CellMargins -> {{72, 72}, {2, 2}}, StyleMenuListing -> None, 
             FontFamily -> "I Janson Text Italic", FontSize -> 9]}, Closed]], 
         
         Cell[
          CellGroupData[{
            Cell[
             StyleData["PageNumber"], StyleMenuListing -> None, FontFamily -> 
             "Times", FontSize -> 9, FontWeight -> "Bold"], 
            Cell[
             StyleData["PageNumber", "Production"], PageWidth -> PaperWidth, 
             CellMargins -> {{72, 72}, {2, 2}}, StyleMenuListing -> None, 
             FontFamily -> "B Janson Text Bold"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Footer"], 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
             7, FontSlant -> "Italic"], 
            Cell[
             StyleData["Footer", "Production"], PageWidth -> PaperWidth, 
             CellMargins -> {{72, 72}, {2, 2}}, StyleMenuListing -> None, 
             FontFamily -> "O Futura BookOblique", FontSize -> 6]}, Closed]]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Hyperlink Styles", "Section", CellFrame -> False, CellDingbat -> 
          None, ShowCellBracket -> True, CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
         "The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Hyperlink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`NotebookLocate[#2]}]& ), ButtonNote -> 
               ButtonData}], 
            Cell[
             StyleData["Hyperlink", "Presentation"]], 
            Cell[
             StyleData["Hyperlink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["Hyperlink", "Production"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
         "The following styles are for linking automatically to the on-line \
help system.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MainBookLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFrame -> "None", 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["MainBook", #]}]& )}], 
            Cell[
             StyleData["MainBookLink", "Presentation"]], 
            Cell[
             StyleData["MainBookLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["MainBookLink", "Production"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["AddOnsLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFrame -> "None", 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["AddOns", #]}]& )}], 
            Cell[
             StyleData["AddOnsLink", "Presentation"]], 
            Cell[
             StyleData["AddOnsLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["AddOnsLink", "Production"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["RefGuideLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFrame -> "None", 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["RefGuide", #]}]& )}], 
            Cell[
             StyleData["RefGuideLink", "Presentation"]], 
            Cell[
             StyleData["RefGuideLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["RefGuideLink", "Production"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["GettingStartedLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFrame -> "None", 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["GettingStarted", #]}]& )}], 
            Cell[
             StyleData["GettingStartedLink", "Presentation"]], 
            Cell[
             StyleData["GettingStartedLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["GettingStartedLink", "Production"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OtherInformationLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFrame -> "None", 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["OtherInformation", #]}]& )}], 
            Cell[
             StyleData["OtherInformationLink", "Presentation"]], 
            Cell[
             StyleData["OtherInformationLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["OtherInformationLink", "Production"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "FormatType Styles", "Section", CellFrame -> False, CellDingbat -> 
          None, ShowCellBracket -> True, CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
         "These cells define styles that are mixed in with most other cells.  \
If the FormatType of a cell style matches the name of one of the styles \
defined below, then that style is applied along with the local cell style \
definitions. This is particularly true of Input and Output.", "Text", 
          CellMargins -> {{24, 0}, {Inherited, Inherited}}], 
         Cell[
          StyleData["CellExpression"], CellMargins -> {{54, 24}, {2, 4}}, 
          ShowCellLabel -> False, ShowSpecialCharacters -> False, 
          AllowInlineCells -> False, Hyphenation -> False, 
          AutoItalicWords -> {}, StyleMenuListing -> None, FontFamily -> 
          "Courier", FontSize -> 10, Background -> GrayLevel[1]], 
         Cell[
          StyleData["InputForm"], AllowInlineCells -> False, Hyphenation -> 
          False, LineSpacing -> {1.25, 0}, StyleMenuListing -> None, 
          FontFamily -> "Courier", 
          FontProperties -> {
           "FontMonospaced" -> True, "FontSerifed" -> True}], 
         Cell[
          StyleData["OutputForm"], LineSpacing -> {1.25, 0}, StyleMenuListing -> 
          None, FontFamily -> "Courier", 
          FontProperties -> {
           "FontMonospaced" -> True, "FontSerifed" -> True}], 
         Cell[
          StyleData["StandardForm"], LineSpacing -> {1.25, 0}, 
          SingleLetterItalics -> False, StyleMenuListing -> None, FontFamily -> 
          "Courier", 
          FontProperties -> {
           "FontMonospaced" -> True, "FontSerifed" -> True}], 
         Cell[
          StyleData["TraditionalForm"], 
          InputAutoReplacements -> {
           "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> 
            "\[LessEqual]", ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", 
            "==" -> "\[Equal]", Inherited}, LineSpacing -> {1.25, 0}, 
          SingleLetterItalics -> True, TraditionalFunctionNotation -> True, 
          DelimiterMatching -> None, StyleMenuListing -> None, FontFamily -> 
          "Times", 
          FontProperties -> {
           "FontMonospaced" -> False, "FontSerifed" -> True}], 
         Cell[
         "The style defined below is mixed in to any cell that is in an \
inline cell within another.", "Text", 
          CellMargins -> {{24, 0}, {Inherited, Inherited}}], 
         Cell[
          StyleData["InlineCell"], TextAlignment -> Left, ScriptLevel -> 1, 
          StyleMenuListing -> None], 
         Cell[
          StyleData["InlineCellEditing"], StyleMenuListing -> None, 
          Background -> RGBColor[1, 0.749996, 0.8]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Inline Formatting", "Section", CellFrame -> False, CellDingbat -> 
          None, ShowCellBracket -> True, CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
         "These styles are for modifying individual words or letters in a \
cell exclusive of the cell style.", "Text", PageWidth -> 342, 
          CellMargins -> {{24, 0}, {Inherited, Inherited}}], 
         Cell[
         "RM used to change selection to FontWeight->Plain, FontSlant->Plain",
           "Text"], 
         Cell[
          StyleData["RM"], FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
         "BF used to change selection to FontWeight->Bold, FontSlant->Plain", 
          "Text"], 
         Cell[
          StyleData["BF"], FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
         "IT used to change selection to FontWeight->Plain, \
FontSlant->Italic", "Text"], 
         Cell[
          StyleData["IT"], FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
         "BFI used to change selection to FontWeight->Bold, \
FontSlant->Italic", "Text"], 
         Cell[
          StyleData["BFI"], FontWeight -> "Bold", FontSlant -> "Italic"], 
         Cell[
         "TR used to change selection to normal text font, FontWeight->Plain, \
FontSlant->Plain", "Text"], 
         Cell[
          StyleData["TR"], FontFamily -> "Times", FontWeight -> "Plain", 
          FontSlant -> "Plain"], 
         Cell[
         "TI used to change selection to normal text font, FontWeight->Plain, \
FontSlant->Italic", "Text"], 
         Cell[
          StyleData["TI"], FontFamily -> "Times", FontWeight -> "Plain", 
          FontSlant -> "Italic"], 
         Cell[
         "TB used to change selection to normal text font, FontWeight->Bold, \
FontSlant->Plain", "Text"], 
         Cell[
          StyleData["TB"], FontFamily -> "Times", FontWeight -> "Bold", 
          FontSlant -> "Plain"], 
         Cell[
         "TBI used to change selection to normal text font, FontWeight->Bold, \
FontSlant->Italic", "Text"], 
         Cell[
          StyleData["TBI"], FontFamily -> "Times", FontWeight -> "Bold", 
          FontSlant -> "Italic"], 
         Cell[
         "MR used to change selection to monospace font with \
FontWeight->Plain, FontSlant->Plain", "Text"], 
         Cell[
          StyleData["MR"], StyleMenuListing -> None, FontFamily -> "Courier", 
          FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
         "MR used to change selection to monospace font with \
FontWeight->Plain, FontSlant->Oblique", "Text"], 
         Cell[
          StyleData["MO"], StyleMenuListing -> None, FontFamily -> "Courier", 
          FontWeight -> "Plain", FontSlant -> "Oblique"], 
         Cell[
         "MB used to change selection to monospace font with \
FontWeight->Bold, FontSlant->Plain", "Text"], 
         Cell[
          StyleData["MB"], StyleMenuListing -> None, FontFamily -> "Courier", 
          FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
         "MBO used to change selection to monospace font with \
FontWeight->Bold, FontSlant->Oblique", "Text"], 
         Cell[
          StyleData["MBO"], StyleMenuListing -> None, FontFamily -> "Courier",
           FontWeight -> "Bold", FontSlant -> "Oblique"], 
         Cell[
         "SR used to change selection to sans serif font with \
FontWeight->Plain, FontSlant->Plain", "Text"], 
         Cell[
          StyleData["SR"], FontFamily -> "Helvetica", FontWeight -> "Plain", 
          FontSlant -> "Plain"], 
         Cell[
         "SO used to change selection to sans serif font with \
FontWeight->Plain, FontSlant->Oblique", "Text"], 
         Cell[
          StyleData["SO"], FontFamily -> "Helvetica", FontWeight -> "Plain", 
          FontSlant -> "Oblique"], 
         Cell[
         "SB used to change selection to sans serif font with \
FontWeight->Bold, FontSlant->Plain", "Text"], 
         Cell[
          StyleData["SB"], FontFamily -> "Helvetica", FontWeight -> "Bold", 
          FontSlant -> "Plain"], 
         Cell[
         "SBO used to change selection to sans serif font with \
FontWeight->Bold, FontSlant->Oblique", "Text"], 
         Cell[
          StyleData["SBO"], FontFamily -> "Helvetica", FontSize -> 10, 
          FontWeight -> "Bold", FontSlant -> "Oblique"]}, Closed]]}, Open]]}, 
  Visible -> False, FrontEndVersion -> 
  "6.0 for Microsoft Windows (32-bit) (April 9, 2007)", StyleDefinitions -> 
  "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "harmonic approximation"->{
  Cell[4298, 172, 406, 16, 27, "Text",
   CellTags->"harmonic approximation"]},
 "damping"->{
  Cell[4998, 201, 477, 17, 27, "Text",
   CellTags->{"damping", "sinusoidal driving term"}]},
 "sinusoidal driving term"->{
  Cell[4998, 201, 477, 17, 27, "Text",
   CellTags->{"damping", "sinusoidal driving term"}]},
 "undamped pendulum"->{
  Cell[6475, 264, 188, 6, 27, "Text",
   CellTags->"undamped pendulum"]},
 "phase-space plot"->{
  Cell[7027, 285, 1633, 49, 125, "BeginEndQuestion",
   CellTags->"phase-space plot"]},
 "damped pendulum"->{
  Cell[30861, 1268, 207, 6, 27, "Text",
   CellTags->"damped pendulum"]},
 "period-3 limit cycle"->{
  Cell[36034, 1460, 291, 9, 49, "Text",
   CellTags->{"period-3 limit cycle", "periodic"}]},
 "periodic"->{
  Cell[36034, 1460, 291, 9, 49, "Text",
   CellTags->{"period-3 limit cycle", "periodic"}]},
 "Poincar\[EAcute] section"->{
  Cell[36328, 1471, 291, 7, 49, "Text",
   CellTags->{"Poincar\[EAcute] section", "driving frequency"}]},
 "driving frequency"->{
  Cell[36328, 1471, 291, 7, 49, "Text",
   CellTags->{"Poincar\[EAcute] section", "driving frequency"}]},
 "transient effects"->{
  Cell[36971, 1494, 140, 4, 27, "Text",
   CellTags->"transient effects"]},
 "series solution"->{
  Cell[38306, 1554, 582, 20, 50, "Text",
   CellTags->"series solution"]},
 "linearized equation"->{
  Cell[60160, 2347, 314, 13, 70, "Text",
   CellTags->"linearized equation"]},
 "Iterated mapping"->{
  Cell[61860, 2435, 881, 30, 72, "Text",
   CellTags->{"Iterated mapping", "Bounded absolute value"}],
  Cell[82351, 3162, 546, 17, 70, "Text",
   CellTags->{
    "Iterated mapping", "connected Julia sets", "Mandelbrot set"}]},
 "Bounded absolute value"->{
  Cell[61860, 2435, 881, 30, 72, "Text",
   CellTags->{"Iterated mapping", "Bounded absolute value"}]},
 "Module"->{
  Cell[64053, 2520, 864, 30, 72, "Text",
   CellTags->"Module"]},
 "pure function"->{
  Cell[65704, 2579, 428, 15, 28, "Text",
   CellTags->{"pure function", "Function"}],
  Cell[74594, 2898, 959, 18, 118, "Text",
   CellTags->{
    "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
     "SameTest", "pure function", "True"}]},
 "Function"->{
  Cell[65704, 2579, 428, 15, 28, "Text",
   CellTags->{"pure function", "Function"}],
  Cell[70371, 2742, 774, 21, 74, "Warning",
   CellTags->{
    "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
     "Compile", "argument typing"}]},
 "rank-2 tensor"->{
  Cell[70371, 2742, 774, 21, 74, "Warning",
   CellTags->{
    "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
     "Compile", "argument typing"}]},
 "TraditionalForm"->{
  Cell[70371, 2742, 774, 21, 74, "Warning",
   CellTags->{
    "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
     "Compile", "argument typing"}]},
 "numerical functions"->{
  Cell[70371, 2742, 774, 21, 74, "Warning",
   CellTags->{
    "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
     "Compile", "argument typing"}]},
 "Compile"->{
  Cell[70371, 2742, 774, 21, 74, "Warning",
   CellTags->{
    "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
     "Compile", "argument typing"}],
  Cell[71148, 2765, 724, 25, 51, "Warning",
   CellTags->{
    "Compile", "machine-precision numbers", "variable declarations", 
     "_Complex", "_Integer"}]},
 "argument typing"->{
  Cell[70371, 2742, 774, 21, 74, "Warning",
   CellTags->{
    "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
     "Compile", "argument typing"}]},
 "machine-precision numbers"->{
  Cell[71148, 2765, 724, 25, 51, "Warning",
   CellTags->{
    "Compile", "machine-precision numbers", "variable declarations", 
     "_Complex", "_Integer"}]},
 "variable declarations"->{
  Cell[71148, 2765, 724, 25, 51, "Warning",
   CellTags->{
    "Compile", "machine-precision numbers", "variable declarations", 
     "_Complex", "_Integer"}]},
 "_Complex"->{
  Cell[71148, 2765, 724, 25, 51, "Warning",
   CellTags->{
    "Compile", "machine-precision numbers", "variable declarations", 
     "_Complex", "_Integer"}]},
 "_Integer"->{
  Cell[71148, 2765, 724, 25, 51, "Warning",
   CellTags->{
    "Compile", "machine-precision numbers", "variable declarations", 
     "_Complex", "_Integer"}]},
 "Guessing variable types"->{
  Cell[72861, 2833, 1025, 36, 74, "Warning",
   CellTags->{"Guessing variable types", "local variable", "JuliaCompile"}]},
 "local variable"->{
  Cell[72861, 2833, 1025, 36, 74, "Warning",
   CellTags->{"Guessing variable types", "local variable", "JuliaCompile"}]},
 "JuliaCompile"->{
  Cell[72861, 2833, 1025, 36, 74, "Warning",
   CellTags->{"Guessing variable types", "local variable", "JuliaCompile"}]},
 "FixedPoint"->{
  Cell[74594, 2898, 959, 18, 118, "Text",
   CellTags->{
    "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
     "SameTest", "pure function", "True"}]},
 "FixedPointList"->{
  Cell[74594, 2898, 959, 18, 118, "Text",
   CellTags->{
    "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
     "SameTest", "pure function", "True"}]},
 "fractal sets"->{
  Cell[74594, 2898, 959, 18, 118, "Text",
   CellTags->{
    "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
     "SameTest", "pure function", "True"}]},
 "stopping condition"->{
  Cell[74594, 2898, 959, 18, 118, "Text",
   CellTags->{
    "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
     "SameTest", "pure function", "True"}]},
 "SameTest"->{
  Cell[74594, 2898, 959, 18, 118, "Text",
   CellTags->{
    "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
     "SameTest", "pure function", "True"}]},
 "True"->{
  Cell[74594, 2898, 959, 18, 118, "Text",
   CellTags->{
    "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
     "SameTest", "pure function", "True"}]},
 "Julia set"->{
  Cell[78233, 3018, 713, 28, 61, "BeginEndQuestion",
   CellTags->"Julia set"]},
 "connected Julia sets"->{
  Cell[82351, 3162, 546, 17, 70, "Text",
   CellTags->{
    "Iterated mapping", "connected Julia sets", "Mandelbrot set"}]},
 "Mandelbrot set"->{
  Cell[82351, 3162, 546, 17, 70, "Text",
   CellTags->{
    "Iterated mapping", "connected Julia sets", "Mandelbrot set"}]},
 "complex argument"->{
  Cell[83265, 3203, 803, 28, 58, "Text",
   CellTags->{
    "complex argument", "n-th roots of unity", "Newton iteration", 
     "Newton's method"}]},
 "n-th roots of unity"->{
  Cell[83265, 3203, 803, 28, 58, "Text",
   CellTags->{
    "complex argument", "n-th roots of unity", "Newton iteration", 
     "Newton's method"}]},
 "Newton iteration"->{
  Cell[83265, 3203, 803, 28, 58, "Text",
   CellTags->{
    "complex argument", "n-th roots of unity", "Newton iteration", 
     "Newton's method"}]},
 "Newton's method"->{
  Cell[83265, 3203, 803, 28, 58, "Text",
   CellTags->{
    "complex argument", "n-th roots of unity", "Newton iteration", 
     "Newton's method"}]},
 "pure function replacement rule"->{
  Cell[84777, 3263, 763, 30, 28, "BrightIdea",
   CellTags->"pure function replacement rule"]},
 "attracting root"->{
  Cell[86272, 3321, 200, 7, 27, "Text",
   CellTags->"attracting root"]},
 "NestList"->{
  Cell[89191, 3427, 807, 23, 72, "Text",
   CellTags->{
    "NestList", "period-doubling route to chaos", 
     "Feigenbaum bifurcation diagram"}]},
 "period-doubling route to chaos"->{
  Cell[89191, 3427, 807, 23, 72, "Text",
   CellTags->{
    "NestList", "period-doubling route to chaos", 
     "Feigenbaum bifurcation diagram"}]},
 "Feigenbaum bifurcation diagram"->{
  Cell[89191, 3427, 807, 23, 72, "Text",
   CellTags->{
    "NestList", "period-doubling route to chaos", 
     "Feigenbaum bifurcation diagram"}]},
 "Feigenbaum"->{
  Cell[90001, 3452, 815, 25, 27, "Input",
   CellTags->"Feigenbaum"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"harmonic approximation", 171361, 5196},
 {"damping", 171455, 5199},
 {"sinusoidal driving term", 171579, 5202},
 {"undamped pendulum", 171697, 5205},
 {"phase-space plot", 171794, 5208},
 {"damped pendulum", 171904, 5211},
 {"period-3 limit cycle", 172005, 5214},
 {"periodic", 172113, 5217},
 {"Poincar\[EAcute] section", 172237, 5220},
 {"driving frequency", 172367, 5223},
 {"transient effects", 172497, 5226},
 {"series solution", 172595, 5229},
 {"linearized equation", 172696, 5232},
 {"Iterated mapping", 172798, 5235},
 {"Bounded absolute value", 173055, 5241},
 {"Module", 173172, 5244},
 {"pure function", 173258, 5247},
 {"Function", 173536, 5254},
 {"rank-2 tensor", 173815, 5261},
 {"TraditionalForm", 174010, 5266},
 {"numerical functions", 174209, 5271},
 {"Compile", 174396, 5276},
 {"argument typing", 174751, 5285},
 {"machine-precision numbers", 174956, 5290},
 {"variable declarations", 175145, 5295},
 {"_Complex", 175321, 5300},
 {"_Integer", 175497, 5305},
 {"Guessing variable types", 175688, 5310},
 {"local variable", 175832, 5313},
 {"JuliaCompile", 175974, 5316},
 {"FixedPoint", 176114, 5319},
 {"FixedPointList", 176312, 5324},
 {"fractal sets", 176508, 5329},
 {"stopping condition", 176710, 5334},
 {"SameTest", 176902, 5339},
 {"True", 177090, 5344},
 {"Julia set", 177283, 5349},
 {"connected Julia sets", 177391, 5352},
 {"Mandelbrot set", 177537, 5356},
 {"complex argument", 177685, 5360},
 {"n-th roots of unity", 177862, 5365},
 {"Newton iteration", 178036, 5370},
 {"Newton's method", 178209, 5375},
 {"pure function replacement rule", 178397, 5380},
 {"attracting root", 178515, 5383},
 {"NestList", 178604, 5386},
 {"period-doubling route to chaos", 178790, 5391},
 {"Feigenbaum bifurcation diagram", 178976, 5396},
 {"Feigenbaum", 179142, 5401}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 45, 0, 29, "OnlineHeader"],
Cell[CellGroupData[{
Cell[638, 25, 123, 5, 100, "Title",
 CounterAssignments->{{"Title", 0}}],
Cell[764, 32, 29, 0, 31, "Author"],
Cell[796, 34, 414, 12, 119, "Address"],
Cell[CellGroupData[{
Cell[1235, 50, 39, 0, 50, "Subsubsection"],
Cell[1277, 52, 212, 5, 28, "Text"],
Cell[1492, 59, 151, 5, 27, "Input",
 InitializationCell->True],
Cell[1646, 66, 85, 2, 27, "Text"],
Cell[1734, 70, 201, 7, 27, "Input",
 InitializationCell->True],
Cell[1938, 79, 263, 8, 28, "Text"],
Cell[2204, 89, 254, 8, 27, "Input",
 InitializationCell->True],
Cell[2461, 99, 402, 11, 27, "Input",
 InitializationCell->True],
Cell[2866, 112, 290, 9, 27, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[3193, 126, 157, 9, 50, "SectionFirst",
 Evaluatable->False],
Cell[3353, 137, 287, 9, 49, "Text"],
Cell[3643, 148, 413, 12, 41, "NumberedEquation"],
Cell[4059, 162, 236, 8, 29, "Text"],
Cell[4298, 172, 406, 16, 27, "Text",
 CellTags->"harmonic approximation"],
Cell[4707, 190, 288, 9, 33, "NumberedEquation"],
Cell[4998, 201, 477, 17, 27, "Text",
 CellTags->{"damping", "sinusoidal driving term"}],
Cell[5478, 220, 549, 17, 33, "NumberedEquation"],
Cell[6030, 239, 271, 9, 49, "Text"],
Cell[CellGroupData[{
Cell[6326, 252, 146, 10, 68, "Subsection"],
Cell[6475, 264, 188, 6, 27, "Text",
 CellTags->"undamped pendulum"],
Cell[6666, 272, 358, 11, 27, "Input"],
Cell[7027, 285, 1633, 49, 125, "BeginEndQuestion",
 CellTags->"phase-space plot"],
Cell[CellGroupData[{
Cell[8685, 338, 32, 0, 50, "Subsubsection"],
Cell[CellGroupData[{
Cell[8742, 342, 806, 24, 27, "Input"],
Cell[9551, 368, 872, 25, 27, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[10460, 398, 477, 15, 27, "Input"],
Cell[10940, 415, 17511, 749, 356, 13751, 684, "GraphicsData", "PostScript", \
"Graphics"],
Cell[28454, 1166, 166, 5, 27, "Output"]
}, Closed]],
Cell[28635, 1174, 391, 12, 49, "Warning"],
Cell[29029, 1188, 430, 14, 82, "BeginEndQuestion"],
Cell[29462, 1204, 412, 15, 61, "BeginEndQuestion"],
Cell[29877, 1221, 19, 0, 37, "Answer"],
Cell[29899, 1223, 744, 25, 89, "BeginEndQuestion"],
Cell[30646, 1250, 19, 0, 37, "Answer"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[30714, 1256, 144, 10, 39, "Subsection"],
Cell[30861, 1268, 207, 6, 27, "Text",
 CellTags->"damped pendulum"],
Cell[31071, 1276, 512, 15, 27, "Input"],
Cell[31586, 1293, 740, 26, 82, "BeginEndQuestion"],
Cell[32329, 1321, 19, 0, 37, "Answer"]
}, Closed]],
Cell[CellGroupData[{
Cell[32385, 1326, 151, 10, 39, "Subsection"],
Cell[32539, 1338, 132, 5, 27, "Text"],
Cell[32674, 1345, 614, 18, 27, "Input"],
Cell[33291, 1365, 1526, 46, 128, "BeginEndQuestion"],
Cell[34820, 1413, 18, 0, 37, "Answer"],
Cell[34841, 1415, 1169, 41, 82, "BeginEndQuestion"],
Cell[36013, 1458, 18, 0, 37, "Answer"],
Cell[36034, 1460, 291, 9, 49, "Text",
 CellTags->{"period-3 limit cycle", "periodic"}],
Cell[36328, 1471, 291, 7, 49, "Text",
 CellTags->{"Poincar\[EAcute] section", "driving frequency"}],
Cell[36622, 1480, 346, 12, 66, "BeginEndQuestion"],
Cell[36971, 1494, 140, 4, 27, "Text",
 CellTags->"transient effects"],
Cell[37114, 1500, 987, 35, 82, "BeginEndQuestion"],
Cell[38104, 1537, 18, 0, 37, "Answer"]
}, Closed]],
Cell[CellGroupData[{
Cell[38159, 1542, 144, 10, 39, "Subsection"],
Cell[38306, 1554, 582, 20, 50, "Text",
 CellTags->"series solution"],
Cell[CellGroupData[{
Cell[38913, 1578, 394, 13, 28, "Input"],
Cell[39310, 1593, 4652, 146, 85, "Output"]
}, Closed]],
Cell[43977, 1742, 330, 12, 27, "Text"],
Cell[CellGroupData[{
Cell[44332, 1758, 195, 6, 28, "Input"],
Cell[44530, 1766, 1873, 60, 44, "Output"]
}, Closed]],
Cell[46418, 1829, 1405, 51, 74, "Text"],
Cell[CellGroupData[{
Cell[47848, 1884, 97, 2, 27, "Input"],
Cell[47948, 1888, 3308, 120, 85, "Output"]
}, Closed]],
Cell[51271, 2011, 828, 30, 50, "Text"],
Cell[CellGroupData[{
Cell[52124, 2045, 403, 14, 31, "Input"],
Cell[52530, 2061, 2418, 82, 57, "Output"]
}, Closed]],
Cell[54963, 2146, 236, 7, 49, "Text"],
Cell[CellGroupData[{
Cell[55224, 2157, 118, 3, 27, "Input"],
Cell[55345, 2162, 1737, 53, 44, "Output"]
}, Closed]],
Cell[57097, 2218, 401, 15, 27, "Text"],
Cell[CellGroupData[{
Cell[57523, 2237, 330, 11, 27, "Input"],
Cell[57856, 2250, 688, 22, 48, "Output"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[58593, 2278, 170, 10, 39, "Subsection"],
Cell[58766, 2290, 64, 0, 70, "Text"],
Cell[58833, 2292, 358, 11, 70, "NumberedEquation"],
Cell[59194, 2305, 963, 40, 70, "BeginEndQuestion"],
Cell[60160, 2347, 314, 13, 70, "Text",
 CellTags->"linearized equation"],
Cell[60477, 2362, 324, 10, 70, "NumberedEquation"],
Cell[60804, 2374, 605, 25, 70, "BeginEndQuestion"],
Cell[61412, 2401, 18, 0, 70, "Answer"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[61479, 2407, 116, 8, 82, "Section"],
Cell[61598, 2417, 96, 2, 27, "Text"],
Cell[CellGroupData[{
Cell[61719, 2423, 138, 10, 68, "Subsection"],
Cell[61860, 2435, 881, 30, 72, "Text",
 CellTags->{"Iterated mapping", "Bounded absolute value"}],
Cell[62744, 2467, 1285, 49, 100, "BeginEndQuestion"],
Cell[64032, 2518, 18, 0, 37, "Answer"],
Cell[64053, 2520, 864, 30, 72, "Text",
 CellTags->"Module"],
Cell[64920, 2552, 781, 25, 31, "Input"],
Cell[65704, 2579, 428, 15, 28, "Text",
 CellTags->{"pure function", "Function"}],
Cell[66135, 2596, 880, 27, 31, "Input"],
Cell[67018, 2625, 87, 2, 27, "Text"],
Cell[CellGroupData[{
Cell[67130, 2631, 658, 19, 27, "Input"],
Cell[67791, 2652, 103, 2, 27, "Output"]
}, Closed]],
Cell[CellGroupData[{
Cell[67931, 2659, 660, 19, 27, "Input"],
Cell[68594, 2680, 103, 2, 27, "Output"]
}, Closed]],
Cell[68712, 2685, 391, 11, 50, "Text"],
Cell[69106, 2698, 993, 31, 60, "Input"],
Cell[70102, 2731, 266, 9, 61, "BeginEndQuestion"],
Cell[70371, 2742, 774, 21, 74, "Warning",
 CellTags->{
  "rank-2 tensor", "TraditionalForm", "numerical functions", "Function", 
   "Compile", "argument typing"}],
Cell[71148, 2765, 724, 25, 51, "Warning",
 CellTags->{
  "Compile", "machine-precision numbers", "variable declarations", "_Complex",
    "_Integer"}],
Cell[71875, 2792, 485, 17, 50, "Warning"],
Cell[72363, 2811, 162, 6, 60, "Input"],
Cell[72528, 2819, 38, 0, 27, "Text"],
Cell[72569, 2821, 289, 10, 27, "Input"],
Cell[72861, 2833, 1025, 36, 74, "Warning",
 CellTags->{"Guessing variable types", "local variable", "JuliaCompile"}],
Cell[73889, 2871, 702, 25, 82, "BeginEndQuestion"],
Cell[74594, 2898, 959, 18, 118, "Text",
 CellTags->{
  "FixedPoint", "FixedPointList", "fractal sets", "stopping condition", 
   "SameTest", "pure function", "True"}],
Cell[CellGroupData[{
Cell[75578, 2920, 356, 10, 27, "Input"],
Cell[75937, 2932, 74, 1, 27, "Output"]
}, Closed]],
Cell[76026, 2936, 474, 18, 61, "BeginEndQuestion"],
Cell[76503, 2956, 231, 7, 28, "Text"],
Cell[76737, 2965, 728, 23, 42, "Input"],
Cell[77468, 2990, 762, 26, 51, "Text"],
Cell[78233, 3018, 713, 28, 61, "BeginEndQuestion",
 CellTags->"Julia set"],
Cell[78949, 3048, 1285, 36, 160, "BeginEndQuestion"],
Cell[80237, 3086, 772, 26, 49, "Text"],
Cell[81012, 3114, 1152, 31, 95, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[82201, 3150, 147, 10, 68, "Subsection"],
Cell[82351, 3162, 546, 17, 70, "Text",
 CellTags->{"Iterated mapping", "connected Julia sets", "Mandelbrot set"}],
Cell[82900, 3181, 181, 5, 70, "BeginEndQuestion"]
}, Closed]],
Cell[CellGroupData[{
Cell[83118, 3191, 144, 10, 39, "Subsection"],
Cell[83265, 3203, 803, 28, 58, "Text",
 CellTags->{
  "complex argument", "n-th roots of unity", "Newton iteration", 
   "Newton's method"}],
Cell[CellGroupData[{
Cell[84093, 3235, 450, 15, 54, "Input"],
Cell[84546, 3252, 216, 8, 45, "Output"]
}, Closed]],
Cell[84777, 3263, 763, 30, 28, "BrightIdea",
 CellTags->"pure function replacement rule"],
Cell[85543, 3295, 37, 0, 27, "Text"],
Cell[85583, 3297, 686, 22, 52, "Input"],
Cell[86272, 3321, 200, 7, 27, "Text",
 CellTags->"attracting root"],
Cell[86475, 3330, 1046, 36, 83, "BeginEndQuestion"],
Cell[87524, 3368, 18, 0, 37, "Answer"],
Cell[87545, 3370, 345, 10, 50, "Text"],
Cell[87893, 3382, 1099, 28, 93, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[89029, 3415, 159, 10, 68, "Subsection"],
Cell[89191, 3427, 807, 23, 72, "Text",
 CellTags->{
  "NestList", "period-doubling route to chaos", 
   "Feigenbaum bifurcation diagram"}],
Cell[90001, 3452, 815, 25, 27, "Input",
 CellTags->"Feigenbaum"],
Cell[90819, 3479, 1080, 34, 104, "BeginEndQuestion"],
Cell[91902, 3515, 18, 0, 37, "Answer"],
Cell[91923, 3517, 658, 23, 84, "BeginEndQuestion"],
Cell[92584, 3542, 18, 0, 37, "Answer"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

