(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    188230,       5580]
NotebookOptionsPosition[     86484,       3333]
NotebookOutlinePosition[    178799,       5315]
CellTagsIndexPosition[    176810,       5260]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Computational Physics", "OnlineHeader"],

Cell[CellGroupData[{

Cell["Exam 2003", "Title"],

Cell[TextData[{
 "Department of Physics\nUniversity of Western Australia\n35 Stirling Highway\
\nCrawley WA 6009\nAUSTRALIA\n\nURL: ",
 ButtonBox["physics.uwa.edu.au/Physics/Courses/Third_Year/Computational_\
Physics.html",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://physics.uwa.edu.au/Courses/Third_Year/Computational_Physics.\
html"], None}]
}], "Address"],

Cell[CellGroupData[{

Cell["Instructions", "Subsection"],

Cell["\<\
This exam, worth 40% of the total mark for Computational Physics, is due in \
on Friday May 2 at 4pm.\
\>", "Text"],

Cell[TextData[{
 "Attempt 5 of 6 questions. The marks for each question and each part is \
indicated in red brackets (",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", ",
 StyleBox["[", "Marks"],
 StyleBox["n", "Marks",
  FontSlant->"Italic"],
 StyleBox["]", "Marks"],
 ") and, obviously, the marks provide a good guide to the question's \
difficulty. Bonus marks will be given for elegant or unconventional \
solutions."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plagiarism", "Subsection"],

Cell[TextData[{
 "I quote from the Departmental ",
 StyleBox["Guidelines on Plagiarism",
  FontSlant->"Italic"],
 ":"
}], "Text"],

Cell["\<\
Like the scientific process, assessment of students relies on the integrity \
of the participants. The Department expects that any piece of work submitted \
by a student for assessment will be essentially their own work, and that \
contributions of others to that work will be appropriately acknowledged. In \
essence, students are expected to write their own essays and assignments, \
just as they are expected to sit the exams themselves.\
\>", "Quote"],

Cell["\<\
Students should generally avoid verbatim copying of published work, even when \
the work is cited. They are strongly encouraged to express their knowledge \
and thoughts in their own words, rather than those of others, as this greatly \
assists the learning process. It is acknowledged however that in some \
circumstances it is desirable to quote directly from a published work.\
\>", "Quote"],

Cell[TextData[{
 "Please do not leave copies of your working Notebooks in public locations, \
such as on the computers in the second- or third-year laboratory. I recommend \
that you backup your solutions to a password-secured area, such as to your \
tartarus account. Note that, when I mark the exam papers, I find it \
particularly easy to spot answers, or ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " code, that is common to more than one student."
}], "Warning"]
}, Closed]],

Cell[CellGroupData[{

Cell["Submitting your Solution", "Subsection"],

Cell[TextData[{
 "Name your exam solution using your initials, ",
 StyleBox["e.g.",
  FontSlant->"Italic"],
 ", ",
 StyleBox["PCA.nb", "InlineInputTraditionalForm"],
 ", and submit to ",
 ButtonBox["ftp://ftp.physics.uwa.edu.au/incoming/Exam",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["ftp://ftp.physics.uwa.edu.au/incoming/Exam"], None}],
 "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Pre-requisites", "Subsection"],

Cell["\<\
You are asked whether you want to load the following code automatically each \
time the kernel is started.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Plotting", "Subsubsection"],

Cell[TextData[{
 "To improve the appearance of graphics, ",
 StyleBox["TraditionalForm", "InlineInputTraditionalForm"],
 " will be used as the default format type for text that appears in \
graphics,"
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"$FormatType", "=", "TraditionalForm"}], ";"}], 
  TraditionalForm]], "Input",
 InitializationCell->True],

Cell["\<\
and the default style for text in graphics is set as follows.\
\>", "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"$TextStyle", "=", 
    RowBox[{"{", 
     RowBox[{"FontSize", "\[Rule]", "10"}], "}"}]}], ";"}], 
  TraditionalForm]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equations", "Subsubsection"],

Cell[TextData[{
 "We modify ",
 Cell[BoxData[
  FormBox[
   StyleBox["Equal", "Input"], TraditionalForm]]],
 " so that ",
 Cell[BoxData[
  FormBox[
   StyleBox["Listable", "Input"], TraditionalForm]]],
 " operations are automatically applied to both sides of any equality:"
}], "Text",
 CellTags->{"Equal", "Listable"}],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Unprotect", "[", "Equal", "]"}], ";"}], TraditionalForm]], "Input",\

 InitializationCell->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"listableQ", "(", "f_", ")"}], ":=", 
   RowBox[{"MemberQ", "(", 
    RowBox[{
     RowBox[{"Attributes", "(", "f", ")"}], ",", "Listable"}], ")"}]}], 
  TraditionalForm]], "Input",
 InitializationCell->True],

Cell[BoxData[
 FormBox[
  RowBox[{"Equal", "/:", " ", 
   RowBox[{"lhs", ":", 
    RowBox[{
     RowBox[{"f_Symbol", "?", "listableQ"}], "[", 
     RowBox[{"___", ",", " ", "_Equal", ",", " ", "___"}], "]"}]}], " ", ":=",
    "\n", "        ", 
   RowBox[{"Thread", "[", " ", 
    RowBox[{
     RowBox[{"Unevaluated", "[", "lhs", "]"}], ",", " ", "Equal"}], " ", 
    "]"}]}], TraditionalForm]], "Input",
 InitializationCell->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Protect", "[", "Equal", "]"}], ";"}], TraditionalForm]], "Input",
 InitializationCell->True],

Cell["Now, we can directly manipulate equations.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Roots in Range", "Subsubsection"],

Cell[BoxData[
 FormBox[
  RowBox[{"Needs", "[", "\"\<Utilities`FilterOptions`\>\"", "]"}], 
  TraditionalForm]], "Input",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"RootsInRange", "[", 
   RowBox[{"\[Delta]_", ",", 
    RowBox[{"{", 
     RowBox[{"\[Lambda]_", ",", "\[Lambda]min_", ",", "\[Lambda]max_"}], 
     "}"}], ",", "opts___"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", ",", "pts", ",", "x", ",", 
      RowBox[{"f", "=", 
       RowBox[{"Function", "[", 
        RowBox[{"\[Lambda]", ",", 
         RowBox[{"Evaluate", "[", "\[Delta]", "]"}]}], "]"}]}]}], "}"}], ",", 
    
    RowBox[{
     RowBox[{"p", "=", 
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{"f", "[", "\[Lambda]", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Lambda]", ",", "\[Lambda]min", ",", "\[Lambda]max"}], 
         "}"}], ",", 
        RowBox[{"Compiled", "\[Rule]", "False"}], ",", 
        RowBox[{"Evaluate", "[", 
         RowBox[{"Sequence", "@@", 
          RowBox[{"FilterRules", "[", 
           RowBox[{
            RowBox[{"Flatten", "[", 
             RowBox[{"{", "opts", "}"}], "]"}], ",", 
            RowBox[{"Options", "[", "Plot", "]"}]}], "]"}]}], "]"}]}], 
       "]"}]}], ";", 
     RowBox[{"pts", "=", 
      RowBox[{"Cases", "[", 
       RowBox[{
        RowBox[{"First", "[", "p", "]"}], ",", 
        RowBox[{
         RowBox[{"Line", "[", 
          RowBox[{"{", "x__", "}"}], "]"}], "\[Rule]", "x"}], ",", 
        "\[Infinity]"}], "]"}]}], ";", 
     RowBox[{"pts", "=", 
      RowBox[{"Map", "[", 
       RowBox[{"First", ",", 
        RowBox[{"Select", "[", 
         RowBox[{
          RowBox[{"Split", "[", 
           RowBox[{"pts", ",", 
            RowBox[{
             RowBox[{
              RowBox[{"Sign", "[", 
               RowBox[{"Last", "[", "#2", "]"}], "]"}], "\[Equal]", 
              RowBox[{"-", 
               RowBox[{"Sign", "[", 
                RowBox[{"Last", "[", "#1", "]"}], "]"}]}]}], "&"}]}], "]"}], 
          ",", 
          RowBox[{
           RowBox[{
            RowBox[{"Length", "[", "#1", "]"}], "\[Equal]", "2"}], "&"}]}], 
         "]"}], ",", 
        RowBox[{"{", "2", "}"}]}], "]"}]}], ";", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"FindRoot", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"f", "[", "\[Lambda]", "]"}], "\[Equal]", "0"}], ",", 
          RowBox[{"{", 
           RowBox[{"\[Lambda]", ",", "##1"}], "}"}], ",", 
          RowBox[{"Evaluate", "[", 
           RowBox[{"Sequence", "@@", 
            RowBox[{"FilterRules", "[", 
             RowBox[{
              RowBox[{"Flatten", "[", 
               RowBox[{"{", "opts", "}"}], "]"}], ",", 
              RowBox[{"Options", "[", "FindRoot", "]"}]}], "]"}]}], "]"}]}], 
         "]"}], "&"}], ")"}], "/@", "pts"}]}]}], "]"}]}]], "Input",
 InitializationCell->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"RootsInRange", "::", "usage"}], "=", 
    "\"\<RootsInRange[f,{x,xmin,xmax}] generates a plot of f as a\nfunction \
of x from xmin to xmax and then uses FindRoot to determine the roots of f\nin \
the range (xmin,xmax).\>\""}], ";"}], TraditionalForm]], "Input",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Load J/Link and URLToStream", "Subsubsection"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Off", "[", 
    RowBox[{
     RowBox[{"General", "::", "\"\<spell\>\""}], ",", 
     RowBox[{"General", "::", "\"\<spell1\>\""}]}], "]"}], ";"}], 
  TraditionalForm]], "Input",
 InitializationCell->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"Needs", "[", "\"\<JLink`\>\"", "]"}], ";"}], 
  TraditionalForm]], "Input",
 PageWidth->Infinity,
 InitializationCell->True,
 ShowSpecialCharacters->False],

Cell["Code for opening and reading from a URL stream.", "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"URLToStream", "::", "usage"}], "=", 
    "\"\<URLToStream[url_String] reads the contents of URL and converts it to \
a stream suitable for processing by Import, Read, ReadList, etc.\>\""}], 
   ";"}], TraditionalForm]], "Input",
 InitializationCell->True],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"URLToStream", "[", "url_String", "]"}], ":=", 
    RowBox[{"JavaBlock", "[", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "u", ",", "s", ",", "stream", ",", "numRead", ",", "outFile", ",", 
         "buf"}], "}"}], ",", 
       RowBox[{
        RowBox[{"InstallJava", "[", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"u", "=", 
         RowBox[{"JavaNew", "[", 
          RowBox[{"\"\<java.net.URL\>\"", ",", "url"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"stream", "=", 
         RowBox[{"u", "[", 
          RowBox[{"openStream", "[", "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"stream", "===", "$Failed"}], ",", 
          RowBox[{"Return", "[", "$Failed", "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"buf", "=", 
         RowBox[{"JavaNew", "[", 
          RowBox[{"\"\<[B\>\"", ",", "5000"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"s", "=", "\"\<\>\""}], ";", "\[IndentingNewLine]", 
        RowBox[{"While", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"numRead", "=", 
             RowBox[{"stream", "[", 
              RowBox[{"read", "[", "buf", "]"}], "]"}]}], ")"}], ">", "0"}], 
          ",", 
          RowBox[{"s", "=", 
           RowBox[{"s", "<>", 
            RowBox[{"FromCharacterCode", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{"#", "<", "0"}], ",", 
                  RowBox[{"#", "+", "256"}], ",", "#"}], "]"}], "&"}], ")"}], 
              "/@", 
              RowBox[{"Take", "[", 
               RowBox[{
                RowBox[{"Val", "[", "buf", "]"}], ",", "numRead"}], "]"}]}], 
             "]"}]}]}]}], "]"}], ";", "\[IndentingNewLine]", " ", 
        RowBox[{"stream", "[", 
         RowBox[{"close", "[", "]"}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"StringToStream", "[", "s", "]"}]}]}], "]"}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], TraditionalForm]], "Input",
 InitializationCell->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". Analysis of Pulsar Timing Data ",
 StyleBox["[20]", "Marks"]
}], "SectionFirst"],

Cell[TextData[{
 "Alex Wolszczan has studied timing variations for the pulsar PSR B1257+12 \
over a 3-year period (see Wolszczan, A. & Frail, D., 1992, ",
 StyleBox["Nature",
  FontSlant->"Italic"],
 ", 255:145, \"A Planetary System around the Millisecond Pulsar PSR1257+12\"; \
Wolszczan, A., 1994, ",
 StyleBox["Science",
  FontSlant->"Italic"],
 ", ",
 StyleBox["264",
  FontWeight->"Bold"],
 ":538, \"Confirmation of Earth-Mass Planets Orbiting the Millisecond Pulsar \
PSR B1257+12\"; ",
 ButtonBox["http://www.astro.psu.edu/users/pspm/planets.html",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.astro.psu.edu/users/pspm/planets.html"], None}],
 "). "
}], "Text",
 CellTags->"pulsar PSR1257+12"],

Cell["\<\
Ordinarily, pulsars are highly regular astronomical clocks. Suppose however \
that the pulsar has one heavy unseen companion.  Then the pulsar will orbit \
around the centre of mass of the combined system, sometimes moving towards \
the earth and sometimes away from it.  This will lead to a sinusoidal \
variation in the timings as measured by an earth-based observer. If there is \
more than one unseen companion the timing variation will be more complicated \
but, to a good approximation, will be a linear superposition of sinusoidal \
variations with differing periods.\
\>", "Text"],

Cell[TextData[{
 "The timing variations for PSR B1257+12 indicate that it is orbited by at \
least two \"planets\".  The data in the file",
 " ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"pulsar", ".", "dat"}], "Input"], TraditionalForm]]],
 " (kindly supplied by Alex Wolszczan and available at ",
 ButtonBox["ftp://ftp.physics.uwa.edu.au/pub/Data/pulsar.dat",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["ftp://ftp.physics.uwa.edu.au/pub/Data/pulsar.dat"], None}],
 ") represent post-fit residuals after fitting out a standard timing model \
assuming a single pulsar (",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", taking into account the earth's orbital motion, ",
 StyleBox["etc",
  FontSlant->"Italic"],
 "). In this exercise you will fit a double planet model to the data and \
determine the orbital periods of each planet."
}], "Text",
 CellTags->{"timing residuals", "Alex Wolszczan"}],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Import the pulsar timing data and call the result ",
 Cell[BoxData[
  FormBox[
   StyleBox["data", "Input"], TraditionalForm]]],
 ". ",
 StyleBox["[1]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". ",
 StyleBox["Select columns 2 (",
  FontSlant->"Plain"],
 StyleBox["epoch",
  FontSlant->"Italic"],
 StyleBox[", ",
  FontSlant->"Plain"],
 StyleBox["i.e.",
  FontSlant->"Italic"],
 StyleBox[", time in decimal years) and 3 (",
  FontSlant->"Plain"],
 StyleBox["residual",
  FontSlant->"Italic"],
 StyleBox[" in ms) of ",
  FontSlant->"Plain"],
 Cell[BoxData[
  FormBox[
   StyleBox["data", "Input"], TraditionalForm]]],
 StyleBox[". It is a good idea to subtract 1990 from all the epoch values. ",
  FontSlant->"Plain"],
 StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". ",
 "Visualise the residuals and describe the basic features. ",
 StyleBox["[2]", "Marks"]
}], "BeginEndQuestion",
 CellTags->"residuals"],

Cell[TextData[{
 "The discrete Fourier transform (DFT) can be used to determine the principal \
frequencies of a periodic system. However, ",
 Cell[BoxData[
  FormBox[
   StyleBox["Fourier", "Input"], TraditionalForm]]],
 " can only be used for ",
 StyleBox["uniformly",
  FontWeight->"Bold"],
 " sampled data. One way to approximately determine the orbital frequencies \
is to interpolate the timing data, re-sample it uniformly, and then apply ",
 Cell[BoxData[
  FormBox[
   StyleBox["Fourier", "Input"], TraditionalForm]]],
 ". This is somewhat clumsy and introduces additional numerical error.  There \
is a simple spectral analysis method that avoids interpolation and \
resampling: For each frequency ",
 Cell[BoxData[
  FormBox["\[Omega]", TraditionalForm]]],
 ", fit ",
 Cell[BoxData[
  FormBox["\[Alpha]", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["\[Beta]", TraditionalForm]]],
 " in ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Alpha]", " ", 
     RowBox[{"sin", "(", 
      RowBox[{"\[Omega]", " ", "t"}], ")"}]}], "+", 
    RowBox[{"\[Beta]", " ", 
     RowBox[{"cos", "(", 
      RowBox[{"\[Omega]", " ", "t"}], ")"}]}]}], TraditionalForm]]],
 " to the data by ",
 StyleBox["linear",
  FontSlant->"Italic"],
 " least-squares (",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", using ",
 Cell[BoxData[
  FormBox[
   StyleBox["Fit", "Input"], TraditionalForm]]],
 "). The spectral energy ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[ScriptCapitalE]", "(", "\[Omega]", ")"}], TraditionalForm]]],
 " is then the square amplitude integrated over one period, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"T", "=", 
    RowBox[{"2", " ", 
     RowBox[{"\[Pi]", "/", "\[Omega]"}]}]}], TraditionalForm]]],
 " (normalised by dividing by ",
 Cell[BoxData[
  FormBox["T", TraditionalForm]]],
 ")."
}], "Text",
 CellGroupingRules->{"SectionGrouping", 55},
 CellTags->{
  "Fourier", "astronomical time-series data", "spectral analysis", 
   "irregularly sampled data", "interpolation", "resampling", 
   "linear least-squares", "spectral energy"}],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Show that the spectral energy of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Alpha]", " ", 
     RowBox[{"sin", "(", 
      RowBox[{"\[Omega]", " ", "t"}], ")"}]}], "+", 
    RowBox[{"\[Beta]", " ", 
     RowBox[{"cos", "(", 
      RowBox[{"\[Omega]", " ", "t"}], ")"}]}]}], TraditionalForm]]],
 " is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[ScriptCapitalE]", "(", "\[Omega]", ")"}], "=", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[Alpha]", "2"], "+", 
       SuperscriptBox["\[Beta]", "2"]}], ")"}], " "}]}], TraditionalForm]]],
 ". ",
 StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Compute and plot ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[ScriptCapitalE]", "(", "\[Omega]", ")"}], TraditionalForm]]],
 " for ",
 Cell[BoxData[
  FormBox[
   StyleBox["data", "Input"], TraditionalForm]]],
 " over ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Omega]", "\[Element]", 
    RowBox[{"[", 
     RowBox[{"1", ",", "50"}], "]"}]}], TraditionalForm]]],
 ". ",
 StyleBox["[5]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Find the two principal frequencies for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Omega]", "\[Element]", 
    RowBox[{"[", 
     RowBox[{"1", ",", "50"}], "]"}]}], TraditionalForm]]],
 ". Since all times are in fractions of decimal years, express the periods \
corresponding to the principal frequencies in days. ",
 StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Since we now have good estimates for the orbital periods, it is easy to \
do a nonlinear fit of a double planet model:"
}], "BeginQuestion"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"model", "(", 
     RowBox[{
     "a_", ",", "b_", ",", "\[Theta]_", ",", "\[Gamma]_", ",", "\[Phi]_", ",",
       "\[Delta]_", ",", "\[Epsilon]_"}], ")"}], "=", 
    RowBox[{
     RowBox[{"a", " ", 
      RowBox[{"sin", "(", 
       RowBox[{
        RowBox[{"\[Theta]", " ", "t"}], "+", "\[Gamma]"}], ")"}]}], "+", 
     RowBox[{"b", " ", 
      RowBox[{"sin", "(", 
       RowBox[{
        RowBox[{"\[Phi]", " ", "t"}], "+", "\[Delta]"}], ")"}]}], "+", 
     "\[Epsilon]"}]}], ";"}], TraditionalForm]], "Input"],

Cell[TextData[{
 "Use the ",
 Cell[BoxData[
  FormBox[
   StyleBox["Statistics`NonlinearFit`", "Input"], TraditionalForm]]],
 " package ",
 StyleBox["and the ",
  FontSlant->"Plain"],
 "principal frequencies",
 StyleBox[" determined in the previous section to determine the optimal \
values of ",
  FontSlant->"Plain"],
 Cell[BoxData[
  FormBox[
   StyleBox["a", "Input"], TraditionalForm]]],
 StyleBox[",  ",
  FontSlant->"Plain"],
 Cell[BoxData[
  FormBox[
   StyleBox["b", "Input"], TraditionalForm]]],
 StyleBox[",  ",
  FontSlant->"Plain"],
 Cell[BoxData[
  FormBox[
   StyleBox["\[Theta]", "Input"], TraditionalForm]]],
 StyleBox[",  ",
  FontSlant->"Plain"],
 Cell[BoxData[
  FormBox[
   StyleBox["\[Gamma]", "Input"], TraditionalForm]]],
 StyleBox[",  ",
  FontSlant->"Plain"],
 Cell[BoxData[
  FormBox[
   StyleBox["\[Phi]", "Input"], TraditionalForm]]],
 StyleBox[",  ",
  FontSlant->"Plain"],
 Cell[BoxData[
  FormBox[
   StyleBox["\[Delta]", "Input"], TraditionalForm]]],
 StyleBox[",  and ",
  FontSlant->"Plain"],
 Cell[BoxData[
  FormBox[
   StyleBox["\[Epsilon]", "Input"], TraditionalForm]]],
 ". The principal frequencies provide good starting values for ",
 Cell[BoxData[
  FormBox[
   StyleBox["\[Theta]", "Input"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   StyleBox["\[Phi]", "Input"], TraditionalForm]]],
 " in the nonlinear fitting routine. The option ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"ShowProgress", "\[Rule]", "True"}], "Input"], 
   TraditionalForm]]],
 " may be useful. Compare the resulting best-fit with the timing residuals \
visualised in question ",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise", "residuals"],
 ". ",
 StyleBox["[5]", "Marks"]
}], "EndQuestion"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". Wavelets ",
 StyleBox["[20]", "Marks"]
}], "Section"],

Cell[TextData[{
 "Wavelets are sets of basis functions used in the analysis of signals and \
images.  In contrast to the Fourier trigonometric basis functions (",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", ",
 "sin and cos), wavelets have both spatial and frequency localisation, making \
them useful for the analysis of sharply-varying or non-periodic signals. The \
(two-scale dilation) equation"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"\[Phi]", "(", "x", ")"}], "=", 
    RowBox[{
     SubsuperscriptBox["\[Sum]", 
      RowBox[{"k", "=", "0"}], "n"], 
     RowBox[{
      SubscriptBox["c", "k"], 
      RowBox[{"\[Phi]", "(", 
       RowBox[{
        RowBox[{"2", "x"}], "-", "k"}], ")"}]}]}]}], ","}], 
  TraditionalForm]], "NumberedEquation",
 CellTags->"two-scale dilation equation"],

Cell["with boundary condition", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"\[Phi]", "(", "x", ")"}], "=", 
    RowBox[{"0", Cell[" for "], 
     FormBox[
      RowBox[{"x", "\[LessEqual]", "0"}],
      TraditionalForm], Cell[" or "], " ", 
     FormBox[
      RowBox[{"x", "\[GreaterEqual]", "n"}],
      TraditionalForm]}]}], ","}], TraditionalForm]], "NumberedEquation",
 CellTags->"boundary conditions"],

Cell[TextData[{
 "arises in discrete wavelet theory. In this question you will use matrix \
methods and recursion to solve equation (",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Equation", "two-scale dilation equation"],
 ") for the specific case of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "5"}], TraditionalForm]]],
 "."
}], "Text",
 CellTags->"wavelet theory"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". For ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "5"}], TraditionalForm]]],
 ", the boundary condition (",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Equation", "boundary conditions"],
 ") implies that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Phi]", "(", "0", ")"}], "=", "0"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Phi]", "(", "5", ")"}], "=", "0"}], TraditionalForm]]],
 ". Using this and equation (",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Equation", "two-scale dilation equation"],
 "), show that the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Phi]", "(", "i", ")"}], TraditionalForm]]],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", "2", ",", "3", ",", "4"}], 
   TraditionalForm]]],
 ", satisfy an eigenvalue equation of the form"
}], "BeginQuestion"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     StyleBox["C",
      FontWeight->"Bold"], ".", 
     RowBox[{"(", GridBox[{
        {
         RowBox[{"\[Phi]", "(", "1", ")"}]},
        {
         RowBox[{"\[Phi]", "(", "2", ")"}]},
        {
         RowBox[{"\[Phi]", "(", "3", ")"}]},
        {
         RowBox[{"\[Phi]", "(", "4", ")"}]}
       }], ")"}]}], "=", 
    RowBox[{"(", GridBox[{
       {
        RowBox[{"\[Phi]", "(", "1", ")"}]},
       {
        RowBox[{"\[Phi]", "(", "2", ")"}]},
       {
        RowBox[{"\[Phi]", "(", "3", ")"}]},
       {
        RowBox[{"\[Phi]", "(", "4", ")"}]}
      }], ")"}]}], ","}], TraditionalForm]], "NumberedEquation",
 CellTags->"eigenvalue equation"],

Cell[TextData[{
 "and determine the matrix ",
 Cell[BoxData[
  FormBox[
   StyleBox["C",
    FontWeight->"Bold"], TraditionalForm]]],
 ". Note that the eigenvalue equation (",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Equation", "eigenvalue equation"],
 ") only determines the values of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Phi]", "(", "i", ")"}], TraditionalForm]]],
 " up to a multiplicative constant. ",
 StyleBox["[3]", "Marks"]
}], "EndQuestion"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Applying a set of normalisation, approximation, and orthogonality \
conditions to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Phi]", "(", "x", ")"}], TraditionalForm]]],
 ", yields a system of equations for the constants, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "k"], TraditionalForm]]],
 ":"
}], "BeginQuestion"],

Cell[BoxData[
 FormBox[GridBox[{
    {
     RowBox[{
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Sum]", 
         RowBox[{"k", "=", "0"}], "5"], 
        SubscriptBox["c", "k"]}], "=", "2"}], ","}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Sum]", 
         RowBox[{"k", "=", "0"}], "3"], 
        RowBox[{
         SubscriptBox["c", "k"], 
         SubscriptBox["c", 
          RowBox[{"k", "+", "2"}]]}]}], "=", "0"}], ","}]},
    {
     RowBox[{
      RowBox[{
       SubsuperscriptBox["\[Sum]", 
        RowBox[{"k", "=", "0"}], "1"], 
       RowBox[{
        SubscriptBox["c", "k"], 
        SubscriptBox["c", 
         RowBox[{"k", "+", "4"}]]}]}], "=", "0"}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Sum]", 
         RowBox[{"k", "=", "0"}], "5"], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "k"], " ", 
         SubscriptBox["c", "k"]}]}], "=", "0"}], ","}]},
    {
     RowBox[{
      RowBox[{
       RowBox[{
        SubsuperscriptBox["\[Sum]", 
         RowBox[{"k", "=", "0"}], "5"], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"-", "1"}], ")"}], "k"], "k", " ", 
         SubscriptBox["c", "k"]}]}], "=", "0"}], ","}]},
    {
     RowBox[{
      RowBox[{
       SubsuperscriptBox["\[Sum]", 
        RowBox[{"k", "=", "0"}], "5"], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], "k"], 
        SuperscriptBox["k", "2"], " ", 
        SubscriptBox["c", "k"]}]}], "=", "0."}]}
   }], TraditionalForm]], "NumberedEquation",
 GridBoxOptions->{
 GridBoxAlignment->{
  "Columns" -> {{"="}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
   "RowsIndexed" -> {}}},
 CellTags->"coefficient conditions"],

Cell[TextData[{
 "Note that the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "k"], TraditionalForm]]],
 " are non-zero only for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"k", "=", "0"}], ",", "1", ",", "\[Ellipsis]", ",", "5"}], 
   TraditionalForm]]],
 ". Determine the ",
 StyleBox["exact",
  FontSlant->"Italic"],
 " values of the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "k"], TraditionalForm]]],
 " by selecting the ",
 StyleBox["real",
  FontSlant->"Italic"],
 " solution to equation (",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Equation", "coefficient conditions"],
 ") with largest positive value of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "0"], TraditionalForm]]],
 ". ",
 StyleBox["[2]", "Marks"]
}], "EndQuestion"]
}, Open  ]],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Compute the eigenvector of ",
 Cell[BoxData[
  FormBox[
   StyleBox["C",
    FontWeight->"Bold"], TraditionalForm]]],
 " corresponding to unit eigenvalue and impose the normalisation condition, \
",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "4"], 
     RowBox[{"\[Phi]", "(", "i", ")"}]}], "=", "1"}], TraditionalForm]]],
 ", to determine the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Phi]", "(", "i", ")"}], TraditionalForm]]],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", "2", ",", "3", ",", "4"}], 
   TraditionalForm]]],
 ". ",
 StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Using the values of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Phi]", "(", "i", ")"}], TraditionalForm]]],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"i", "=", "0"}], ",", "1", ",", "\[Ellipsis]", ",", "5"}], 
   TraditionalForm]]],
 ", and the boundary conditions (",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Equation", "boundary conditions"],
 "), implement the recursive equation (",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Equation", "two-scale dilation equation"],
 ") using dynamic programming. As a check, the exact value of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Phi]", "(", 
    FractionBox["5", "2"], ")"}], TraditionalForm]]],
 " is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["5", "208"], " ", 
    RowBox[{"(", 
     RowBox[{"31", "-", 
      RowBox[{"10", " ", 
       SqrtBox["10"]}]}], ")"}]}], TraditionalForm]]],
 ". ",
 StyleBox["[1]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ".  Compute ",
 StyleBox["approximate ",
  FontSlant->"Italic"],
 "numerical values of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Phi]", "(", "x", ")"}], TraditionalForm]]],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "=", 
     FractionBox["1", "128"]}], ",", 
    FractionBox["2", "128"], ",", 
    FractionBox["3", "128"], ",", "\[Ellipsis]", ",", 
    RowBox[{"5", "-", 
     FractionBox["1", "128"]}]}], TraditionalForm]]],
 ". Use ",
 Cell[BoxData[
  FormBox[
   StyleBox["ListPlot", "Input"], TraditionalForm]]],
 " to visualise the solution to equation (",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Equation", "two-scale dilation equation"],
 "), ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Phi]", "(", "x", ")"}], TraditionalForm]]],
 ". ",
 StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". The Fourier transform ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["\[Phi]", "^"], "(", "\[Omega]", ")"}], TraditionalForm]]],
 " of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Phi]", "(", "x", ")"}], TraditionalForm]]],
 " is defined, as usual, by ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["\[Phi]", "^"], "(", "\[Omega]", ")"}], "=", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
     RowBox[{
      RowBox[{"\[Phi]", "(", "x", ")"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]", " ", "x"}]], 
      RowBox[{"\[DifferentialD]", "x"}]}]}]}], TraditionalForm]]],
 ". Introducing ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[ScriptCapitalH]", "(", "\[Omega]", ")"}], "=", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"k", "=", "0"}], "n"], 
      RowBox[{
       SubscriptBox["c", "k"], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", "k", " ", "\[Omega]"}]]}]}]}]}],
    TraditionalForm]]],
 ", and given that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "\[Infinity]"}], "\[Infinity]"], 
     RowBox[{
      RowBox[{"\[Phi]", "(", "x", ")"}], 
      RowBox[{"\[DifferentialD]", "x"}]}]}], "=", "1"}], TraditionalForm]]],
 ", use equation (",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Equation", "two-scale dilation equation"],
 ") to show that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["\[Phi]", "^"], "(", "\[Omega]", ")"}], TraditionalForm]]],
 " satisfies ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["\[Phi]", "^"], "(", "\[Omega]", ")"}], "=", 
    RowBox[{
     RowBox[{"\[ScriptCapitalH]", "(", 
      FractionBox["\[Omega]", "2"], ")"}], 
     RowBox[{
      OverscriptBox["\[Phi]", "^"], "(", 
      FractionBox["\[Omega]", "2"], ")"}]}]}], TraditionalForm]]],
 " and hence that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["\[Phi]", "^"], "(", "\[Omega]", ")"}], "=", 
    RowBox[{
     UnderoverscriptBox["\[Product]", 
      RowBox[{"i", "=", "1"}], "\[Infinity]"], 
     RowBox[{"\[ScriptCapitalH]", "(", 
      FractionBox["\[Omega]", 
       SuperscriptBox["2", "i"]], ")"}]}]}], TraditionalForm]]],
 ". ",
 StyleBox["[6]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Compute and simplify \[ScriptCapitalH](\[Omega]) for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "=", "5"}], TraditionalForm]]],
 ". Plot ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[LeftBracketingBar]", 
    RowBox[{
     OverscriptBox["\[Phi]", "^"], "(", "\[Omega]", ")"}], 
    "\[RightBracketingBar]"}], TraditionalForm]]],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Omega]", "\[Element]", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], "\[Pi]"}], ",", 
      RowBox[{"6", "\[Pi]"}]}], "]"}]}], TraditionalForm]]],
 " by suitably truncating the infinite product expansion of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["\[Phi]", "^"], "(", "\[Omega]", ")"}], TraditionalForm]]],
 ". ",
 StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". Green Function Solution to an Inverse Problem ",
 StyleBox["[20]", "Marks"]
}], "Section"],

Cell[TextData[{
 "A powerful and general method for solving inhomogeneous differential \
equations such as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"L", "[", 
     RowBox[{"f", "(", "x", ")"}], "]"}], "=", 
    RowBox[{"g", "(", "x", ")"}]}], TraditionalForm]]],
 ", where ",
 Cell[BoxData[
  FormBox["L", TraditionalForm]]],
 " is a differential operator with homogenous boundary conditions, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"f", "(", "a", ")"}], "=", "0"}], ",", " ", 
    RowBox[{
     RowBox[{"f", "(", "b", ")"}], "=", "0"}]}], TraditionalForm]]],
 ", is provided by the ",
 StyleBox["Green function",
  FontSlant->"Italic"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"G", "(", 
    RowBox[{"x", ",", "y"}], ")"}], TraditionalForm]]],
 ", which formally satisfies ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"L", "[", 
     RowBox[{"G", "(", 
      RowBox[{"x", ",", "y"}], ")"}], "]"}], "=", 
    RowBox[{"\[Delta]", "(", 
     RowBox[{"x", "-", "y"}], ")"}]}], TraditionalForm]]],
 ", where \[Delta] is the ",
 StyleBox["Dirac delta function",
  FontSlant->"Italic"],
 " (distribution), and the (homogenous) boundary conditions"
}], "Text",
 CellTags->{"Green function", "Dirac delta function", "distribution"}],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     RowBox[{"G", "(", 
      RowBox[{"a", ",", "y"}], ")"}], "=", "0"}], ",", " ", 
    RowBox[{
     RowBox[{"G", "(", 
      RowBox[{"b", ",", "y"}], ")"}], "=", "0"}], ",", " ", 
    RowBox[{
     RowBox[{"G", "(", 
      RowBox[{"x", ",", "a"}], ")"}], "=", "0"}], ",", " ", 
    RowBox[{
     RowBox[{"G", "(", 
      RowBox[{"x", ",", "b"}], ")"}], "=", "0."}]}]}], 
  TraditionalForm]], "NumberedEquation",
 CellTags->"homogenous boundary conditions"],

Cell["\<\
Green functions are due to George Green (1793-1841), an English mathematician \
whose work was not appreciated during his lifetime\[ThinSpace]\[LongDash]\
\[ThinSpace]largely due to his unusual methodology.\
\>", "Text"],

Cell[TextData[{
 "The strength of the method is that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"G", "(", 
    RowBox[{"x", ",", "y"}], ")"}], TraditionalForm]]],
 " is ",
 StyleBox["independent",
  FontSlant->"Italic"],
 " of the inhomogeneous part of the differential equation, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", "x", ")"}], TraditionalForm]]],
 ". The solution to the differential equation is"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"f", "(", "x", ")"}], "=", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", "a", "b"], " ", 
    RowBox[{
     RowBox[{"G", "(", 
      RowBox[{"x", ",", "y"}], ")"}], 
     RowBox[{"g", "(", "y", ")"}], 
     RowBox[{
      RowBox[{"\[DifferentialD]", "y"}], "."}]}]}]}], 
  TraditionalForm]], "NumberedEquation",
 CellTags->"solution"],

Cell["\<\
Consider the differential equation describing a forced simple harmonic \
oscillator:\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "\[DoublePrime]"], "(", "t", ")"}], "+", 
     RowBox[{"x", "(", "t", ")"}]}], "=", 
    RowBox[{"g", "(", "t", ")"}]}], ","}], 
  TraditionalForm]], "NumberedEquation",
 CellTags->"forced simple harmonic oscillator"],

Cell["along with the boundary conditions", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"x", "(", "0", ")"}], "=", 
   RowBox[{
    RowBox[{"x", "(", 
     FractionBox["\[Pi]", "2"], ")"}], "=", "0."}]}], 
  TraditionalForm]], "NumberedEquation",
 CellTags->"boundary conditions"],

Cell[TextData[{
 "The (region-dependent) Green function, independent of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", "t", ")"}], TraditionalForm]]],
 ", is"
}], "Text",
 CellTags->"region-dependent function"]
}, Open  ]],

Cell[BoxData[
 FormBox[
  RowBox[{" ", 
   RowBox[{
    RowBox[{"G", "(", 
     RowBox[{"t", ",", "\[Tau]"}], ")"}], "=", 
    RowBox[{
     RowBox[{
      StyleBox["{",
       SpanMaxSize->Infinity], GridBox[{
        {
         RowBox[{
          RowBox[{
           RowBox[{"-", "cos"}], 
           RowBox[{"(", "\[Tau]", ")"}], " ", 
           RowBox[{"sin", "(", "t", ")"}]}], ",", " ", 
          RowBox[{
          "0", "\[LessEqual]", "t", "\[LessEqual]", "\[Tau]", "\[LessEqual]", 
           
           FractionBox["\[Pi]", "2"]}]}]},
        {
         RowBox[{
          RowBox[{
           RowBox[{"-", "cos"}], 
           RowBox[{"(", "t", ")"}], " ", 
           RowBox[{"sin", "(", "\[Tau]", ")"}]}], ",", " ", 
          RowBox[{
          "0", "\[LessEqual]", "\[Tau]", "\[LessEqual]", "t", "\[LessEqual]", 
           
           FractionBox["\[Pi]", "2"]}]}]}
       }], "\[AutoRightMatch]"}], "."}]}]}], 
  TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Implement the Green function. Show that it is continuous. ",
 StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". ",
 "Verify that the Green function satisfies the homogenous boundary conditions \
(",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Equation", "homogenous boundary conditions"],
 ") and the homogenous differential equation, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"L", "[", 
     RowBox[{"G", "(", 
      RowBox[{"t", ",", "\[Tau]"}], ")"}], "]"}], "\[Equal]", "0"}], 
   TraditionalForm]]],
 ", in each region (",
 Cell[BoxData[
  FormBox[
   RowBox[{"0", "\[LessEqual]", "t", "<", "\[Tau]", "\[LessEqual]", 
    FractionBox["\[Pi]", "2"]}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0", "\[LessEqual]", "\[Tau]", "<", "t", "\[LessEqual]", 
    FractionBox["\[Pi]", "2"]}], TraditionalForm]]],
 "). ",
 StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Visualize the Green function to reveal its behaviour on the boundaries \
and determine its symmetry about the diagonal line ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "=", "\[Tau]"}], TraditionalForm]]],
 ". ",
 StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". The Green function has a discontinuous derivative along the line ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "=", "\[Tau]"}], TraditionalForm]]],
 ". Compute the difference in the derivative across this line. \
Differentiation of this step-function discontinuity leads to the Dirac delta \
function (distribution), ",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"L", "[", 
     RowBox[{"G", "(", 
      RowBox[{"t", ",", "\[Tau]"}], ")"}], "]"}], "=", 
    RowBox[{"\[Delta]", "(", 
     RowBox[{"t", "-", "\[Tau]"}], ")"}]}], TraditionalForm]]],
 ". ",
 StyleBox["[1]", "Marks"]
}], "BeginEndQuestion",
 CellTags->"discontinuous derivative"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". For the forcing term ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"g", "(", "t", ")"}], "=", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", "t"], " ", 
     RowBox[{"sin", "(", 
      RowBox[{"10", " ", "t"}], ")"}]}]}], TraditionalForm]]],
 " compute the ",
 StyleBox["exact",
  FontSlant->"Italic"],
 " solution, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "(", "t", ")"}], TraditionalForm]]],
 ", to the differential equation using the Green function and equation (",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Equation", "solution"],
 "). Verify that your solution ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "(", "t", ")"}], TraditionalForm]]],
 " is correct (",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", it satisfies (",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Equation", "forced simple harmonic oscillator"],
 ") and takes into account the boundary conditions). ",
 StyleBox["[4]", "Marks"]
}], "BeginEndQuestion",
 CellTags->"exact solution"],

Cell[CellGroupData[{

Cell[TextData[{
 "Consider the ",
 StyleBox["inverse problem",
  FontSlant->"Italic"],
 " of determining the Inhomogeneous part, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", "t", ")"}], TraditionalForm]]],
 ", of the differential equation by measuring ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "(", "t", ")"}], TraditionalForm]]],
 " at a finite number of times. Discretizing the equation, we obtain the \
following matrix equation:"
}], "Text",
 CellGroupingRules->{"SectionGrouping", 55},
 CellTags->{"discretizing equations", "inverse problem"}],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"x", "(", "t", ")"}], "=", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"\[Pi]", "/", "2"}]], " ", 
      RowBox[{
       RowBox[{"G", "(", 
        RowBox[{"t", ",", "\[Tau]"}], ")"}], 
       RowBox[{"g", "(", "\[Tau]", ")"}], 
       RowBox[{"\[DifferentialD]", 
        RowBox[{"\[Tau]", "\[LongRightArrow]", 
         RowBox[{"x", "(", 
          SubscriptBox["t", "i"], ")"}]}]}]}]}], "=", 
     RowBox[{
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"j", "=", "0"}], "m"], " ", 
       RowBox[{
        RowBox[{"G", "(", 
         RowBox[{
          SubscriptBox["t", "i"], ",", 
          SubscriptBox["\[Tau]", "j"]}], ")"}], 
        RowBox[{"g", "(", 
         SubscriptBox["\[Tau]", "j"], ")"}], 
        RowBox[{
         SubscriptBox["\[Delta]\[Tau]", "j"], "\[LongRightArrow]", 
         SubscriptBox["x", "i"]}]}]}], "=", 
      RowBox[{
       UnderscriptBox["\[Sum]", "j"], 
       RowBox[{
        SubscriptBox["G", 
         RowBox[{"i", "\[InvisibleComma]", "j"}]], 
        SubscriptBox["g", "j"]}]}]}]}]}], ","}], 
  TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["G", 
     RowBox[{"i", "\[InvisibleComma]", "j"}]], "=", 
    RowBox[{
     RowBox[{"G", "(", 
      RowBox[{
       SubscriptBox["t", "i"], ",", 
       SubscriptBox["\[Tau]", "j"]}], ")"}], 
     SubscriptBox["\[Delta]\[Tau]", "j"]}]}], TraditionalForm]]],
 ". The discretized forcing term ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["g", "j"], "\[Congruent]", 
    RowBox[{"g", "(", 
     SubscriptBox["\[Tau]", "j"], ")"}]}], TraditionalForm]]],
 " can be computed from the inverse of the (discretized) Green function,"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["x", "i"], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      UnderscriptBox["\[Sum]", "j"], 
      RowBox[{
       SubscriptBox["G", 
        RowBox[{"i", "\[InvisibleComma]", "j"}]], 
       SubscriptBox["g", "j"]}]}], "\[Implies]", 
     SubscriptBox["g", "j"]}], "=", 
    RowBox[{
     UnderscriptBox["\[Sum]", "i"], 
     RowBox[{
      SuperscriptBox[
       SubscriptBox["G", 
        RowBox[{"i", "\[InvisibleComma]", "j"}]], 
       RowBox[{"-", "1"}]], 
      RowBox[{
       SubscriptBox["x", "i"], "\[CenterDot]"}]}]}]}]}], 
  TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
 "For a list of",
 StyleBox[" equally-spaced",
  FontSlant->"Italic"],
 " data points, this discretization corresponds to the ",
 StyleBox["trapezoid approximation",
  FontSlant->"Italic"],
 " because the Green function vanishes along the boundaries. "
}], "Warning",
 CellTags->{"equally spaced data points", "trapezoid approximation"}],

Cell[TextData[{
 "Note that, in general, the matrix ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["G", 
    RowBox[{"i", "\[InvisibleComma]", "j"}]], TraditionalForm]]],
 " is ",
 StyleBox["rectangular",
  FontSlant->"Italic"],
 " because there can be a ",
 StyleBox["different",
  FontSlant->"Italic"],
 " number of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Tau]", "j"], TraditionalForm]]],
 " samples. Hence no inverse matrix exists in the usual sense. However, \
values of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["g", "j"], "=", 
    RowBox[{"g", "(", 
     SubscriptBox["\[Tau]", "j"], ")"}]}], TraditionalForm]]],
 " can be computed using the pseudo- or Moore-Penrose inverse (",
 Cell[BoxData[
  FormBox[
   StyleBox["PseudoInverse", "Input"], TraditionalForm]]],
 ")."
}], "Text",
 CellTags->{"Moore-Penrose inverse", "PseudoInverse"}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Suppose that, at the times ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["t", "i"], "=", "0"}], ",", 
    FractionBox["\[Pi]", "30"], ",", 
    FractionBox[
     RowBox[{"2", "\[Pi]"}], "30"], ",", "\[Ellipsis]", ",", 
    FractionBox["\[Pi]", "2"]}], TraditionalForm]]],
 ", we make measurements of the displacements ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "i"], "=", 
    RowBox[{"x", "(", 
     SubscriptBox["t", "i"], ")"}]}], TraditionalForm]]],
 ". Using the exact solution found in question ",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise", "exact solution"],
 ", the displacements at these times can be computed. Compute the driving \
term, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["g", "j"], "=", 
    RowBox[{"g", "(", 
     SubscriptBox["\[Tau]", "j"], ")"}]}], TraditionalForm]]],
 ", at the times ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[Tau]", "j"], "=", "0"}], ",", 
    FractionBox["\[Pi]", "40"], ",", 
    FractionBox[
     RowBox[{"2", "\[Pi]"}], "40"], ",", "\[Ellipsis]", ",", 
    FractionBox["\[Pi]", "2"]}], TraditionalForm]]],
 ", by (matrix) multiplying the pseudo-inverse of the discretized product ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["G", 
    RowBox[{"i", "\[InvisibleComma]", "j"}]], TraditionalForm]]],
 " with the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "i"], TraditionalForm]]],
 ". ",
 StyleBox["[5]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Compare the forcing term, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", "t", ")"}], TraditionalForm]]],
 ", and the discretized (inverse) solution, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"g", "(", 
    SubscriptBox["\[Tau]", "j"], ")"}], TraditionalForm]]],
 ", and comment. ",
 StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". Maxwell Construction ",
 StyleBox["[20]", "Marks"]
}], "Section"],

Cell[TextData[{
 "The equation of state of an ideal gas of ",
 Cell[BoxData[
  FormBox["\[ScriptCapitalN]", TraditionalForm]]],
 " noninteracting classical particles reads"
}], "Text",
 CellTags->{"equation of state", "ideal gas"}],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"p", " ", "V"}], "\[Equal]", 
    RowBox[{"\[ScriptCapitalN]", " ", 
     SubscriptBox["k", "B"], "T"}]}], ","}], 
  TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "B"], TraditionalForm]]],
 " is the Boltzmann constant. A simple approximation, taking into account the \
interaction between particles, is the van der Waals equation of state,"
}], "Text",
 CellTags->{"Boltzmann constant", "van der Waals equation"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"p", "+", 
       FractionBox["a", 
        SuperscriptBox["V", "2"]]}], ")"}], 
     RowBox[{"(", 
      RowBox[{"V", "-", "b"}], ")"}]}], "\[Equal]", 
    RowBox[{"\[ScriptCapitalN]", " ", 
     SubscriptBox["k", "B"], "T"}]}], ","}], 
  TraditionalForm]], "NumberedEquation",
 CellTags->"van der Waals"],

Cell[TextData[{
 "with parameters ",
 Cell[BoxData[
  FormBox["a", TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]]],
 ".  As you will see, there exists a critical temperature ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "c"], TraditionalForm]]],
 " below which loops appear in the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "-", "V"}], TraditionalForm]]],
 " diagram.  These loops are forbidden for thermodynamical reasons. For ",
 Cell[BoxData[
  FormBox[
   RowBox[{"T", "<", 
    SubscriptBox["T", "c"]}], TraditionalForm]]],
 ", a phase transition between gas and liquid takes place; at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"T", "=", 
    SubscriptBox["T", "c"]}], TraditionalForm]]],
 " the difference between the liquid and gaseous phases vanishes."
}], "Text"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "c"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "c"], TraditionalForm]]],
 " are determined by the condition that the first and second derivatives of \
",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "(", 
    RowBox[{"V", ",", "T"}], ")"}], TraditionalForm]]],
 " with respect to ",
 Cell[BoxData[
  FormBox["V", TraditionalForm]]],
 " vanish, ",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"\[PartialD]", 
      RowBox[{"p", "(", 
       RowBox[{"V", ",", "T"}], ")"}]}], 
     RowBox[{"\[PartialD]", "V"}],
     MultilineFunction->None], "\[Equal]", "0"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["\[PartialD]", "2"], 
      RowBox[{"p", "(", 
       RowBox[{"V", ",", "T"}], ")"}]}], 
     RowBox[{"\[PartialD]", 
      SuperscriptBox["V", "2"]}],
     MultilineFunction->None], "\[Equal]", "0"}], TraditionalForm]]],
 ". "
}], "Text"]
}, Open  ]],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Determine ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "c"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "c"], TraditionalForm]]],
 ", and the corresponding ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["p", "c"], "=", 
    RowBox[{"p", "(", 
     RowBox[{
      SubscriptBox["V", "c"], ",", 
      SubscriptBox["T", "c"]}], ")"}]}], TraditionalForm]]],
 " for the van der Waals equation (",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Equation", "van der Waals"],
 "). As a check, you should find that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["p", "c"], "=", 
    FractionBox["a", 
     RowBox[{"27", " ", 
      SuperscriptBox["b", "2"]}]]}], TraditionalForm]]],
 ". ",
 StyleBox["[5]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Rescale ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox["V", TraditionalForm]]],
 ", and ",
 Cell[BoxData[
  FormBox["T", TraditionalForm]]],
 " by ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "c"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "c"], TraditionalForm]]],
 ", and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "c"], TraditionalForm]]],
 ", respectively, to obtain a dimensionless form of the van der Waals \
equation. In the following, the dimensionless parameters are denoted using ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["x", "~"], "=", 
    RowBox[{"x", "/", 
     SubscriptBox["x", "c"]}]}], TraditionalForm]]],
 ". ",
 StyleBox["[4]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Plot a set of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["p", "~"], "-", 
    OverscriptBox["V", "~"]}], TraditionalForm]]],
 " curves for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["T", "~"], "=", 
     StyleBox["0.85`",
      StyleBoxAutoDelete->True,
      PrintPrecision->2]}], ",", "0.9`", ",", "\[Ellipsis]", ",", "1.05"}], 
   TraditionalForm]]],
 " over ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0.5", "\[LessEqual]", 
    OverscriptBox["V", "~"], "\[LessEqual]", "5"}], TraditionalForm]]],
 " to visualise the unphysical van der Waals loops which arise for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["T", "~"], "<", 
    StyleBox["1",
     StyleBoxAutoDelete->True,
     PrintPrecision->2]}], TraditionalForm]]],
 ". ",
 StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"],

Cell[CellGroupData[{

Cell[TextData[{
 "Over a certain temperature range, three volumes ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["v", "1"], "\[LessEqual]", 
    SubscriptBox["v", "2"], "\[LessEqual]", 
    SubscriptBox["v", "3"]}], TraditionalForm]]],
 " correspond to each pressure ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["p", "~"], TraditionalForm]]],
 ".  For thermodynamic reasons, the transition from the gas with large volume \
",
 Cell[BoxData[
  FormBox[
   SubscriptBox["v", "3"], TraditionalForm]]],
 ", to the liquid, with small volume ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["v", "1"], TraditionalForm]]],
 ", takes place at the pressure ",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    SubscriptBox["p", "t"], "~"], TraditionalForm]]],
 " for which "
}], "Text",
 CellGroupingRules->{"SectionGrouping", 45}],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Integral]", 
     SubscriptBox[
      SubsuperscriptBox["v", "1", "v"], "3"]], 
    RowBox[{
     RowBox[{
      OverscriptBox["p", "~"], "(", "v", ")"}], 
     RowBox[{"\[DifferentialD]", "v"}]}]}], "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SubscriptBox["v", "3"], "-", 
      SubscriptBox["v", "1"]}], ")"}], 
    RowBox[{
     OverscriptBox[
      SubscriptBox["p", "t"], "~"], "\[CenterDot]"}]}]}], 
  TraditionalForm]], "NumberedEquation",
 CellTags->"equal area"],

Cell[TextData[{
 "At ",
 Cell[BoxData[
  FormBox[
   OverscriptBox[
    SubscriptBox["p", "t"], "~"], TraditionalForm]]],
 ", gas and liquid are simultaneously present for all volumes ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]]],
 " with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["v", "1"], "\[LessEqual]", "v", "\[LessEqual]", 
    SubscriptBox["v", "3"]}], TraditionalForm]]],
 "; one observes a two-phase mixture.  Geometrically, equation (",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Equation", "equal area"],
 ") means that the area between the curve ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["p", "~"], "(", "v", ")"}], TraditionalForm]]],
 " and the straight line ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox[
     SubscriptBox["p", "t"], "~"], "=", "constant"}], TraditionalForm]]],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["v", "1"], "\[LessEqual]", "v", "\[LessEqual]", 
    SubscriptBox["v", "2"]}], TraditionalForm]]],
 " is the same as the corresponding area for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["v", "2"], "\[LessEqual]", "v", "\[LessEqual]", 
    SubscriptBox["v", "3"]}], TraditionalForm]]],
 ". This is known as the ",
 StyleBox["Maxwell construction",
  FontSlant->"Italic"],
 ".We want to construct the line ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox[
     SubscriptBox["p", "t"], "~"], "=", "constant"}], TraditionalForm]]],
 ", the two-phase line. For the two-phase line we need two equations in order \
to determine the two unknown volumes ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["v", "1"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["v", "3"], TraditionalForm]]],
 ":"
}], "Text",
 CellTags->{"two-phase line", "Maxwell construction"}]
}, Open  ]],

Cell[BoxData[
 FormBox[GridBox[{
    {
     RowBox[{
      OverscriptBox["p", "~"], "(", 
      RowBox[{
       SubscriptBox["v", "1"], ",", "t"}], ")"}], "\[Equal]", 
     RowBox[{
      RowBox[{
       OverscriptBox["p", "~"], "(", 
       RowBox[{
        SubscriptBox["v", "3"], ",", "t"}], ")"}], ","}]},
    {
     RowBox[{
      SubscriptBox["\[Integral]", 
       SubscriptBox[
        SubsuperscriptBox["v", "1", "v"], "3"]], 
      RowBox[{
       RowBox[{
        OverscriptBox["p", "~"], "(", 
        RowBox[{"v", ",", "t"}], ")"}], 
       RowBox[{"\[DifferentialD]", "v"}]}]}], "\[Equal]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["v", "3"], "-", 
        SubscriptBox["v", "1"]}], ")"}], 
      RowBox[{
       RowBox[{
        OverscriptBox["p", "~"], "(", 
        RowBox[{
         SubscriptBox["v", "1"], ",", "t"}], ")"}], "."}]}]}
   }], TraditionalForm]], "NumberedEquation",
 CellTags->"two-phase"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". There is no simple analytical solution to equations (",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Equation", "two-phase"],
 ") so, for each temperature, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["T", "~"], "=", 
     StyleBox["0.85`",
      StyleBoxAutoDelete->True,
      PrintPrecision->2]}], ",", "0.9`", ",", "0.95"}], TraditionalForm]]],
 ", determine ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["v", "1"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["v", "3"], TraditionalForm]]],
 " using ",
 Cell[BoxData[
  FormBox[
   StyleBox["FindRoot", "Input"], TraditionalForm]]],
 ". You will need fairly accurate initial guesses \[LongDash] these can be \
obtained from the plots of the unphysical van der Waals ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    OverscriptBox["p", "~"], "-", 
    OverscriptBox["V", "~"]}], TraditionalForm]]],
 " equation in part [c]. ",
 StyleBox["[6]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Display the Maxwell construction for the van der Waals equation for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["T", "~"], "=", 
     StyleBox["0.85`",
      StyleBoxAutoDelete->True,
      PrintPrecision->2]}], ",", "0.9`", ",", "\[Ellipsis]", ",", "1.05"}], 
   TraditionalForm]]],
 ". Physically interpret the lowest three curves (",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ",  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     OverscriptBox["T", "~"], "=", 
     StyleBox["0.85`",
      StyleBoxAutoDelete->True,
      PrintPrecision->2]}], ",", "0.9`", ",", "0.95"}], TraditionalForm]]],
 ") and the two-phase lines. ",
 StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". Normal Modes of a Circular Membrane ",
 StyleBox["[20]", "Marks"]
}], "Section",
 Evaluatable->False,
 AspectRatioFixed->True],

Cell["\<\
If there is no external force, the wave equation for free vibrations of a \
uniform isotropic membrane reads\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["\[PartialD]", "2"], 
      RowBox[{"u", "(", 
       RowBox[{"x", ",", "y", ",", "t"}], ")"}]}], 
     RowBox[{"\[PartialD]", 
      SuperscriptBox["t", "2"]}],
     MultilineFunction->None], "=", 
    RowBox[{
     SuperscriptBox["c", "2"], " ", "\[CapitalDelta]", " ", 
     RowBox[{"u", "(", 
      RowBox[{"x", ",", "y", ",", "t"}], ")"}]}]}], ","}], 
  TraditionalForm]], "NumberedEquation",
 CellTags->"wave equation"],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox["\[CapitalDelta]", TraditionalForm]]],
 " is the two-dimensional Laplacian operator,"
}], "Text",
 CellTags->{"boundary condition", "polar coordinates"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  RowBox[{"\[CapitalDelta]", "=", 
   RowBox[{
    FractionBox[
     SuperscriptBox["\[PartialD]", "2"], 
     RowBox[{"\[PartialD]", 
      SuperscriptBox["x", "2"]}]], "+", 
    RowBox[{
     FractionBox[
      SuperscriptBox["\[PartialD]", "2"], 
      RowBox[{"\[PartialD]", 
       SuperscriptBox["y", "2"]}]], "."}]}]}], 
  TraditionalForm]], "NumberedEquation",
 CellTags->"Laplacian"],

Cell[TextData[{
 "For a circular membrane of radius ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "=", "1"}], TraditionalForm]]],
 " fixed at its edge, polar coordinates ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"r", ",", "\[Theta]"}], ")"}], TraditionalForm]]],
 " are convenient; the boundary condition is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"u", "(", 
     RowBox[{"1", ",", "\[Theta]", ",", "t"}], ")"}], "=", "0"}], 
   TraditionalForm]]],
 " and the Laplacian",
 " (",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Equation", "Laplacian"],
 ") ",
 "reads"
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[CapitalDelta]", "[", "f_", "]"}], ":=", 
   RowBox[{
    RowBox[{
     FractionBox["1", "r"], 
     FractionBox[
      RowBox[{"\[PartialD]", 
       RowBox[{"(", 
        RowBox[{"r", 
         FractionBox[
          RowBox[{"\[PartialD]", "f"}], 
          RowBox[{"\[PartialD]", "r"}]]}], ")"}]}], 
      RowBox[{"\[PartialD]", "r"}]]}], "+", 
    RowBox[{
     FractionBox["1", 
      SuperscriptBox["r", "2"]], 
     FractionBox[
      RowBox[{
       SuperscriptBox["\[PartialD]", "2"], "f"}], 
      RowBox[{"\[PartialD]", 
       SuperscriptBox["\[Theta]", "2"]}]]}]}]}], TraditionalForm]], "Input"]
}, Open  ]],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". ",
 "By hand, or using ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", apply separation of variables, ",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"u", "(", 
     RowBox[{"r", ",", "\[Theta]", ",", "t"}], ")"}], "=", 
    RowBox[{
     RowBox[{"R", "(", "r", ")"}], " ", 
     RowBox[{"\[CapitalTheta]", "(", "\[Theta]", ")"}], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"\[ImaginaryI]", " ", "\[Omega]", " ", "t"}]]}]}], 
   TraditionalForm]]],
 ", and introduce a ",
 StyleBox["separation constant",
  FontSlant->"Italic"],
 ", to reduce equation (",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Equation", "wave equation"],
 ") to a pair of ordinary differential equations. ",
 StyleBox["[3]", "Marks"]
}], "BeginEndQuestion",
 CellTags->"separation of variables"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Solve the differential equation for ",
 Cell[BoxData[
  FormBox["\[CapitalTheta]", TraditionalForm]]],
 ". What condition does this solution place on the separation constant?  ",
 StyleBox["Hint",
  FontSlant->"Italic"],
 ": a physical solution must be single-valued, ",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[CapitalTheta]", "(", 
     RowBox[{"\[Theta]", "+", 
      RowBox[{"2", "m", " ", "\[Pi]"}]}], ")"}], "=", 
    RowBox[{"\[CapitalTheta]", "(", "\[Theta]", ")"}]}], TraditionalForm]]],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", "\[Element]", 
    FormBox[
     TagBox["\[DoubleStruckCapitalZ]",
      Integers& ],
     TraditionalForm]}], TraditionalForm]]],
 ". Hence, choose the separation constant so that you will get trigonometric \
solutions to the ",
 Cell[BoxData[
  FormBox["\[CapitalTheta]", TraditionalForm]]],
 "-equation. ",
 StyleBox["[1]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Determine the differential equation for ",
 Cell[BoxData[
  FormBox["R", TraditionalForm]]],
 ", eliminating ",
 Cell[BoxData[
  FormBox["\[Omega]", TraditionalForm]]],
 " using ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["k", "2"], "=", 
    RowBox[{
     SuperscriptBox["\[Omega]", "2"], "/", 
     SuperscriptBox["c", "2"]}]}], TraditionalForm]]],
 ", and solve this equation (",
 StyleBox["Hint",
  FontSlant->"Italic"],
 ": you should obtain a solution involving a pair of Bessel functions.) \
Produce plots of the linearly independent solutions for a range of values of \
the separation constant. ",
 StyleBox["[4]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Considering the nature of the solution at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "=", "0"}], TraditionalForm]]],
 ", one of the linearly independent solutions can be excluded. Hence write \
down the general solution to equation (",
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Equation", "wave equation"],
 "). ",
 StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Apply the boundary condition, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"u", "(", 
     RowBox[{"1", ",", "\[Theta]", ",", "t"}], ")"}], "=", "0"}], 
   TraditionalForm]]],
 ", to write down an expression which ",
 StyleBox["implicitly",
  FontSlant->"Italic"],
 " determines the allowed values of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "=", 
    RowBox[{
     RowBox[{"\[Omega]", "/", "c"}], "=", 
     RowBox[{"2", "\[Pi]", " ", 
      RowBox[{"\[Nu]", "/", " ", "c"}]}]}]}], TraditionalForm]]],
 ". Determine the ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]]],
 "-values corresponding to the 10 lowest frequencies and, in one plot, \
display the corresponding (unnormalised) radial functions ",
 Cell[BoxData[
  FormBox[
   RowBox[{"R", "(", "r", ")"}], TraditionalForm]]],
 ". ",
 StyleBox["Hint",
  FontSlant->"Italic"],
 ": you may find the ",
 Cell[BoxData[
  FormBox[
   StyleBox["NumericalMath`BesselZeros`", "Input"], TraditionalForm]]],
 " package or the ",
 Cell[BoxData[
  FormBox[
   StyleBox["RootsInRange", "Input"], TraditionalForm]]],
 " function (loaded when you start the kernel) useful. ",
 StyleBox["[8]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Produce an animation of one period (",
 Cell[BoxData[
  FormBox[
   RowBox[{"T", "=", 
    RowBox[{"2", 
     RowBox[{"\[Pi]", "/", "\[Omega]"}]}]}], TraditionalForm]]],
 ") of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"u", "(", 
    RowBox[{"r", ",", "\[Theta]", ",", "t"}], ")"}], TraditionalForm]]],
 " for the third lowest frequency. ",
 StyleBox["Hint",
  FontSlant->"Italic"],
 ": you may find ",
 Cell[BoxData[
  FormBox[
   StyleBox["CylindricalPlot3D", "Input"], TraditionalForm]]],
 " useful. ",
 StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ". Matrix Arithmetic ",
 StyleBox["[20]", "Marks"]
}], "Section"],

Cell[TextData[{
 "The ",
 StyleBox["Pauli spin matrices",
  FontSlant->"Italic"],
 ", "
}], "Text",
 CellTags->"Pauli spin matrices"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[Sigma]", "/:", 
    SubscriptBox["\[Sigma]", "1"], "=", 
    RowBox[{"(", GridBox[{
       {"0", "1"},
       {"1", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], ")"}]}], ";"}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[Sigma]", "/:", 
    SubscriptBox["\[Sigma]", "2"], "=", 
    RowBox[{"(", GridBox[{
       {"0", 
        RowBox[{"-", "\[ImaginaryI]"}]},
       {"\[ImaginaryI]", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], ")"}]}], ";"}], 
  TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"\[Sigma]", "/:", 
    SubscriptBox["\[Sigma]", "3"], "=", 
    RowBox[{"(", GridBox[{
       {"1", "0"},
       {"0", 
        RowBox[{"-", "1"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}], ")"}]}], ";"}], 
  TraditionalForm]], "Input"],

Cell[TextData[{
 "along with the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "\[Cross]", "2"}], TraditionalForm]]],
 " identity matrix:"
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   SubscriptBox["\[ScriptCapitalI]", "n_"], ":=", 
   RowBox[{"IdentityMatrix", "[", "n", "]"}]}], TraditionalForm]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  SubscriptBox["\[ScriptCapitalI]", "2"], TraditionalForm]], "Input"],

Cell[BoxData[
 FormBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0"},
     {"0", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Decimal}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
       "RowsIndexed" -> {}}], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["\<\
are used in a matrix representation of spin operators in quantum mechanics.\
\>", "Text"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". ",
 "Verify that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[Sigma]", "i"], ".", 
     SubscriptBox["\[Sigma]", "i"]}], "=", 
    SubscriptBox["\[ScriptCapitalI]", "2"]}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", "2", ",", "3"}], TraditionalForm]]],
 ". ",
 StyleBox["[1]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Introducing the ",
 StyleBox["commutator bracket",
  FontSlant->"Italic"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"[", 
     RowBox[{"a", ",", "b"}], "]"}], "=", 
    RowBox[{
     RowBox[{"a", ".", "b"}], "-", 
     RowBox[{"b", ".", "a"}]}]}], TraditionalForm]]],
 ", verify that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"[", 
     RowBox[{
      SubscriptBox["\[Sigma]", "i"], ",", 
      SubscriptBox["\[Sigma]", "j"]}], "]"}], "=", 
    RowBox[{"2", "\[ImaginaryI]", " ", 
     SubscriptBox["\[Epsilon]", 
      RowBox[{"i", ",", "j", ",", "k"}]], 
     SubscriptBox["\[Sigma]", "k"]}]}], TraditionalForm]]],
 " where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Epsilon]", 
    RowBox[{"i", ",", "j", ",", "k"}]], TraditionalForm]]],
 " is the (3-component) Levi-Civita tensor which is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"+", "1"}], TraditionalForm]]],
 " if ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"i", ",", "j", ",", "k"}], ")"}], TraditionalForm]]],
 " is a cyclic permutation of the indices, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "1"}], TraditionalForm]]],
 " if ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"i", ",", "j", ",", "k"}], ")"}], TraditionalForm]]],
 " is an anti-cyclic permutation, and ",
 Cell[BoxData[
  FormBox["0", TraditionalForm]]],
 " otherwise. ",
 StyleBox["Hint",
  FontSlant->"Italic"],
 ": there is a very simple and general implementation of this tensor, ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     SubscriptBox["\[Epsilon]", "i__"], ":=", 
     RowBox[{"Signature", "[", 
      RowBox[{"{", "i", "}"}], "]"}]}], "Input"], TraditionalForm]]],
 ". Also, you might find ",
 Cell[BoxData[
  FormBox[
   StyleBox["Permutations", "Input"], TraditionalForm]]],
 " useful. ",
 StyleBox["[4]", "Marks"]
}], "BeginEndQuestion",
 CellTags->"Levi-Civita tensor"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". ",
 "Show that the three matrices, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Sigma]", "i"], TraditionalForm]]],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", "2", ",", "3"}], TraditionalForm]]],
 ", along with unit ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "\[Times]", "2"}], TraditionalForm]]],
 " matrix ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalI]", "2"], TraditionalForm]]],
 " form a complete set of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "\[Times]", "2"}], TraditionalForm]]],
 " matrices in the sense that an ",
 StyleBox["arbitrary",
  FontSlant->"Italic"],
 " complex ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "\[Times]", "2"}], TraditionalForm]]],
 " matrix can be expressed in terms of them. ",
 StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Show that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       StyleBox["\[Sigma]",
        FontWeight->"Bold"], "\[CenterDot]", 
       StyleBox["A",
        FontWeight->"Bold"]}], ")"}], 
     RowBox[{"(", 
      RowBox[{
       StyleBox["\[Sigma]",
        FontWeight->"Bold"], "\[CenterDot]", 
       StyleBox["B",
        FontWeight->"Bold"]}], ")"}]}], "=", 
    RowBox[{
     RowBox[{
      StyleBox["A",
       FontWeight->"Bold"], "\[CenterDot]", 
      StyleBox["B",
       FontWeight->"Bold"]}], "+", 
     RowBox[{"\[ImaginaryI]", " ", 
      RowBox[{
       StyleBox["\[Sigma]",
        FontWeight->"Bold"], "\[CenterDot]", 
       RowBox[{"(", 
        RowBox[{
         StyleBox["A",
          FontWeight->"Bold"], "\[Cross]", 
         StyleBox["B",
          FontWeight->"Bold"]}], ")"}]}]}]}]}], TraditionalForm]]],
 " where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox["\[Sigma]",
     FontWeight->"Bold"], 
    StyleBox["\[Congruent]",
     FontWeight->"Bold"], 
    RowBox[{"(", 
     RowBox[{
      TagBox[
       SubscriptBox["\[Sigma]", "1"],
       HoldForm], ",", 
      TagBox[
       SubscriptBox["\[Sigma]", "2"],
       HoldForm], ",", 
      TagBox[
       SubscriptBox["\[Sigma]", "3"],
       HoldForm]}], ")"}]}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   StyleBox["A",
    FontWeight->"Bold"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   StyleBox["B",
    FontWeight->"Bold"], TraditionalForm]]],
 " are any two vectors. ",
 StyleBox["NB",
  FontSlant->"Italic"],
 ": this identity, as stated, is a typical abuse of notation widely used in \
quantum mechanics texts.  Explicitly, what you are trying to show is that "
}], "BeginQuestion"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["a", "1"], 
       SubscriptBox["\[Sigma]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["a", "2"], 
       SubscriptBox["\[Sigma]", "2"]}], "+", 
      RowBox[{
       SubscriptBox["a", "3"], 
       SubscriptBox["\[Sigma]", "3"]}]}], ")"}], ".", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SubscriptBox["b", "1"], 
       SubscriptBox["\[Sigma]", "1"]}], "+", 
      RowBox[{
       SubscriptBox["b", "2"], 
       SubscriptBox["\[Sigma]", "2"]}], "+", 
      RowBox[{
       SubscriptBox["b", "3"], 
       SubscriptBox["\[Sigma]", "3"]}]}], ")"}]}], "\[Equal]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["a", "1"], ",", 
        SubscriptBox["a", "2"], ",", 
        SubscriptBox["a", "3"]}], "}"}], ".", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["b", "1"], ",", 
        SubscriptBox["b", "2"], ",", 
        SubscriptBox["b", "3"]}], "}"}]}], 
     SubscriptBox["\[ScriptCapitalI]", "2"]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["a", "1"], ",", 
          SubscriptBox["a", "2"], ",", 
          SubscriptBox["a", "3"]}], "}"}], "\[Cross]", 
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["b", "1"], ",", 
          SubscriptBox["b", "2"], ",", 
          SubscriptBox["b", "3"]}], "}"}]}], ")"}], ".", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["\[Sigma]", "1"], ",", 
        SubscriptBox["\[Sigma]", "2"], ",", 
        SubscriptBox["\[Sigma]", "3"]}], "}"}], ".", " ", 
      StyleBox[
       RowBox[{"[", "3", "]"}], "Marks"]}]}]}]}], 
  TraditionalForm]], "NumberedEquation"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". The following set of 5, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"4", "\[Times]", "4"}], TraditionalForm]]],
 ", ",
 StyleBox["Dirac gamma matrices",
  FontSlant->"Italic"],
 " arise in relativistic quantum mechanics:"
}], "BeginQuestion",
 CellTags->"Dirac gamma matrices"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["\[Gamma]", "k"], "=", 
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"\[ScriptCapitalO]", 
        RowBox[{
         RowBox[{"-", "\[ImaginaryI]"}], " ", 
         SubscriptBox["\[Sigma]", "k"]}]},
       {
        RowBox[{"\[ImaginaryI]", " ", 
         SubscriptBox["\[Sigma]", "k"]}], "\[ScriptCapitalO]"}
      }], "\[NoBreak]", ")"}]}], ",", " ", 
   RowBox[{"k", "=", "1"}], ",", "2", ",", "3", ",", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["\[Gamma]", "4"], "=", 
    RowBox[{"(", GridBox[{
       {
        SubscriptBox["\[ScriptCapitalI]", "2"], "\[ScriptCapitalO]"},
       {"\[ScriptCapitalO]", 
        RowBox[{"-", 
         SubscriptBox["\[ScriptCapitalI]", "2"]}]}
      }], ")"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{
    SubscriptBox["\[Gamma]", "5"], "=", " ", 
    RowBox[{
     SubscriptBox["\[Gamma]", "1"], ".", 
     SubscriptBox["\[Gamma]", "2"], ".", 
     SubscriptBox["\[Gamma]", "3"], ".", 
     SubscriptBox["\[Gamma]", "4"]}]}], ","}], 
  TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox["\[ScriptCapitalO]", TraditionalForm]]],
 " is a ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "\[Times]", "2"}], TraditionalForm]]],
 " zero matrix, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[ScriptCapitalI]", "2"], TraditionalForm]]],
 " is a ",
 Cell[BoxData[
  FormBox[
   RowBox[{"2", "\[Times]", "2"}], TraditionalForm]]],
 " unit matrix, and the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Sigma]", "k"], TraditionalForm]]],
 " are the Pauli spin matrices. Implement these matrices and show that they \
satisfy the following ",
 StyleBox["anti-commutation",
  FontSlant->"Italic"],
 " relation, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["\[Gamma]", "\[Mu]"], ".", 
      SubscriptBox["\[Gamma]", "\[Nu]"]}], "+", 
     RowBox[{
      SubscriptBox["\[Gamma]", "\[Nu]"], ".", 
      SubscriptBox["\[Gamma]", "\[Mu]"]}]}], "=", 
    RowBox[{"2", 
     SubscriptBox[
      InterpretationBox["\[Delta]",
       KroneckerDelta,
       Editable->False,
       Selectable->False], 
      RowBox[{"\[Mu]", ",", "\[Nu]"}]], " ", 
     SubscriptBox["\[ScriptCapitalI]", "4"]}]}], TraditionalForm]]],
 ", for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Mu]", ",", 
    RowBox[{"\[Nu]", "=", "1"}], ",", "2", ",", "3", ",", "4"}], 
   TraditionalForm]]],
 ", where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    InterpretationBox["\[Delta]",
     KroneckerDelta,
     Editable->False,
     Selectable->False], 
    RowBox[{"\[Mu]", ",", "\[Nu]"}]], TraditionalForm]]],
 " is the Kronecker delta function. ",
 StyleBox["[4]", "Marks"]
}], "EndQuestion"]
}, Open  ]],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". Show that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Sigma]", 
     RowBox[{"\[Mu]", ",", "\[Nu]"}]], "=", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", "\[ImaginaryI]"}]], "[", 
      RowBox[{
       SubscriptBox["\[Gamma]", "\[Mu]"], ",", 
       SubscriptBox["\[Gamma]", "\[Nu]"]}], "]"}], "=", " ", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", 
      RowBox[{
       SubscriptBox["\[Gamma]", "\[Mu]"], ".", 
       SubscriptBox["\[Gamma]", "\[Nu]"]}]}]}]}], TraditionalForm]]],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"\[Mu]", "\[NotEqual]", "\[Nu]"}], "=", "1"}], ",", "2", ",", 
    "3", ",", "4"}], TraditionalForm]]],
 ". ",
 StyleBox["[2]", "Marks"]
}], "BeginEndQuestion"],

Cell[TextData[{
 
 CounterBox["Section"],
 ".",
 
 CounterBox["Exercise"],
 ". ",
 "Show that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"\[Mu]", "=", "1"}], "4"], 
     RowBox[{
      SubscriptBox["\[Gamma]", "\[Mu]"], ".", 
      RowBox[{"(", 
       RowBox[{"\[Gamma]", ".", "\[ScriptCapitalA]"}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{"\[Gamma]", ".", "\[ScriptCapitalB]"}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{"\[Gamma]", ".", "\[ScriptCapitalC]"}], ")"}], ".", 
      SubscriptBox["\[Gamma]", "\[Mu]"]}]}], "=", 
    RowBox[{
     RowBox[{"-", "2"}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"\[Gamma]", ".", "\[ScriptCapitalC]"}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{"\[Gamma]", ".", "\[ScriptCapitalB]"}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{"\[Gamma]", ".", "\[ScriptCapitalA]"}], ")"}]}]}]}], 
   TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"Tr", "(", 
     RowBox[{
      SubscriptBox["\[Gamma]", "5"], ".", 
      RowBox[{"(", 
       RowBox[{"\[Gamma]", ".", "\[ScriptCapitalA]"}], ")"}], ".", 
      RowBox[{"(", 
       RowBox[{"\[Gamma]", ".", "\[ScriptCapitalB]"}], ")"}]}], ")"}], "=", 
    "0"}], TraditionalForm]]],
 " where ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Gamma]", "=", 
    RowBox[{"(", 
     RowBox[{
      TagBox[
       SubscriptBox["\[Gamma]", "1"],
       HoldForm], ",", 
      TagBox[
       SubscriptBox["\[Gamma]", "2"],
       HoldForm], ",", 
      TagBox[
       SubscriptBox["\[Gamma]", "3"],
       HoldForm], ",", 
      TagBox[
       SubscriptBox["\[Gamma]", "4"],
       HoldForm]}], ")"}]}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox["\[ScriptCapitalA]", TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox["\[ScriptCapitalB]", TraditionalForm]]],
 ", and ",
 Cell[BoxData[
  FormBox["\[ScriptCapitalC]", TraditionalForm]]],
 " are ",
 StyleBox["arbitrary",
  FontSlant->"Italic"],
 " 4-vectors, ",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[ScriptCapitalA]", "=", 
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["a", "1"], ",", 
      SubscriptBox["a", "2"], ",", 
      SubscriptBox["a", "3"], ",", 
      SubscriptBox["a", "4"]}], "}"}]}], TraditionalForm]]],
 ", ",
 StyleBox["etc",
  FontSlant->"Italic"],
 "., and ",
 Cell[BoxData[
  FormBox["Tr", TraditionalForm]]],
 " denotes the trace of a square matrix (",
 StyleBox["i.e.",
  FontSlant->"Italic"],
 ", the sum of the diagonal entries in the matrix).  ",
 StyleBox["[3]", "Marks"]
}], "BeginEndQuestion"]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{956, 647},
WindowMargins->{{8, Automatic}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{3, Automatic},
PageHeaders->{{None, Inherited, None}, {None, Inherited, None}},
PageFooters->{{
   Cell[
    TextData[{"Computational Physics ", 
      CounterBox["Page"]}], "Footer"], Inherited, Inherited}, {
  Inherited, Inherited, 
   Cell[
    TextData[{"Computational Physics ", 
      CounterBox["Page"]}], "Footer"]}},
PageHeaderLines->{False, False},
PrintingOptions->{"FacingPages"->True,
"FirstPageHeader"->False,
"PrintingMargins"->{{18, 18}, {36, 36}}},
InputAliases->{"note" -> RowBox[{"Notation", "[", 
     RowBox[{
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"],
        " ", "\[DoubleLongLeftRightArrow]", " ", 
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> 
        "NotationTemplateStyle"]}], "]"}], "note>" -> 
  RowBox[{"Notation", "[", 
     RowBox[{
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"],
        " ", "\[DoubleLongRightArrow]", " ", 
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> 
        "NotationTemplateStyle"]}], "]"}], "note<" -> 
  RowBox[{"Notation", "[", 
     RowBox[{
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"],
        " ", "\[DoubleLongLeftArrow]", " ", 
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> 
        "NotationTemplateStyle"]}], "]"}], "infixnote" -> 
  RowBox[{"InfixNotation", "[", 
     RowBox[{
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"],
        ",", "\[Placeholder]"}], "]"}], "pattwrap" -> 
  TagBox["\[Placeholder]", NotationPatternTag, TagStyle -> 
    "NotationPatternWrapperStyle"], "madeboxeswrap" -> 
  TagBox["\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
    "NotationMadeBoxesWrapperStyle"], "notation" -> RowBox[{"Notation", "[", 
     RowBox[{
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"],
        " ", "\[DoubleLongLeftRightArrow]", " ", 
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> 
        "NotationTemplateStyle"]}], "]"}], "notation>" -> 
  RowBox[{"Notation", "[", 
     RowBox[{
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"],
        " ", "\[DoubleLongRightArrow]", " ", 
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> 
        "NotationTemplateStyle"]}], "]"}], "notation<" -> 
  RowBox[{"Notation", "[", 
     RowBox[{
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"],
        " ", "\[DoubleLongLeftArrow]", " ", 
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> 
        "NotationTemplateStyle"]}], "]"}], "symb" -> 
  RowBox[{"Symbolize", "[", 
     TagBox[
     "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"], 
     "]"}], "infixnotation" -> RowBox[{"InfixNotation", "[", 
     RowBox[{
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"],
        ",", "\[Placeholder]"}], "]"}], "addia" -> 
  RowBox[{"AddInputAlias", "[", 
     RowBox[{
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"],
        ",", "\[Placeholder]"}], "]"}], "pattwraper" -> 
  TagBox["\[Placeholder]", NotationPatternTag, TagStyle -> 
    "NotationPatternWrapperStyle"], "madeboxeswraper" -> 
  TagBox["\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
    "NotationMadeBoxesWrapperStyle"]},
Magnification->1.25,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (April 9, 2007)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell[
      "Style Definitions for \nComputational Physics", "Subtitle", 
       CellMargins -> {{0, Inherited}, {Inherited, 0}}, 
       CellFrameMargins -> {{20, 4}, {8, 20}}, FontSize -> 36, FontWeight -> 
       "Bold", FontColor -> GrayLevel[1], Background -> GrayLevel[0]], 
      Cell[
       CellGroupData[{
         Cell[
         "Style Environment Names", "Section", CellFrame -> False, 
          CellDingbat -> None, ShowCellBracket -> True, 
          CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
          StyleData[All, "Working"], ScreenStyleEnvironment -> "Working", 
          PrintingStyleEnvironment -> "Printout", 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.115343, 0.350561, 0.362966]}, ShowCellLabel -> 
          True, CellFrameLabelMargins -> 6, ScriptMinSize -> 9], 
         Cell[
          StyleData[All, "Presentation"], ScreenStyleEnvironment -> 
          "Presentation", PrintingStyleEnvironment -> "Printout", 
          CellFrameMargins -> {{30, 4}, {8, 8}}, Magnification -> 1.25], 
         Cell[
          StyleData[All, "Printout"], ScreenStyleEnvironment -> "Printout", 
          PrintingStyleEnvironment -> "Printout", PageWidth -> PaperWidth, 
          PageFooters -> {{
             Cell[
              TextData[{"Computational Physics ", 
                CounterBox["Page"]}], "Footer"], Inherited, Inherited}, {
            Inherited, Inherited, 
             Cell[
              TextData[{"Computational Physics ", 
                CounterBox["Page"]}], "Footer"]}}, 
          PrintingOptions -> {
           "FacingPages" -> True, "FirstPageHeader" -> False, 
            "PrintRegistrationMarks" -> False, 
            "PrintingMargins" -> {{24, 74}, {72, 72}}}, ShowCellBracket -> 
          False, PrivateFontOptions -> {"FontType" -> "Outline"}], 
         Cell[
          StyleData[All, "Production"], ScreenStyleEnvironment -> 
          "Production", PrintingStyleEnvironment -> "Production", PageWidth -> 
          PaperWidth, 
          PrintingOptions -> {
           "FacingPages" -> True, "FirstPageHeader" -> False, 
            "PageSize" -> {486, 711}, "PrintRegistrationMarks" -> True, 
            "PrintingMargins" -> {{0, 0}, {82, 56}}}, 
          CellLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          ScriptMinSize -> 5, 
          PrivateFontOptions -> {"FontType" -> "Outline"}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Notebook Options", "Section", CellFrame -> False, CellDingbat -> 
          None, ShowCellBracket -> True, CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
         "The options defined for the style below will be used at the \
Notebook level.", "Text"], 
         Cell[
          StyleData["Notebook"], CellFrameLabelMargins -> 6, 
          CommonDefaultFormatTypes -> {
           "Input" -> TraditionalForm, "Output" -> TraditionalForm}, 
          HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
          StyleMenuListing -> None]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Styles for Headings", "Section", CellFrame -> False, CellDingbat -> 
          None, ShowCellBracket -> True, CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
         "Each notebook should contain at least one title cell. Title resets \
all cell CounterBox values to zero (except Title).", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], ShowCellBracket -> False, 
             CellMargins -> {{0, 25}, {Inherited, 0}}, 
             CellGroupingRules -> {"TitleGrouping", 0}, PageBreakBelow -> 
             False, CellFrameMargins -> {{55, 4}, {8, 20}}, 
             LineSpacing -> {1.125, 0}, CounterIncrements -> "Title", 
             CounterAssignments -> {{"Subtitle", 0}, {"Section", 0}, {
               "Subsection", 0}, {"Subsubsection", 0}, {"List", 0}, {
               "NumberedFigure", 0}, {"NumberedTable", 0}, {
               "NumberedProgram", 0}, {"Equation", 0}, {"Text", 0}, {
               "SmallText", 0}, {"Reference", 0}, {"Exercise", 0}}, 
             FontFamily -> "Times", FontSize -> 36, FontSlant -> "Italic", 
             FontColor -> GrayLevel[1], Background -> 
             RGBColor[0.699931, 0.198672, 0.198672]], 
            Cell[
             StyleData["Title", "Presentation"], LineSpacing -> {0.95, 0}, 
             FontSize -> 40, FontSlant -> "Italic", Background -> 
             RGBColor[0.699931, 0.198672, 0.198672]], 
            Cell[
             StyleData["Title", "Printout"], 
             CellMargins -> {{54, 0}, {30, Inherited}}, CellFrameMargins -> 
             False, LineSpacing -> {0.95, 0}, FontColor -> GrayLevel[0], 
             Background -> None], 
            Cell[
             StyleData["Title", "Production"], 
             CellMargins -> {{72, 72}, {14, 0}}, CellFrameMargins -> False, 
             FontFamily -> "Janson Text", 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}, FontColor -> 
             GrayLevel[0], Background -> None]}, Closed]], 
         Cell[
         "Subtitle is an optional cell. Used for Tech Support column, \
Subtitle states topics in current issue.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], CellMargins -> {{54, 25}, {0, 10}}, 
             CellGroupingRules -> {"TitleGrouping", 10}, PageBreakBelow -> 
             False, LineSpacing -> {1, 0}, CounterIncrements -> "Subtitle", 
             FontFamily -> "Times", FontSize -> 24, FontSlant -> "Italic"], 
            Cell[
             StyleData["Subtitle", "Presentation"]], 
            Cell[
             StyleData["Subtitle", "Printout"], 
             CellMargins -> {{54, 0}, {10, 10}}, FontSize -> 12], 
            Cell[
             StyleData["Subtitle", "Production"], 
             CellMargins -> {{72, 72}, {12, 2}}, FontFamily -> "Janson Text", 
             FontSize -> 12, FontSlant -> "Italic", 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], CellMargins -> {{54, 25}, {0, 10}}, 
             CellGroupingRules -> {"TitleGrouping", 10}, PageBreakBelow -> 
             False, LineSpacing -> {1, 0}, CounterIncrements -> "Subtitle", 
             FontFamily -> "Times", FontSize -> 18, FontSlant -> "Italic"], 
            Cell[
             StyleData["Subsubtitle", "Presentation"]], 
            Cell[
             StyleData["Subsubtitle", "Printout"], 
             CellMargins -> {{54, 0}, {Inherited, Inherited}}, FontSize -> 
             16], 
            Cell[
             StyleData["Subsubtitle", "Production"], 
             CellMargins -> {{72, 72}, {6, 2}}, FontFamily -> "Janson Text", 
             FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
         "SectionFirst should be used for the first Section level heading in \
a notebook. Sets the following counter values to zero: Subsection and \
Subsubsection. Sets Section counter value to 1.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SectionFirst"], CellFrame -> {{0, 0}, {0, 2}}, 
             CellDingbat -> "\[FilledSquare]", 
             CellMargins -> {{54, 25}, {10, 30}}, 
             CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
             False, CellFrameMargins -> 2, CellFrameColor -> 
             RGBColor[0.668009, 0.669383, 0.345068], CounterIncrements -> 
             "Section", 
             CounterAssignments -> {{"Section", 0}, {"Subsection", 0}, {
               "Subsubsection", 0}, {"Equation", 0}, {"Exercise", 0}}, 
             FontFamily -> "Helvetica", FontSize -> 18, FontWeight -> "Bold"],
             
            Cell[
             StyleData["SectionFirst", "Presentation"], 
             CellFrame -> {{0, 0}, {0, 3}}, 
             CellFrameMargins -> {{0, 0}, {0, 4}}, CellFrameColor -> 
             RGBColor[0.668009, 0.669383, 0.345068], FontSize -> 18], 
            Cell[
             StyleData["SectionFirst", "Printout"], 
             CellFrame -> {{0, 0}, {0, 3}}, 
             CellMargins -> {{54, 24}, {15, 15}}, 
             CellFrameMargins -> {{0, 0}, {0, 5}}, CellFrameColor -> 
             GrayLevel[0], FontSize -> 14], 
            Cell[
             StyleData["SectionFirst", "Production"], CellFrame -> False, 
             CellMargins -> {{72, 72}, {2, 30}}, FontFamily -> 
             "CXB Futura CondExtraBold", FontSize -> 12, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
         "Section should be used for subsequent Section level headings. Sets \
counter values Subsection and Subsubsection to zero.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellFrame -> {{0, 0}, {0, 0.5}}, 
             CellDingbat -> "\[FilledSquare]", 
             CellMargins -> {{54, 25}, {10, 30}}, 
             CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
             False, CellFrameMargins -> 2, CellFrameColor -> 
             RGBColor[0.668009, 0.669383, 0.345068], CounterIncrements -> 
             "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
               "Equation", 0}, {"Exercise", 0}}, FontFamily -> "Helvetica", 
             FontSize -> 18, FontWeight -> "Bold"], 
            Cell[
             StyleData["Section", "Presentation"], 
             CellFrameMargins -> {{0, 0}, {0, 4}}, FontSize -> 18], 
            Cell[
             StyleData["Section", "Printout"], 
             CellMargins -> {{54, 24}, {3, 15}}, PageBreakAbove -> True, 
             CellFrameMargins -> {{0, 0}, {0, 5}}, CellFrameColor -> 
             GrayLevel[0], FontSize -> 14], 
            Cell[
             StyleData["Section", "Production"], CellFrame -> False, 
             CellMargins -> {{72, 72}, {2, 30}}, FontFamily -> 
             "CXB Futura CondExtraBold", FontSize -> 12, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Open]], 
         Cell[
         "Subsection is an optional style. Sets counter Subsubsection to \
zero.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> "\[GraySquare]", 
             CellMargins -> {{54, 25}, {10, 26}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsection", 
             CounterAssignments -> {{"Subsubsection", 0}}, FontFamily -> 
             "Helvetica", FontSize -> 14, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsection", "Presentation"]], 
            Cell[
             StyleData["Subsection", "Printout"], CellDingbat -> None, 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, FontSize -> 
             12], 
            Cell[
             StyleData["Subsection", "Production"], 
             CellMargins -> {{72, 72}, {2, Inherited}}, FontFamily -> 
             "CXB Futura CondExtraBold", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
         "SubsectionNoSpace is an optional style, it is to be used if a \
subsection level heading directly follows a section level heading. Sets \
counter Subsubsection to zero.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubsectionNoSpace"], CellDingbat -> "\[GraySquare]", 
             CellMargins -> {{54, 25}, {2, 2}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsection", 
             CounterAssignments -> {{"Subsubsection", 0}}, FontFamily -> 
             "Helvetica", FontSize -> 14, FontWeight -> "Bold"], 
            Cell[
             StyleData["SubsectionNoSpace", "Presentation"]], 
            Cell[
             StyleData["SubsectionNoSpace", "Printout"], 
             CellMargins -> {{54, 24}, {2, 2}}, FontSize -> 12], 
            Cell[
             StyleData["SubsectionNoSpace", "Production"], 
             CellMargins -> {{72, 72}, {2, 2}}, FontFamily -> 
             "CXB Futura CondExtraBold", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellDingbat -> 
             "\[FilledSmallSquare]", CellMargins -> {{54, 25}, {6, 20}}, 
             CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsubsection", FontFamily -> 
             "Helvetica", FontSize -> 12, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsubsection", "Presentation"]], 
            Cell[
             StyleData["Subsubsection", "Printout"], 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, FontSize -> 
             10], 
            Cell[
             StyleData["Subsubsection", "Production"], CellDingbat -> None, 
             CellMargins -> {{72, 72}, {-4, 2}}, FontFamily -> "Futura Book", 
             FontSize -> 9, FontWeight -> "Plain", FontSlant -> "Italic", 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
         "NoDingbat versions of headings for use in print published \
frontmatter.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SectionNoDingbat"], CellFrame -> {{0, 0}, {0, 0.5}}, 
             CellDingbat -> None, CellMargins -> {{54, 25}, {10, 30}}, 
             CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
             False, CellFrameMargins -> 2, CellFrameColor -> 
             RGBColor[0.668009, 0.669383, 0.345068], CounterIncrements -> 
             "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
             18, FontWeight -> "Bold"], 
            Cell[
             StyleData["SectionNoDingbat", "Presentation"], 
             CellFrameMargins -> {{0, 0}, {0, 4}}], 
            Cell[
             StyleData["SectionNoDingbat", "Printout"], 
             CellMargins -> {{54, 24}, {3, 15}}, 
             CellFrameMargins -> {{0, 0}, {0, 5}}, CellFrameColor -> 
             GrayLevel[0], FontSize -> 14], 
            Cell[
             StyleData["SectionNoDingbat", "Production"], CellFrame -> False, 
             CellMargins -> {{72, 72}, {2, 30}}, FontFamily -> 
             "CXB Futura CondExtraBold", FontSize -> 12, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubsectionNoDingbat"], CellDingbat -> None, 
             CellMargins -> {{54, 25}, {10, 26}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsection", 
             CounterAssignments -> {{"Subsubsection", 0}}, StyleMenuListing -> 
             None, FontFamily -> "Helvetica", FontSize -> 14, FontWeight -> 
             "Bold"], 
            Cell[
             StyleData["SubsectionNoDingbat", "Presentation"]], 
            Cell[
             StyleData["SubsectionNoDingbat", "Printout"], 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, FontSize -> 
             12], 
            Cell[
             StyleData["SubsectionNoDingbat", "Production"], 
             CellMargins -> {{72, 72}, {2, Inherited}}, FontFamily -> 
             "CXB Futura CondExtraBold", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubsectionNoSpaceNoDingbat"], 
             CellMargins -> {{54, 25}, {2, 2}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsection", 
             CounterAssignments -> {{"Subsubsection", 0}}, StyleMenuListing -> 
             None, FontFamily -> "Helvetica", FontSize -> 14, FontWeight -> 
             "Bold"], 
            Cell[
             StyleData["SubsectionNoSpaceNoDingbat", "Presentation"]], 
            Cell[
             StyleData["SubsectionNoSpaceNoDingbat", "Printout"], 
             CellMargins -> {{54, 24}, {2, 2}}, FontSize -> 12], 
            Cell[
             StyleData["SubsectionNoSpaceNoDingbat", "Production"], 
             CellMargins -> {{72, 72}, {2, 2}}, FontFamily -> 
             "CXB Futura CondExtraBold", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SubsubsectionNoDingbat"], 
             CellMargins -> {{54, 25}, {6, 20}}, 
             CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
             False, CounterIncrements -> "Subsubsection", StyleMenuListing -> 
             None, FontFamily -> "Helvetica", FontSize -> 12, FontWeight -> 
             "Bold"], 
            Cell[
             StyleData["SubsubsectionNoDingbat", "Presentation"]], 
            Cell[
             StyleData["SubsubsectionNoDingbat", "Printout"], 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, FontSize -> 
             10], 
            Cell[
             StyleData["SubsubsectionNoDingbat", "Production"], 
             CellMargins -> {{72, 72}, {-4, 2}}, FontFamily -> "Futura Book", 
             FontSize -> 9, FontWeight -> "Plain", FontSlant -> "Italic", 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Styles for Body Text", "Section", CellFrame -> False, CellDingbat -> 
          None, ShowCellBracket -> True, CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 4}, CounterIncrements -> "Text", FontFamily -> 
             "Times", FontSize -> 12], 
            Cell[
             StyleData["Text", "Presentation"], FontSize -> 14], 
            Cell[
             StyleData["Text", "Printout"], 
             CellMargins -> {{54, 10}, {Inherited, 0}}, TextJustification -> 
             1, LineSpacing -> {1, 3}, FontSize -> 10], 
            Cell[
             StyleData["Text", "Production"], 
             CellMargins -> {{72, 72}, {2, 4}}, TextJustification -> 1, 
             Hyphenation -> True, LineSpacing -> {0, 12}, FontFamily -> 
             "Janson Text", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SmallText"], 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 4}, CounterIncrements -> "SmallText", 
             FontFamily -> "Times", FontSize -> 10], 
            Cell[
             StyleData["SmallText", "Presentation"], 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, FontSize -> 
             12], 
            Cell[
             StyleData["SmallText", "Printout"], 
             CellMargins -> {{54, 10}, {Inherited, 0}}, TextJustification -> 
             1, LineSpacing -> {1, 3}, FontSize -> 9], 
            Cell[
             StyleData["SmallText", "Production"], 
             CellMargins -> {{72, 72}, {2, 4}}, TextJustification -> 1, 
             Hyphenation -> True, LineSpacing -> {0, 11}, FontFamily -> 
             "Janson Text", FontSize -> 9, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
         "BeginQuestion is used directly after a section cell. Followed by \
either Question or Input/Output etc. Last paragraph of the question should be \
in EndQuestion cell style.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["BeginQuestion"], CellFrame -> {{0, 0}, {0, 1}}, 
             CellMargins -> {{54, 34}, {8, 8}}, 
             CellGroupingRules -> {"SectionGrouping", 55}, 
             CellFrameMargins -> {{0, 0}, {2, 4}}, CounterIncrements -> 
             "Exercise", FontColor -> RGBColor[0.115511, 0.321752, 0.580118]],
             
            Cell[
             StyleData["BeginQuestion", "Presentation"], 
             LineSpacing -> {1, 4}, FontSize -> 16, FontColor -> 
             RGBColor[0.115511, 0.321752, 0.580118]], 
            Cell[
             StyleData["BeginQuestion", "Printout"], 
             CellMargins -> {{54, 10}, {Inherited, Inherited}}, 
             TextJustification -> 1, FontSize -> 10, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["BeginQuestion", "Production"], PageWidth -> 
             PaperWidth, CellFrame -> {{0, 0}, {0, 2}}, 
             CellMargins -> {{72, 72}, {2, 4}}, TextJustification -> 1, 
             Hyphenation -> True, LineSpacing -> {0, 12}, FontFamily -> 
             "Janson Text", FontSize -> 10, FontWeight -> "Plain", FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
         "EndQuestion used as the last paragraph of the question.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["EndQuestion"], CellFrame -> {{0, 0}, {1, 0}}, 
             CellMargins -> {{54, 34}, {8, 8}}, 
             CellGroupingRules -> {"SectionGrouping", 58}, FontColor -> 
             RGBColor[0.115511, 0.321752, 0.580118]], 
            Cell[
             StyleData["EndQuestion", "Presentation"], LineSpacing -> {1, 4}, 
             FontSize -> 16, FontColor -> 
             RGBColor[0.115511, 0.321752, 0.580118]], 
            Cell[
             StyleData["EndQuestion", "Printout"], 
             CellMargins -> {{54, 10}, {Inherited, Inherited}}, 
             TextJustification -> 1, FontSize -> 10, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["EndQuestion", "Production"], 
             CellFrame -> {{0, 0}, {2, 0}}, CellMargins -> {{72, 72}, {2, 0}},
              TextJustification -> 1, Hyphenation -> True, 
             LineSpacing -> {0, 12}, FontFamily -> "Janson Text", FontSize -> 
             10, FontWeight -> "Plain", 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
         "BeginEndQuestion is used in the In and Out column directly after a \
section cell. Used if the question is a single text paragraph.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["BeginEndQuestion"], CellFrame -> {{0, 0}, {1, 1}}, 
             CellMargins -> {{54, 35}, {8, 8}}, 
             CellGroupingRules -> {"SectionGrouping", 55}, CounterIncrements -> 
             "Exercise", StyleMenuListing -> Automatic, FontColor -> 
             RGBColor[0.115511, 0.321752, 0.580118]], 
            Cell[
             StyleData["BeginEndQuestion", "Presentation"], 
             LineSpacing -> {1, 4}, FontSize -> 16, FontColor -> 
             RGBColor[0.115511, 0.321752, 0.580118]], 
            Cell[
             StyleData["BeginEndQuestion", "Printout"], 
             CellMargins -> {{54, 10}, {Inherited, Inherited}}, 
             TextJustification -> 1, FontSize -> 10, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["BeginEndQuestion", "Production"], 
             CellMargins -> {{72, 72}, {2, 4}}, TextJustification -> 1, 
             Hyphenation -> True, LineSpacing -> {0, 12}, FontFamily -> 
             "Janson Text", FontSize -> 10, FontWeight -> "Plain", FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
         "BeginAnswer is used directly after an EndQuestion or \
BeginEndQuestion cell style to begin the answer portion. Followed by Text or \
Input/Output etc.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Answer"], CellDingbat -> "Answer: ", 
             CellMargins -> {{54, 35}, {8, 8}}, LineSpacing -> {1, 4}], 
            Cell[
             StyleData["Answer", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["Answer", "Printout"], 
             CellMargins -> {{54, 10}, {Inherited, Inherited}}, 
             TextJustification -> 1, LineSpacing -> {1, 3}, FontSize -> 10], 
            Cell[
             StyleData["Answer", "Production"], 
             CellMargins -> {{72, 72}, {2, 4}}, TextJustification -> 1, 
             Hyphenation -> True, LineSpacing -> {0, 12}, FontFamily -> 
             "Janson Text", FontSize -> 10]}, Closed]], 
         Cell[
         "Quote should be used when displaying text previously published \
elsewhere (and appropriately cited).", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Quote"], 
             CellMargins -> {{70, 40}, {Inherited, Inherited}}, 
             TextJustification -> 0, LineSpacing -> {1, 3}, FontFamily -> 
             "Times", FontSize -> 12], 
            Cell[
             StyleData["Quote", "Presentation"], FontSize -> 14], 
            Cell[
             StyleData["Quote", "Printout"], 
             CellMargins -> {{80, 20}, {Inherited, Inherited}}, 
             TextJustification -> 1, FontSize -> 10], 
            Cell[
             StyleData["Quote", "Production"], 
             CellMargins -> {{96, 96}, {2, 4}}, TextJustification -> 1, 
             Hyphenation -> True, LineSpacing -> {0, 12}, FontFamily -> 
             "Janson Text", FontSize -> 10, FontSlant -> "Plain", 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Styles for Input/Output", "Section", CellFrame -> False, 
          CellDingbat -> None, ShowCellBracket -> True, 
          CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
         "The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], CellMargins -> {{76, 24}, {4, 4}}, 
             Evaluatable -> True, CellGroupingRules -> "InputGrouping", 
             CellHorizontalScrolling -> True, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultInputFormatType, 
             AutoItalicWords -> {}, FormatType -> InputForm, 
             ShowStringCharacters -> True, NumberMarks -> True, 
             CounterIncrements -> "Input", FontWeight -> "Bold"], 
            Cell[
             StyleData["Input", "Presentation"]], 
            Cell[
             StyleData["Input", "Printout"], FontSize -> 9], 
            Cell[
             StyleData["Input", "Production"], CellFrame -> False, 
             CellMargins -> {{96, 72}, {2, 4}}, 
             PrivateEvaluationOptions -> {"OutputFormPageWidth" -> 342}, 
             CellFrameMargins -> False, LineSpacing -> {1.25, 0}, FontFamily -> 
             "WriCMTT9", FontSize -> 9, FontWeight -> "Bold", 
             FontProperties -> {
              "FontMonospaced" -> True, "FontSerifed" -> True}, Background -> 
             None]}, Closed]], 
         Cell[
         "Output cell style is usually generated by the Mathematica kernel. ",
           "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], CellMargins -> {{76, 24}, {4, 4}}, 
             CellEditDuplicate -> True, CellGroupingRules -> "OutputGrouping",
              CellHorizontalScrolling -> True, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, 
             AutoItalicWords -> {}, FormatType -> InputForm, 
             CounterIncrements -> "Output"], 
            Cell[
             StyleData["Output", "Presentation"]], 
            Cell[
             StyleData["Output", "Printout"], FontSize -> 9], 
            Cell[
             StyleData["Output", "Production"], CellFrame -> False, 
             CellMargins -> {{96, 72}, {2, 4}}, 
             CellLabelMargins -> {{72, Inherited}, {Inherited, Inherited}}, 
             LineSpacing -> {1.25, 0}, FontFamily -> "WriCMTT9", FontSize -> 
             9, FontProperties -> {
              "FontMonospaced" -> True, "FontSerifed" -> True}, Background -> 
             None]}, Closed]], 
         Cell[
          TextData[{"Message cells are usually generated by the ", 
            StyleBox["Mathematica", FontSlant -> "Italic"], 
            " kernel, typically messages emitted during evaluation."}], 
          "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Message"], CellDingbat -> "\[WarningSign]", 
             CellMargins -> {{78, 24}, {2, 2}}, CellGroupingRules -> 
             "OutputGrouping", PageBreakWithin -> False, GroupPageBreakWithin -> 
             False, GeneratedCell -> True, CellAutoOverwrite -> True, 
             ShowCellLabel -> False, 
             CellLabelMargins -> {{23, Inherited}, {Inherited, Inherited}}, 
             DefaultFormatType -> DefaultOutputFormatType, 
             AutoItalicWords -> {}, CounterIncrements -> "Message", 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
             10, FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["Message", "Presentation"], FontSize -> 12], 
            Cell[
             StyleData["Message", "Printout"], FontSize -> 8, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["Message", "Production"], CellFrame -> True, 
             CellDingbat -> None, CellMargins -> {{96, 72}, {2, 4}}, 
             PrivateEvaluationOptions -> {"OutputFormPageWidth" -> 342}, 
             CellFrameMargins -> 4, LineSpacing -> {0, 10}, FontFamily -> 
             "WriCMTT9", FontSize -> 8, 
             FontProperties -> {
              "FontMonospaced" -> True, "FontSerifed" -> True}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          TextData[{"Print cells are usually generated by the ", 
            StyleBox["Mathematica", FontSlant -> "Italic"], 
            " kernel, typically from such commands as ?Plot."}], "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], CellFrame -> True, 
             CellMargins -> {{78, 24}, {1, 6}}, CellGroupingRules -> 
             "OutputGrouping", CellHorizontalScrolling -> True, 
             PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, ShowCellLabel -> 
             False, CellLabelMargins -> {{23, Inherited}, {
               Inherited, Inherited}}, CellFrameColor -> 
             RGBColor[0.718318, 0.694575, 0.474449], DefaultFormatType -> 
             DefaultOutputFormatType, AutoItalicWords -> {}, 
             CounterIncrements -> "Print", StyleMenuListing -> None, FontSize -> 
             10], 
            Cell[
             StyleData["Print", "Presentation"], CellFrame -> 2, FontSize -> 
             12, Background -> None], 
            Cell[
             StyleData["Print", "Printout"], CellFrameColor -> GrayLevel[0], 
             FontSize -> 8], 
            Cell[
             StyleData["Print", "Production"], CellFrame -> True, 
             CellMargins -> {{96, 72}, {2, 4}}, 
             PrivateEvaluationOptions -> {"OutputFormPageWidth" -> 342}, 
             CellFrameMargins -> 4, CellFrameColor -> GrayLevel[0], 
             LineSpacing -> {0, 11}, FontFamily -> "WriCMTT9", FontSize -> 9, 
             FontProperties -> {
              "FontMonospaced" -> True, "FontSerifed" -> True}, Background -> 
             None]}, Closed]], 
         Cell[
         "Graphics cell usually output by kernel. To be preceded by Input \
cell, not followed by Output cell.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Graphics"], CellMargins -> {{54, 24}, {10, 0}}, 
             CellGroupingRules -> "GraphicsGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             CellLabelAutoDelete -> True, DefaultFormatType -> 
             DefaultOutputFormatType, CounterIncrements -> "Graphics", 
             ImageMargins -> {{30, 0}, {0, 0}}], 
            Cell[
             StyleData["Graphics", "Presentation"]], 
            Cell[
             StyleData["Graphics", "Printout"], 
             CellMargins -> {{120, 24}, {10, 0}}, ImageSize -> {266, 266}, 
             ImageMargins -> {{40, Inherited}, {Inherited, Inherited}}, 
             Magnification -> 0.8, Background -> None], 
            Cell[
             StyleData["Graphics", "Production"], CellFrame -> False, 
             CellMargins -> {{96, 72}, {8, 10}}, LineSpacing -> {0, 12}, 
             ImageSize -> {144, 144}, FontFamily -> "Janson Text", FontSize -> 
             10, Background -> None]}, Open]], 
         Cell[
         "CellLabel style definition controls how labels appear when a cell \
has ShowCellLabels->True.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 9, FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["CellLabel", "Presentation"]], 
            Cell[
             StyleData["CellLabel", "Printout"], FontSize -> 9, FontSlant -> 
             "Italic", FontColor -> GrayLevel[0]], 
            Cell[
             StyleData["CellLabel", "Production"], LineSpacing -> {1, 0}, 
             FontFamily -> "CLO Futura CondLightOblique", FontSize -> 6, 
             FontSlant -> "Oblique", 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}, 
             PrivateFontOptions -> {
              "FontPostScriptName" -> "Futura-CondensedLightOblique"}, 
             FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
         "InlineInputTraditionalForm is for TraditionalForm input cells \
embedded within another cell.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["InlineInputTraditionalForm"], Evaluatable -> True, 
             CellGroupingRules -> "InputGrouping", CellHorizontalScrolling -> 
             True, AutoItalicWords -> {}, FormatType -> TraditionalForm, 
             ShowStringCharacters -> True, NumberMarks -> True, 
             SingleLetterItalics -> True, CounterIncrements -> "Input", 
             FontFamily -> "Times", FontWeight -> "Bold"], 
            Cell[
             StyleData["InlineInputTraditionalForm", "Presentation"]], 
            Cell[
             StyleData["InlineInputTraditionalForm", "Printout"]], 
            Cell[
             StyleData["InlineInputTraditionalForm", "Production"], 
             CounterIncrements -> "Input", FontFamily -> "Janson Text", 
             FontWeight -> "Bold", 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Styles for Automatic Numbering", "Section", CellFrame -> False, 
          CellDingbat -> None, ShowCellBracket -> True, 
          CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
         "NumberedEquation is for DisplayFormula-type cells that you want to \
number sequentially throughout a notebook.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedEquation"], 
             CellMargins -> {{100, 10}, {Inherited, Inherited}}, 
             CellGroupingRules -> {"SectionGrouping", 59}, 
             CellFrameLabels -> {{None, 
                Cell[
                 TextData[{"(", 
                   CounterBox["Section"], ".", 
                   CounterBox["Equation"], ")"}]]}, {None, None}}, 
             DefaultFormatType -> DefaultInputFormatType, CounterIncrements -> 
             "Equation", FormatTypeAutoConvert -> False], 
            Cell[
             StyleData["NumberedEquation", "Presentation"], FontSize -> 14], 
            Cell[
             StyleData["NumberedEquation", "Printout"], 
             CellMargins -> {{Inherited, Inherited}, {10, Inherited}}, 
             FontSize -> 10], 
            Cell[
             StyleData["NumberedEquation", "Production"], 
             CellMargins -> {{72, 72}, {2, 4}}, 
             PrivateEvaluationOptions -> {"OutputFormPageWidth" -> 342}, 
             FontFamily -> "Janson Text", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
         "NumberedFigureCaption to be used directly after a PlacedGraphic \
cell. Use the TMJAuthorPalette.nb palette to begin the cell and paste in the \
word Figure and the NumberedFigure counter value. Allows for a descriptive \
caption.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedFigureCaption"], CellDingbat -> 
             "\[FilledUpTriangle]", CellMargins -> {{54, 24}, {5, 10}}, 
             CellLabelPositioning -> Left, TextAlignment -> Left, 
             HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
             CounterIncrements -> "NumberedFigure", FormatTypeAutoConvert -> 
             False, FontFamily -> "Helvetica"], 
            Cell[
             StyleData["NumberedFigureCaption", "Presentation"], 
             CellMargins -> {{54, 24}, {2, 10}}, FontSize -> 14], 
            Cell[
             StyleData["NumberedFigureCaption", "Printout"], 
             CellMargins -> {{144, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 8], 
            Cell[
             StyleData["NumberedFigureCaption", "Production"], CellDingbat -> 
             None, CellMargins -> {{72, 72}, {2, 4}}, TextJustification -> 1, 
             FontFamily -> "Futura Book", FontSize -> 9, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Open]], 
         Cell[
         "NumberedTableCaption to be used directly after a Table cell. Use \
the TMJAuthorPalette.nb palette to begin the cell and paste in the word Table \
and the NumberedTable counter value. Allows for a descriptive caption.", 
          "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedTableCaption"], CellDingbat -> 
             "\[FilledUpTriangle]", CellMargins -> {{54, 24}, {5, 10}}, 
             HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
             CounterIncrements -> "NumberedTable", FontFamily -> "Helvetica", 
             FontSize -> 10], 
            Cell[
             StyleData["NumberedTableCaption", "Presentation"], 
             CellMargins -> {{54, 24}, {2, 10}}, FontSize -> 12], 
            Cell[
             StyleData["NumberedTableCaption", "Printout"], 
             CellFrameLabels -> {{None, None}, {None, None}}, FontSize -> 8], 
            
            Cell[
             StyleData["NumberedTableCaption", "Production"], CellDingbat -> 
             None, CellMargins -> {{72, 72}, {2, 4}}, TextJustification -> 1, 
             Hyphenation -> True, FontFamily -> "Futura Book", FontSize -> 9, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
         "NumberedProgramCaption to be used directly after a Program cell. \
Use the TMJAuthorPalette.nb palette to begin the cell and paste in the word \
Listing and the NumberedProgram counter value. Allows for a descriptive \
caption.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedProgramCaption"], CellDingbat -> 
             "\[FilledUpTriangle]", CellMargins -> {{54, 24}, {5, 10}}, 
             CellFrameLabels -> {{None, None}, {None, None}}, 
             HyphenationOptions -> {"HyphenationCharacter" -> "-"}, 
             CounterIncrements -> "NumberedProgram", FormatTypeAutoConvert -> 
             False, FontFamily -> "Helvetica", FontSize -> 10], 
            Cell[
             StyleData["NumberedProgramCaption", "Presentation"], 
             CellMargins -> {{54, 24}, {2, 10}}, FontSize -> 12], 
            Cell[
             StyleData["NumberedProgramCaption", "Printout"], 
             CellFrameLabels -> {{None, None}, {None, None}}, FontSize -> 8], 
            
            Cell[
             StyleData["NumberedProgramCaption", "Production"], CellDingbat -> 
             None, CellMargins -> {{72, 72}, {2, 4}}, TextJustification -> 1, 
             FontFamily -> "Futura Book", FontSize -> 9, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
         "BulletedList is an optional style. Adds a CellDingbat of \
FilledSmallCircle. Text indents left a little more.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["BulletedList"], CellDingbat -> "\[FilledSmallCircle]",
              CellMargins -> {{86, 10}, {Inherited, Inherited}}, FontFamily -> 
             "Times", FontSize -> 12], 
            Cell[
             StyleData["BulletedList", "Presentation"], FontSize -> 14], 
            Cell[
             StyleData["BulletedList", "Printout"], FontSize -> 10], 
            Cell[
             StyleData["BulletedList", "Production"], 
             CellMargins -> {{96, 72}, {2, Inherited}}, TextJustification -> 
             1, Hyphenation -> True, FontFamily -> "Janson Text", FontSize -> 
             10]}, Closed]], 
         Cell[
         "BeginNumberedList to be used as the first item in a numbered list \
sequence. Use the TMJAuthorPalette.nb palette to begin the cell and paste in \
the List counter value.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["BeginNumberedList"], 
             CellMargins -> {{74, 10}, {Inherited, Inherited}}, 
             CounterIncrements -> "List", CounterAssignments -> {{"List", 0}},
              FontFamily -> "Times", FontSize -> 12], 
            Cell[
             StyleData["BeginNumberedList", "Presentation"], FontSize -> 14], 
            
            Cell[
             StyleData["BeginNumberedList", "Printout"], FontSize -> 10], 
            Cell[
             StyleData["BeginNumberedList", "Production"], 
             CellMargins -> {{84, 72}, {2, Inherited}}, Hyphenation -> True, 
             ParagraphIndent -> -13, FontFamily -> "Janson Text", FontSize -> 
             10, FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
         "NumberedList to be used for subsequent items in a numbered list \
sequence with a single digit. Use the TMJAuthorPalette.nb palette to begin \
the cell and paste in the List counter value.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedList"], 
             CellMargins -> {{74, 10}, {Inherited, Inherited}}, 
             CellFrameLabels -> {{None, None}, {None, None}}, 
             CounterIncrements -> "List", FontFamily -> "Times", FontSize -> 
             12], 
            Cell[
             StyleData["NumberedList", "Presentation"], FontSize -> 14], 
            Cell[
             StyleData["NumberedList", "Printout"], FontSize -> 10], 
            Cell[
             StyleData["NumberedList", "Production"], 
             CellMargins -> {{84, 72}, {2, Inherited}}, TextJustification -> 
             1, Hyphenation -> True, ParagraphIndent -> -13, FontFamily -> 
             "Janson Text", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
         "NumberedListTwo to be used for subsequent items in a numbered list \
sequence with two digits. Use the TMJAuthorPalette.nb palette to begin the \
cell and paste in the List counter value.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["NumberedListTwo"], 
             CellMargins -> {{74, 10}, {Inherited, Inherited}}, 
             CounterIncrements -> "List", FontFamily -> "Times", FontSize -> 
             12], 
            Cell[
             StyleData["NumberedListTwo", "Presentation"], FontSize -> 14], 
            Cell[
             StyleData["NumberedListTwo", "Printout"], FontSize -> 10], 
            Cell[
             StyleData["NumberedListTwo", "Production"], 
             CellMargins -> {{84, 72}, {2, Inherited}}, TextJustification -> 
             1, Hyphenation -> True, ParagraphIndent -> -17, FontFamily -> 
             "Janson Text", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
         "Reference style to be used in the bibliography portion of a \
notebook. One cell for each bibliography entry. Use the TMJAuthorPalette.nb \
palette to begin cell and paste in the Reference counter value.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Reference"], 
             CellMargins -> {{54, 25}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 3}, CounterIncrements -> "Reference", 
             FontFamily -> "Helvetica", FontSize -> 10], 
            Cell[
             StyleData["Reference", "Presentation"], FontFamily -> 
             "Helvetica", FontSize -> 12], 
            Cell[
             StyleData["Reference", "Printout"], FontSize -> 8], 
            Cell[
             StyleData["Reference", "Production"], 
             CellMargins -> {{84, 72}, {2, 4}}, TextJustification -> 1, 
             Hyphenation -> True, LineSpacing -> {0, 10}, 
             ParagraphIndent -> -14, FontFamily -> "Futura Book", FontSize -> 
             8, FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ReferenceTwo"], 
             CellMargins -> {{54, 25}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 3}, CounterIncrements -> "Reference", 
             FontFamily -> "Helvetica", FontSize -> 10], 
            Cell[
             StyleData["ReferenceTwo", "Presentation"], FontFamily -> 
             "Helvetica", FontSize -> 12], 
            Cell[
             StyleData["ReferenceTwo", "Printout"], FontSize -> 8], 
            Cell[
             StyleData["ReferenceTwo", "Production"], 
             CellMargins -> {{84, 72}, {2, 4}}, TextJustification -> 1, 
             Hyphenation -> True, LineSpacing -> {0, 10}, 
             ParagraphIndent -> -18, FontFamily -> "Futura Book", FontSize -> 
             8, FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Unique Styles", "Section", CellFrame -> False, CellDingbat -> None, 
          ShowCellBracket -> True, CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
         "OnlineHeader to be used at the beginning of a notebook. Precedes \
the Title cell.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OnlineHeader"], ShowCellBracket -> False, 
             CellMargins -> {{0, 25}, {0, 0}}, 
             CellGroupingRules -> {"TitleGrouping", 30}, PageBreakBelow -> 
             False, CellFrameMargins -> {{54, 4}, {2, 8}}, 
             LineSpacing -> {1, 1}, FontFamily -> "Times", FontSize -> 12, 
             FontWeight -> "Plain", FontSlant -> "Italic", FontTracking -> 
             "Wide", FontVariations -> {
              "CompatibilityType" -> 0, "Masked" -> False, "Outline" -> False,
                "RotationAngle" -> 0, "Shadow" -> False, "StrikeThrough" -> 
               False, "Underline" -> False}, FontColor -> GrayLevel[1], 
             Background -> GrayLevel[0]], 
            Cell[
             StyleData["OnlineHeader", "Presentation"], 
             CellFrameMargins -> {{54, 25}, {8, 8}}, FontSize -> 14], 
            Cell[
             StyleData["OnlineHeader", "Printout"], CellFrame -> False, 
             CellMargins -> {{54, 24}, {10, 10}}, FontFamily -> "Times", 
             FontSize -> 10, FontColor -> GrayLevel[0], Background -> None], 
            Cell[
             StyleData["OnlineHeader", "Production"], PageWidth -> PaperWidth,
              CellFrame -> False, CellMargins -> {{72, 72}, {0, 0}}, 
             CellElementSpacings -> {"CellMinHeight" -> 2}, FontFamily -> 
             "Janson Text", FontSize -> 10, Background -> None]}, Closed]], 
         Cell[
         "Author to be used after the Title cell with author name(s). Author \
name(s) may be preced by \"Edited by \" for certain columns. Text in author \
cell to be used as the left page header. Usually followed by an Address \
cell.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Author"], 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, 
             CellGroupingRules -> {"TitleGrouping", 20}, PageBreakBelow -> 
             False, FontFamily -> "Helvetica", FontSize -> 14, FontWeight -> 
             "Bold", FontSlant -> "Plain"], 
            Cell[
             StyleData["Author", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["Author", "Printout"], 
             CellMargins -> {{54, 24}, {2, 15}}, FontSize -> 12], 
            Cell[
             StyleData["Author", "Production"], 
             CellMargins -> {{72, 72}, {4, 4}}, LineSpacing -> {0, 14}, 
             FontFamily -> "CXB Futura CondExtraBold", FontSize -> 12, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> False}]}, Closed]], 
         
         Cell[
         "Address to be used after Author or SecondAuthor. Contains contact \
information for article (section) author.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Address"], 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, 
             CellGroupingRules -> {"TitleGrouping", 30}, PageBreakBelow -> 
             False, LineSpacing -> {1, 1}, FontFamily -> "Times", FontSize -> 
             12, FontWeight -> "Plain", FontSlant -> "Italic"], 
            Cell[
             StyleData["Address", "Presentation"], FontSize -> 14], 
            Cell[
             StyleData["Address", "Printout"], 
             CellMargins -> {{54, 24}, {30, 2}}, FontSize -> 10], 
            Cell[
             StyleData["Address", "Production"], 
             CellMargins -> {{72, 72}, {22, 4}}, LineSpacing -> {0, 12}, 
             FontFamily -> "I Janson Text Italic", FontSize -> 8, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
         "Abstract to be used after the Address cell. Contains a short \
descriptive summary of the article.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Abstract"], 
             CellMargins -> {{54, 24}, {Inherited, 30}}, 
             LineSpacing -> {1, 3}, FontFamily -> "Times", FontSize -> 14, 
             FontWeight -> "Bold", FontSlant -> "Italic"], 
            Cell[
             StyleData["Abstract", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["Abstract", "Printout"], 
             CellMargins -> {{54, 24}, {20, 30}}, FontSize -> 12, FontSlant -> 
             "Italic"], 
            Cell[
             StyleData["Abstract", "Production"], 
             CellMargins -> {{72, 72}, {Inherited, 2}}, TextJustification -> 
             1, Hyphenation -> True, LineSpacing -> {0, 12}, FontFamily -> 
             "BI Janson Text Bold Italic", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
         "PictureGroup style definitions included for compatability with the \
Help Browser.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["PictureGroup"], CellFrame -> {{1, 0}, {0, 1}}, 
             CellMargins -> {{54, 25}, {0, 0}}, CellGroupingRules -> 
             "GraphicsGrouping", CellHorizontalScrolling -> True, 
             PageBreakWithin -> False, ShowCellLabel -> False, 
             CounterIncrements -> "Graphics", 
             ImageMargins -> {{35, Inherited}, {Inherited, 0}}, 
             StyleMenuListing -> None], 
            Cell[
             StyleData["PictureGroup", "Presentation"], CounterIncrements -> 
             "Graphics", ImageMargins -> {{35, Inherited}, {Inherited, 0}}, 
             StyleMenuListing -> None], 
            Cell[
             StyleData["PictureGroup", "Printout"], 
             CellMargins -> {{54, Inherited}, {0, 0}}, 
             ImageSize -> {0.0625, 0.0625}], 
            Cell[
             StyleData["PictureGroup", "Production"], CellFrame -> False, 
             CellMargins -> {{72, 72}, {8, 10}}, LineSpacing -> {0, 12}, 
             FontFamily -> "Janson Text", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MarkersComment"], CellFrame -> False, CellDingbat -> 
             "\[FilledCircle]", 
             CellMargins -> {{54, 25}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 3}, CounterIncrements -> "Text", FontColor -> 
             RGBColor[1, 0, 0], Background -> GrayLevel[1]], 
            Cell[
             StyleData["MarkersComment", "Printout"], 
             CellMargins -> {{18, 4}, {Inherited, 0}}, LineSpacing -> {1, 3}, 
             FontSize -> 10], 
            Cell[
             StyleData["MarkersComment", "Production"], 
             CellMargins -> {{24, 0}, {Inherited, 0}}, LineSpacing -> {1, 3}, 
             FontFamily -> "Janson Text", FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Marks"], CellMargins -> {{54, 24}, {Inherited, 30}}, 
             FontFamily -> "Times", FontColor -> RGBColor[1, 0, 0]], 
            Cell[
             StyleData["Marks", "Presentation"], LineSpacing -> {1, 5}], 
            Cell[
             StyleData["Marks", "Printout"]]}, Closed]], 
         Cell[
         "Table cell style to be used for cells containing displayed tabular \
material. Can be followed by NumberedTableCaption cell.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Table"], CellMargins -> {{54, 24}, {5, 10}}, 
             TextAlignment -> Center, FontFamily -> "Times", FontSize -> 12, 
             Background -> GrayLevel[0.899001]], 
            Cell[
             StyleData["Table", "Presentation"], FontSize -> 14], 
            Cell[
             StyleData["Table", "Printout"], FontSize -> 10, Background -> 
             None], 
            Cell[
             StyleData["Table", "Production"], 
             CellMargins -> {{72, 72}, {0, 4}}, FontFamily -> "Janson Text", 
             FontSize -> 10, Background -> None]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Menu"], 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 4}, ParagraphSpacing -> {0, 12}, FontFamily -> 
             "Charcoal"], 
            Cell[
             StyleData["Menu", "Presentation"]], 
            Cell[
             StyleData["Menu", "Printout"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Warning"], CellDingbat -> "\[WarningSign]", 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 4}, ParagraphSpacing -> {0, 12}], 
            Cell[
             StyleData["Warning", "Presentation"], LineSpacing -> {1, 5}, 
             ParagraphSpacing -> {0, 12}], 
            Cell[
             StyleData["Warning", "Printout"], TextJustification -> 1, 
             FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["BrightIdea"], CellDingbat -> "\[LightBulb]", 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, FontFamily -> 
             "Times"], 
            Cell[
             StyleData["BrightIdea", "Presentation"]], 
            Cell[
             StyleData["BrightIdea", "Printout"], TextJustification -> 1, 
             FontSize -> 10]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Formulas and Programming", "Section", CellFrame -> False, 
          CellDingbat -> None, ShowCellBracket -> True, 
          CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], 
             CellMargins -> {{100, 10}, {Inherited, Inherited}}, 
             CellHorizontalScrolling -> True, DefaultFormatType -> 
             DefaultInputFormatType, ScriptLevel -> 0, SingleLetterItalics -> 
             True, FontFamily -> "Times", FontSize -> 12, 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
            Cell[
             StyleData["DisplayFormula", "Presentation"], FontSize -> 14], 
            Cell[
             StyleData["DisplayFormula", "Printout"], 
             CellMargins -> {{54, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 10], 
            Cell[
             StyleData["DisplayFormula", "Production"], 
             CellMargins -> {{72, 72}, {2, 4}}, 
             PrivateEvaluationOptions -> {"OutputFormPageWidth" -> 342}, 
             LineSpacing -> {1.25, 0}, FontFamily -> "Janson Text", FontSize -> 
             10, FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["ChemicalFormula"], CellMargins -> {{54, 25}, {2, 10}},
              DefaultFormatType -> DefaultInputFormatType, AutoSpacing -> 
             False, ScriptBaselineShifts -> {0.6, Automatic}, ScriptLevel -> 
             1, SingleLetterItalics -> False, ZeroWidthTimes -> True, 
             FontFamily -> "Times", FontSize -> 12], 
            Cell[
             StyleData["ChemicalFormula", "Presentation"], FontSize -> 14], 
            Cell[
             StyleData["ChemicalFormula", "Printout"], 
             CellMargins -> {{54, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 10], 
            Cell[
             StyleData["ChemicalFormula", "Production"], 
             CellMargins -> {{72, 72}, {2, 4}}, LineSpacing -> {0, 12}, 
             FontFamily -> "Janson Text", FontSize -> 10, 
             FontProperties -> {
              "FontMonospaced" -> False, "FontSerifed" -> True}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"], CellMargins -> {{54, 25}, {Inherited, 6}}, 
             FontFamily -> "Courier", FontSize -> 10], 
            Cell[
             StyleData["Program", "Presentation"], FontFamily -> "Courier", 
             FontSize -> 12], 
            Cell[
             StyleData["Program", "Printout"], 
             CellMargins -> {{54, 30}, {Inherited, 4}}, FontSize -> 9], 
            Cell[
             StyleData["Program", "Production"], 
             CellMargins -> {{72, 72}, {2, 4}}, LineSpacing -> {0, 11}, 
             FontFamily -> "WriCMTT9", FontSize -> 9, 
             FontProperties -> {
              "FontMonospaced" -> True, "FontSerifed" -> True}]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Styles for Headers and Footers", "Section", CellFrame -> False, 
          CellDingbat -> None, ShowCellBracket -> True, 
          CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Header"], CellMargins -> {{54, 24}, {0, 0}}, 
             StyleMenuListing -> None, FontFamily -> "Times", FontSize -> 9, 
             FontSlant -> "Italic"], 
            Cell[
             StyleData["Header", "Presentation"]], 
            Cell[
             StyleData["Header", "Printout"]], 
            Cell[
             StyleData["Header", "Production"], PageWidth -> PaperWidth, 
             CellMargins -> {{72, 72}, {2, 2}}, StyleMenuListing -> None, 
             FontFamily -> "I Janson Text Italic", FontSize -> 9]}, Closed]], 
         
         Cell[
          CellGroupData[{
            Cell[
             StyleData["PageNumber"], StyleMenuListing -> None, FontFamily -> 
             "Times", FontSize -> 9, FontWeight -> "Bold"], 
            Cell[
             StyleData["PageNumber", "Production"], PageWidth -> PaperWidth, 
             CellMargins -> {{72, 72}, {2, 2}}, StyleMenuListing -> None, 
             FontFamily -> "B Janson Text Bold"]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Footer"], 
             CellMargins -> {{54, 24}, {Inherited, Inherited}}, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
             7, FontSlant -> "Italic"], 
            Cell[
             StyleData["Footer", "Production"], PageWidth -> PaperWidth, 
             CellMargins -> {{72, 72}, {2, 2}}, StyleMenuListing -> None, 
             FontFamily -> "O Futura BookOblique", FontSize -> 6]}, Closed]]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Hyperlink Styles", "Section", CellFrame -> False, CellDingbat -> 
          None, ShowCellBracket -> True, CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
         "The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Hyperlink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`NotebookLocate[#2]}]& ), ButtonNote -> 
               ButtonData}], 
            Cell[
             StyleData["Hyperlink", "Presentation"]], 
            Cell[
             StyleData["Hyperlink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["Hyperlink", "Production"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
         "The following styles are for linking automatically to the on-line \
help system.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MainBookLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFrame -> "None", 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["MainBook", #]}]& )}], 
            Cell[
             StyleData["MainBookLink", "Presentation"]], 
            Cell[
             StyleData["MainBookLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["MainBookLink", "Production"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["AddOnsLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFrame -> "None", 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["AddOns", #]}]& )}], 
            Cell[
             StyleData["AddOnsLink", "Presentation"]], 
            Cell[
             StyleData["AddOnsLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["AddOnsLink", "Production"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["RefGuideLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFrame -> "None", 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["RefGuide", #]}]& )}], 
            Cell[
             StyleData["RefGuideLink", "Presentation"]], 
            Cell[
             StyleData["RefGuideLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["RefGuideLink", "Production"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["GettingStartedLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFrame -> "None", 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["GettingStarted", #]}]& )}], 
            Cell[
             StyleData["GettingStartedLink", "Presentation"]], 
            Cell[
             StyleData["GettingStartedLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["GettingStartedLink", "Production"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OtherInformationLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFrame -> "None", 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["OtherInformation", #]}]& )}], 
            Cell[
             StyleData["OtherInformationLink", "Presentation"]], 
            Cell[
             StyleData["OtherInformationLink", "Printout"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]], 
            Cell[
             StyleData["OtherInformationLink", "Production"], 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "FormatType Styles", "Section", CellFrame -> False, CellDingbat -> 
          None, ShowCellBracket -> True, CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
         "These cells define styles that are mixed in with most other cells.  \
If the FormatType of a cell style matches the name of one of the styles \
defined below, then that style is applied along with the local cell style \
definitions. This is particularly true of Input and Output.", "Text", 
          CellMargins -> {{24, 0}, {Inherited, Inherited}}], 
         Cell[
          StyleData["CellExpression"], CellMargins -> {{54, 24}, {2, 4}}, 
          ShowCellLabel -> False, ShowSpecialCharacters -> False, 
          AllowInlineCells -> False, Hyphenation -> False, 
          AutoItalicWords -> {}, StyleMenuListing -> None, FontFamily -> 
          "Courier", FontSize -> 10, Background -> GrayLevel[1]], 
         Cell[
          StyleData["InputForm"], AllowInlineCells -> False, Hyphenation -> 
          False, LineSpacing -> {1.25, 0}, StyleMenuListing -> None, 
          FontFamily -> "Courier", 
          FontProperties -> {
           "FontMonospaced" -> True, "FontSerifed" -> True}], 
         Cell[
          StyleData["OutputForm"], LineSpacing -> {1.25, 0}, StyleMenuListing -> 
          None, FontFamily -> "Courier", 
          FontProperties -> {
           "FontMonospaced" -> True, "FontSerifed" -> True}], 
         Cell[
          StyleData["StandardForm"], LineSpacing -> {1.25, 0}, 
          SingleLetterItalics -> False, StyleMenuListing -> None, FontFamily -> 
          "Courier", 
          FontProperties -> {
           "FontMonospaced" -> True, "FontSerifed" -> True}], 
         Cell[
          StyleData["TraditionalForm"], 
          InputAutoReplacements -> {
           "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> 
            "\[LessEqual]", ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", 
            "==" -> "\[Equal]", Inherited}, LineSpacing -> {1.25, 0}, 
          SingleLetterItalics -> True, TraditionalFunctionNotation -> True, 
          DelimiterMatching -> None, StyleMenuListing -> None, FontFamily -> 
          "Times", 
          FontProperties -> {
           "FontMonospaced" -> False, "FontSerifed" -> True}], 
         Cell[
         "The style defined below is mixed in to any cell that is in an \
inline cell within another.", "Text", 
          CellMargins -> {{24, 0}, {Inherited, Inherited}}], 
         Cell[
          StyleData["InlineCell"], TextAlignment -> Left, ScriptLevel -> 1, 
          StyleMenuListing -> None], 
         Cell[
          StyleData["InlineCellEditing"], StyleMenuListing -> None, 
          Background -> RGBColor[1, 0.749996, 0.8]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
         "Inline Formatting", "Section", CellFrame -> False, CellDingbat -> 
          None, ShowCellBracket -> True, CellMargins -> {{0, 0}, {10, 40}}, 
          CellFrameMargins -> {{20, 4}, {8, 8}}, FontColor -> GrayLevel[1], 
          Background -> RGBColor[0.269902, 0.558434, 0.715618]], 
         Cell[
         "These styles are for modifying individual words or letters in a \
cell exclusive of the cell style.", "Text", PageWidth -> 342, 
          CellMargins -> {{24, 0}, {Inherited, Inherited}}], 
         Cell[
         "RM used to change selection to FontWeight->Plain, FontSlant->Plain",
           "Text"], 
         Cell[
          StyleData["RM"], FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
         "BF used to change selection to FontWeight->Bold, FontSlant->Plain", 
          "Text"], 
         Cell[
          StyleData["BF"], FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
         "IT used to change selection to FontWeight->Plain, \
FontSlant->Italic", "Text"], 
         Cell[
          StyleData["IT"], FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
         "BFI used to change selection to FontWeight->Bold, \
FontSlant->Italic", "Text"], 
         Cell[
          StyleData["BFI"], FontWeight -> "Bold", FontSlant -> "Italic"], 
         Cell[
         "TR used to change selection to normal text font, FontWeight->Plain, \
FontSlant->Plain", "Text"], 
         Cell[
          StyleData["TR"], FontFamily -> "Times", FontWeight -> "Plain", 
          FontSlant -> "Plain"], 
         Cell[
         "TI used to change selection to normal text font, FontWeight->Plain, \
FontSlant->Italic", "Text"], 
         Cell[
          StyleData["TI"], FontFamily -> "Times", FontWeight -> "Plain", 
          FontSlant -> "Italic"], 
         Cell[
         "TB used to change selection to normal text font, FontWeight->Bold, \
FontSlant->Plain", "Text"], 
         Cell[
          StyleData["TB"], FontFamily -> "Times", FontWeight -> "Bold", 
          FontSlant -> "Plain"], 
         Cell[
         "TBI used to change selection to normal text font, FontWeight->Bold, \
FontSlant->Italic", "Text"], 
         Cell[
          StyleData["TBI"], FontFamily -> "Times", FontWeight -> "Bold", 
          FontSlant -> "Italic"], 
         Cell[
         "MR used to change selection to monospace font with \
FontWeight->Plain, FontSlant->Plain", "Text"], 
         Cell[
          StyleData["MR"], StyleMenuListing -> None, FontFamily -> "Courier", 
          FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
         "MR used to change selection to monospace font with \
FontWeight->Plain, FontSlant->Oblique", "Text"], 
         Cell[
          StyleData["MO"], StyleMenuListing -> None, FontFamily -> "Courier", 
          FontWeight -> "Plain", FontSlant -> "Oblique"], 
         Cell[
         "MB used to change selection to monospace font with \
FontWeight->Bold, FontSlant->Plain", "Text"], 
         Cell[
          StyleData["MB"], StyleMenuListing -> None, FontFamily -> "Courier", 
          FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
         "MBO used to change selection to monospace font with \
FontWeight->Bold, FontSlant->Oblique", "Text"], 
         Cell[
          StyleData["MBO"], StyleMenuListing -> None, FontFamily -> "Courier",
           FontWeight -> "Bold", FontSlant -> "Oblique"], 
         Cell[
         "SR used to change selection to sans serif font with \
FontWeight->Plain, FontSlant->Plain", "Text"], 
         Cell[
          StyleData["SR"], FontFamily -> "Helvetica", FontWeight -> "Plain", 
          FontSlant -> "Plain"], 
         Cell[
         "SO used to change selection to sans serif font with \
FontWeight->Plain, FontSlant->Oblique", "Text"], 
         Cell[
          StyleData["SO"], FontFamily -> "Helvetica", FontWeight -> "Plain", 
          FontSlant -> "Oblique"], 
         Cell[
         "SB used to change selection to sans serif font with \
FontWeight->Bold, FontSlant->Plain", "Text"], 
         Cell[
          StyleData["SB"], FontFamily -> "Helvetica", FontWeight -> "Bold", 
          FontSlant -> "Plain"], 
         Cell[
         "SBO used to change selection to sans serif font with \
FontWeight->Bold, FontSlant->Oblique", "Text"], 
         Cell[
          StyleData["SBO"], FontFamily -> "Helvetica", FontSize -> 10, 
          FontWeight -> "Bold", FontSlant -> "Oblique"]}, Closed]]}, Open]]}, 
  Visible -> False, FrontEndVersion -> 
  "6.0 for Microsoft Windows (32-bit) (April 9, 2007)", StyleDefinitions -> 
  "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Equal"->{
  Cell[4667, 167, 319, 11, 28, "Text",
   CellTags->{"Equal", "Listable"}]},
 "Listable"->{
  Cell[4667, 167, 319, 11, 28, "Text",
   CellTags->{"Equal", "Listable"}]},
 "pulsar PSR1257+12"->{
  Cell[12771, 428, 717, 20, 72, "Text",
   CellTags->"pulsar PSR1257+12"]},
 "timing residuals"->{
  Cell[14092, 461, 911, 23, 94, "Text",
   CellTags->{"timing residuals", "Alex Wolszczan"}]},
 "Alex Wolszczan"->{
  Cell[14092, 461, 911, 23, 94, "Text",
   CellTags->{"timing residuals", "Alex Wolszczan"}]},
 "residuals"->{
  Cell[15926, 529, 217, 10, 55, "BeginEndQuestion",
   CellTags->"residuals"]},
 "Fourier"->{
  Cell[16146, 541, 2063, 64, 140, "Text",
   CellGroupingRules->{"SectionGrouping", 55},
   CellTags->{
    "Fourier", "astronomical time-series data", "spectral analysis", 
     "irregularly sampled data", "interpolation", "resampling", 
     "linear least-squares", "spectral energy"}]},
 "astronomical time-series data"->{
  Cell[16146, 541, 2063, 64, 140, "Text",
   CellGroupingRules->{"SectionGrouping", 55},
   CellTags->{
    "Fourier", "astronomical time-series data", "spectral analysis", 
     "irregularly sampled data", "interpolation", "resampling", 
     "linear least-squares", "spectral energy"}]},
 "spectral analysis"->{
  Cell[16146, 541, 2063, 64, 140, "Text",
   CellGroupingRules->{"SectionGrouping", 55},
   CellTags->{
    "Fourier", "astronomical time-series data", "spectral analysis", 
     "irregularly sampled data", "interpolation", "resampling", 
     "linear least-squares", "spectral energy"}]},
 "irregularly sampled data"->{
  Cell[16146, 541, 2063, 64, 140, "Text",
   CellGroupingRules->{"SectionGrouping", 55},
   CellTags->{
    "Fourier", "astronomical time-series data", "spectral analysis", 
     "irregularly sampled data", "interpolation", "resampling", 
     "linear least-squares", "spectral energy"}]},
 "interpolation"->{
  Cell[16146, 541, 2063, 64, 140, "Text",
   CellGroupingRules->{"SectionGrouping", 55},
   CellTags->{
    "Fourier", "astronomical time-series data", "spectral analysis", 
     "irregularly sampled data", "interpolation", "resampling", 
     "linear least-squares", "spectral energy"}]},
 "resampling"->{
  Cell[16146, 541, 2063, 64, 140, "Text",
   CellGroupingRules->{"SectionGrouping", 55},
   CellTags->{
    "Fourier", "astronomical time-series data", "spectral analysis", 
     "irregularly sampled data", "interpolation", "resampling", 
     "linear least-squares", "spectral energy"}]},
 "linear least-squares"->{
  Cell[16146, 541, 2063, 64, 140, "Text",
   CellGroupingRules->{"SectionGrouping", 55},
   CellTags->{
    "Fourier", "astronomical time-series data", "spectral analysis", 
     "irregularly sampled data", "interpolation", "resampling", 
     "linear least-squares", "spectral energy"}]},
 "spectral energy"->{
  Cell[16146, 541, 2063, 64, 140, "Text",
   CellGroupingRules->{"SectionGrouping", 55},
   CellTags->{
    "Fourier", "astronomical time-series data", "spectral analysis", 
     "irregularly sampled data", "interpolation", "resampling", 
     "linear least-squares", "spectral energy"}]},
 "two-scale dilation equation"->{
  Cell[23068, 804, 411, 14, 70, "NumberedEquation",
   CellTags->"two-scale dilation equation"]},
 "boundary conditions"->{
  Cell[23558, 825, 391, 12, 70, "NumberedEquation",
   CellTags->"boundary conditions"],
  Cell[39390, 1468, 238, 8, 70, "NumberedEquation",
   CellTags->"boundary conditions"]},
 "wavelet theory"->{
  Cell[23952, 839, 377, 14, 70, "Text",
   CellTags->"wavelet theory"]},
 "eigenvalue equation"->{
  Cell[25319, 903, 721, 27, 70, "NumberedEquation",
   CellTags->"eigenvalue equation"]},
 "coefficient conditions"->{
  Cell[26946, 973, 1860, 66, 70, "NumberedEquation",
   CellTags->"coefficient conditions"]},
 "Green function"->{
  Cell[35934, 1338, 1275, 42, 70, "Text",
   CellTags->{"Green function", "Dirac delta function", "distribution"}]},
 "Dirac delta function"->{
  Cell[35934, 1338, 1275, 42, 70, "Text",
   CellTags->{"Green function", "Dirac delta function", "distribution"}]},
 "distribution"->{
  Cell[35934, 1338, 1275, 42, 70, "Text",
   CellTags->{"Green function", "Dirac delta function", "distribution"}]},
 "homogenous boundary conditions"->{
  Cell[37234, 1384, 524, 17, 70, "NumberedEquation",
   CellTags->"homogenous boundary conditions"]},
 "solution"->{
  Cell[38451, 1428, 384, 13, 70, "NumberedEquation",
   CellTags->"solution"]},
 "forced simple harmonic oscillator"->{
  Cell[38983, 1451, 317, 10, 70, "NumberedEquation",
   CellTags->"forced simple harmonic oscillator"]},
 "region-dependent function"->{
  Cell[39631, 1478, 213, 7, 70, "Text",
   CellTags->"region-dependent function"]},
 "discontinuous derivative"->{
  Cell[42243, 1582, 777, 27, 70, "BeginEndQuestion",
   CellTags->"discontinuous derivative"]},
 "exact solution"->{
  Cell[43023, 1611, 1060, 44, 70, "BeginEndQuestion",
   CellTags->"exact solution"]},
 "discretizing equations"->{
  Cell[44108, 1659, 556, 16, 70, "Text",
   CellGroupingRules->{"SectionGrouping", 55},
   CellTags->{"discretizing equations", "inverse problem"}]},
 "inverse problem"->{
  Cell[44108, 1659, 556, 16, 70, "Text",
   CellGroupingRules->{"SectionGrouping", 55},
   CellTags->{"discretizing equations", "inverse problem"}]},
 "equally spaced data points"->{
  Cell[47195, 1768, 353, 9, 70, "Warning",
   CellTags->{"equally spaced data points", "trapezoid approximation"}]},
 "trapezoid approximation"->{
  Cell[47195, 1768, 353, 9, 70, "Warning",
   CellTags->{"equally spaced data points", "trapezoid approximation"}]},
 "Moore-Penrose inverse"->{
  Cell[47551, 1779, 948, 34, 70, "Text",
   CellTags->{"Moore-Penrose inverse", "PseudoInverse"}]},
 "PseudoInverse"->{
  Cell[47551, 1779, 948, 34, 70, "Text",
   CellTags->{"Moore-Penrose inverse", "PseudoInverse"}]},
 "equation of state"->{
  Cell[50668, 1906, 231, 6, 70, "Text",
   CellTags->{"equation of state", "ideal gas"}]},
 "ideal gas"->{
  Cell[50668, 1906, 231, 6, 70, "Text",
   CellTags->{"equation of state", "ideal gas"}]},
 "Boltzmann constant"->{
  Cell[51141, 1925, 324, 8, 70, "Text",
   CellTags->{"Boltzmann constant", "van der Waals equation"}]},
 "van der Waals equation"->{
  Cell[51141, 1925, 324, 8, 70, "Text",
   CellTags->{"Boltzmann constant", "van der Waals equation"}]},
 "van der Waals"->{
  Cell[51502, 1938, 399, 14, 70, "NumberedEquation",
   CellTags->"van der Waals"]},
 "equal area"->{
  Cell[57344, 2181, 550, 20, 70, "NumberedEquation",
   CellTags->"equal area"]},
 "two-phase line"->{
  Cell[57897, 2203, 1816, 64, 70, "Text",
   CellTags->{"two-phase line", "Maxwell construction"}]},
 "Maxwell construction"->{
  Cell[57897, 2203, 1816, 64, 70, "Text",
   CellTags->{"two-phase line", "Maxwell construction"}]},
 "two-phase"->{
  Cell[59728, 2270, 953, 33, 70, "NumberedEquation",
   CellTags->"two-phase"]},
 "wave equation"->{
  Cell[62922, 2401, 524, 17, 49, "NumberedEquation",
   CellTags->"wave equation"]},
 "boundary condition"->{
  Cell[63449, 2420, 205, 6, 27, "Text",
   CellTags->{"boundary condition", "polar coordinates"}]},
 "polar coordinates"->{
  Cell[63449, 2420, 205, 6, 27, "Text",
   CellTags->{"boundary condition", "polar coordinates"}]},
 "Laplacian"->{
  Cell[63691, 2431, 416, 14, 52, "NumberedEquation",
   CellTags->"Laplacian"]},
 "separation of variables"->{
  Cell[65390, 2500, 930, 37, 82, "BeginEndQuestion",
   CellTags->"separation of variables"]},
 "Pauli spin matrices"->{
  Cell[70624, 2713, 133, 6, 27, "Text",
   CellTags->"Pauli spin matrices"]},
 "Levi-Civita tensor"->{
  Cell[73246, 2824, 1959, 74, 112, "BeginEndQuestion",
   CellTags->"Levi-Civita tensor"]},
 "Dirac gamma matrices"->{
  Cell[79849, 3082, 352, 15, 45, "BeginQuestion",
   CellTags->"Dirac gamma matrices"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Equal", 169013, 5068},
 {"Listable", 169105, 5071},
 {"pulsar PSR1257+12", 169206, 5074},
 {"timing residuals", 169305, 5077},
 {"Alex Wolszczan", 169421, 5080},
 {"residuals", 169532, 5083},
 {"Fourier", 169626, 5086},
 {"astronomical time-series data", 169952, 5093},
 {"spectral analysis", 170266, 5100},
 {"irregularly sampled data", 170587, 5107},
 {"interpolation", 170897, 5114},
 {"resampling", 171204, 5121},
 {"linear least-squares", 171521, 5128},
 {"spectral energy", 171833, 5135},
 {"two-scale dilation equation", 172157, 5142},
 {"boundary conditions", 172281, 5145},
 {"wavelet theory", 172481, 5150},
 {"eigenvalue equation", 172580, 5153},
 {"coefficient conditions", 172699, 5156},
 {"Green function", 172814, 5159},
 {"Dirac delta function", 172958, 5162},
 {"distribution", 173094, 5165},
 {"homogenous boundary conditions", 173248, 5168},
 {"solution", 173365, 5171},
 {"forced simple harmonic oscillator", 173485, 5174},
 {"region-dependent function", 173622, 5177},
 {"discontinuous derivative", 173737, 5180},
 {"exact solution", 173854, 5183},
 {"discretizing equations", 173970, 5186},
 {"inverse problem", 174142, 5190},
 {"equally spaced data points", 174325, 5194},
 {"trapezoid approximation", 174472, 5197},
 {"Moore-Penrose inverse", 174617, 5200},
 {"PseudoInverse", 174737, 5203},
 {"equation of state", 174861, 5206},
 {"ideal gas", 174968, 5209},
 {"Boltzmann constant", 175084, 5212},
 {"van der Waals equation", 175218, 5215},
 {"van der Waals", 175343, 5218},
 {"equal area", 175445, 5221},
 {"two-phase line", 175548, 5224},
 {"Maxwell construction", 175676, 5227},
 {"two-phase", 175793, 5230},
 {"wave equation", 175894, 5233},
 {"boundary condition", 176004, 5236},
 {"polar coordinates", 176128, 5239},
 {"Laplacian", 176244, 5242},
 {"separation of variables", 176355, 5245},
 {"Pauli spin matrices", 176476, 5248},
 {"Levi-Civita tensor", 176579, 5251},
 {"Dirac gamma matrices", 176698, 5254}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 45, 0, 29, "OnlineHeader"],
Cell[CellGroupData[{
Cell[638, 25, 26, 0, 92, "Title"],
Cell[667, 27, 373, 9, 137, "Address"],
Cell[CellGroupData[{
Cell[1065, 40, 34, 0, 66, "Subsection"],
Cell[1102, 42, 125, 3, 70, "Text"],
Cell[1230, 47, 432, 13, 70, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[1699, 65, 32, 0, 37, "Subsection"],
Cell[1734, 67, 129, 5, 70, "Text"],
Cell[1866, 74, 465, 7, 70, "Quote"],
Cell[2334, 83, 404, 6, 70, "Quote"],
Cell[2741, 91, 476, 9, 70, "Warning"]
}, Closed]],
Cell[CellGroupData[{
Cell[3254, 105, 46, 0, 37, "Subsection"],
Cell[3303, 107, 365, 12, 70, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[3705, 124, 36, 0, 37, "Subsection"],
Cell[3744, 126, 130, 3, 27, "Text"],
Cell[CellGroupData[{
Cell[3899, 133, 33, 0, 50, "Subsubsection"],
Cell[3935, 135, 212, 5, 28, "Text"],
Cell[4150, 142, 151, 5, 27, "Input",
 InitializationCell->True],
Cell[4304, 149, 85, 2, 27, "Text"],
Cell[4392, 153, 201, 7, 27, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[4630, 165, 34, 0, 50, "Subsubsection"],
Cell[4667, 167, 319, 11, 28, "Text",
 CellTags->{"Equal", "Listable"}],
Cell[4989, 180, 143, 5, 27, "Input",
 InitializationCell->True],
Cell[5135, 187, 254, 8, 27, "Input",
 InitializationCell->True],
Cell[5392, 197, 431, 12, 49, "Input",
 InitializationCell->True],
Cell[5826, 211, 139, 4, 27, "Input",
 InitializationCell->True],
Cell[5968, 217, 58, 0, 27, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6063, 222, 39, 0, 50, "Subsubsection"],
Cell[6105, 224, 148, 4, 27, "Input",
 InitializationCell->True],
Cell[6256, 230, 2773, 78, 159, "Input",
 InitializationCell->True],
Cell[9032, 310, 348, 8, 71, "Input",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[9417, 323, 52, 0, 50, "Subsubsection"],
Cell[9472, 325, 250, 8, 27, "Input",
 InitializationCell->True],
Cell[9725, 335, 202, 7, 27, "Input",
 InitializationCell->True],
Cell[9930, 344, 63, 0, 27, "Text"],
Cell[9996, 346, 315, 8, 71, "Input",
 InitializationCell->True],
Cell[10314, 356, 2279, 59, 247, "Input",
 InitializationCell->True]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[12642, 421, 126, 5, 50, "SectionFirst"],
Cell[12771, 428, 717, 20, 72, "Text",
 CellTags->"pulsar PSR1257+12"],
Cell[13491, 450, 598, 9, 115, "Text"],
Cell[14092, 461, 911, 23, 94, "Text",
 CellTags->{"timing residuals", "Alex Wolszczan"}],
Cell[15006, 486, 264, 12, 61, "BeginEndQuestion"],
Cell[15273, 500, 650, 27, 74, "BeginEndQuestion"],
Cell[15926, 529, 217, 10, 55, "BeginEndQuestion",
 CellTags->"residuals"],
Cell[16146, 541, 2063, 64, 140, "Text",
 CellGroupingRules->{"SectionGrouping", 55},
 CellTags->{
  "Fourier", "astronomical time-series data", "spectral analysis", 
   "irregularly sampled data", "interpolation", "resampling", 
   "linear least-squares", "spectral energy"}],
Cell[18212, 607, 756, 29, 60, "BeginEndQuestion"],
Cell[18971, 638, 496, 22, 55, "BeginEndQuestion"],
Cell[19470, 662, 444, 15, 74, "BeginEndQuestion"],
Cell[CellGroupData[{
Cell[19939, 681, 219, 8, 39, "BeginQuestion"],
Cell[20161, 691, 572, 17, 27, "Input"],
Cell[20736, 710, 1743, 68, 107, "EndQuestion"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[22528, 784, 99, 5, 82, "Section"],
Cell[22630, 791, 413, 9, 70, "Text"],
Cell[CellGroupData[{
Cell[23068, 804, 411, 14, 70, "NumberedEquation",
 CellTags->"two-scale dilation equation"],
Cell[23482, 820, 39, 0, 70, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23558, 825, 391, 12, 70, "NumberedEquation",
 CellTags->"boundary conditions"],
Cell[23952, 839, 377, 14, 70, "Text",
 CellTags->"wavelet theory"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24366, 858, 950, 43, 70, "BeginQuestion"],
Cell[25319, 903, 721, 27, 70, "NumberedEquation",
 CellTags->"eigenvalue equation"],
Cell[26043, 932, 462, 18, 70, "EndQuestion"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26542, 955, 401, 16, 70, "BeginQuestion"],
Cell[26946, 973, 1860, 66, 70, "NumberedEquation",
 CellTags->"coefficient conditions"],
Cell[28809, 1041, 766, 33, 70, "EndQuestion"]
}, Open  ]],
Cell[29590, 1077, 773, 32, 70, "BeginEndQuestion"],
Cell[30366, 1111, 1013, 44, 70, "BeginEndQuestion"],
Cell[31382, 1157, 900, 39, 70, "BeginEndQuestion"],
Cell[32285, 1198, 2602, 93, 70, "BeginEndQuestion"],
Cell[34890, 1293, 868, 33, 70, "BeginEndQuestion"]
}, Closed]],
Cell[CellGroupData[{
Cell[35795, 1331, 136, 5, 48, "Section"],
Cell[35934, 1338, 1275, 42, 70, "Text",
 CellTags->{"Green function", "Dirac delta function", "distribution"}],
Cell[CellGroupData[{
Cell[37234, 1384, 524, 17, 70, "NumberedEquation",
 CellTags->"homogenous boundary conditions"],
Cell[37761, 1403, 230, 4, 70, "Text"],
Cell[37994, 1409, 420, 14, 70, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38451, 1428, 384, 13, 70, "NumberedEquation",
 CellTags->"solution"],
Cell[38838, 1443, 108, 3, 70, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38983, 1451, 317, 10, 70, "NumberedEquation",
 CellTags->"forced simple harmonic oscillator"],
Cell[39303, 1463, 50, 0, 70, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[39390, 1468, 238, 8, 70, "NumberedEquation",
 CellTags->"boundary conditions"],
Cell[39631, 1478, 213, 7, 70, "Text",
 CellTags->"region-dependent function"]
}, Open  ]],
Cell[39859, 1488, 970, 31, 70, "NumberedEquation"],
Cell[40832, 1521, 189, 8, 70, "BeginEndQuestion"],
Cell[41024, 1531, 872, 34, 70, "BeginEndQuestion"],
Cell[41899, 1567, 341, 13, 70, "BeginEndQuestion"],
Cell[42243, 1582, 777, 27, 70, "BeginEndQuestion",
 CellTags->"discontinuous derivative"],
Cell[43023, 1611, 1060, 44, 70, "BeginEndQuestion",
 CellTags->"exact solution"],
Cell[CellGroupData[{
Cell[44108, 1659, 556, 16, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 55},
 CellTags->{"discretizing equations", "inverse problem"}],
Cell[CellGroupData[{
Cell[44689, 1679, 1202, 37, 70, "NumberedEquation"],
Cell[45894, 1718, 632, 21, 70, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46563, 1744, 629, 22, 70, "NumberedEquation"],
Cell[47195, 1768, 353, 9, 70, "Warning",
 CellTags->{"equally spaced data points", "trapezoid approximation"}],
Cell[47551, 1779, 948, 34, 70, "Text",
 CellTags->{"Moore-Penrose inverse", "PseudoInverse"}]
}, Open  ]]
}, Open  ]],
Cell[48526, 1817, 1577, 58, 70, "BeginEndQuestion"],
Cell[50106, 1877, 411, 17, 70, "BeginEndQuestion"]
}, Closed]],
Cell[CellGroupData[{
Cell[50554, 1899, 111, 5, 48, "Section"],
Cell[50668, 1906, 231, 6, 70, "Text",
 CellTags->{"equation of state", "ideal gas"}],
Cell[CellGroupData[{
Cell[50924, 1916, 214, 7, 70, "NumberedEquation"],
Cell[51141, 1925, 324, 8, 70, "Text",
 CellTags->{"Boltzmann constant", "van der Waals equation"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[51502, 1938, 399, 14, 70, "NumberedEquation",
 CellTags->"van der Waals"],
Cell[51904, 1954, 807, 26, 70, "Text"],
Cell[52714, 1982, 1087, 43, 70, "Text"]
}, Open  ]],
Cell[53816, 2028, 867, 39, 70, "BeginEndQuestion"],
Cell[54686, 2069, 859, 37, 70, "BeginEndQuestion"],
Cell[55548, 2108, 918, 37, 70, "BeginEndQuestion"],
Cell[CellGroupData[{
Cell[56491, 2149, 828, 28, 70, "Text",
 CellGroupingRules->{"SectionGrouping", 45}],
Cell[CellGroupData[{
Cell[57344, 2181, 550, 20, 70, "NumberedEquation",
 CellTags->"equal area"],
Cell[57897, 2203, 1816, 64, 70, "Text",
 CellTags->{"two-phase line", "Maxwell construction"}]
}, Open  ]],
Cell[59728, 2270, 953, 33, 70, "NumberedEquation",
 CellTags->"two-phase"],
Cell[60684, 2305, 1060, 42, 70, "BeginEndQuestion"],
Cell[61747, 2349, 794, 30, 70, "BeginEndQuestion"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[62590, 2385, 172, 7, 48, "Section",
 Evaluatable->False],
Cell[62765, 2394, 132, 3, 27, "Text"],
Cell[CellGroupData[{
Cell[62922, 2401, 524, 17, 49, "NumberedEquation",
 CellTags->"wave equation"],
Cell[63449, 2420, 205, 6, 27, "Text",
 CellTags->{"boundary condition", "polar coordinates"}]
}, Open  ]],
Cell[CellGroupData[{
Cell[63691, 2431, 416, 14, 52, "NumberedEquation",
 CellTags->"Laplacian"],
Cell[64110, 2447, 606, 26, 55, "Text"],
Cell[64719, 2475, 656, 22, 65, "Input"]
}, Open  ]],
Cell[65390, 2500, 930, 37, 82, "BeginEndQuestion",
 CellTags->"separation of variables"],
Cell[66323, 2539, 1048, 37, 92, "BeginEndQuestion"],
Cell[67374, 2578, 750, 27, 93, "BeginEndQuestion"],
Cell[68127, 2607, 450, 19, 76, "BeginEndQuestion"],
Cell[68580, 2628, 1261, 45, 111, "BeginEndQuestion"],
Cell[69844, 2675, 632, 26, 74, "BeginEndQuestion"]
}, Open  ]],
Cell[CellGroupData[{
Cell[70513, 2706, 108, 5, 82, "Section"],
Cell[70624, 2713, 133, 6, 27, "Text",
 CellTags->"Pauli spin matrices"],
Cell[70760, 2721, 364, 12, 42, "Input"],
Cell[71127, 2735, 412, 13, 42, "Input"],
Cell[71542, 2750, 388, 13, 42, "Input"],
Cell[71933, 2765, 149, 6, 27, "Text"],
Cell[72085, 2773, 161, 4, 29, "Input"],
Cell[CellGroupData[{
Cell[72271, 2781, 93, 2, 27, "Input"],
Cell[72367, 2785, 285, 8, 43, "Output"]
}, Open  ]],
Cell[72667, 2796, 99, 2, 27, "Text"],
Cell[72769, 2800, 474, 22, 61, "BeginEndQuestion"],
Cell[73246, 2824, 1959, 74, 112, "BeginEndQuestion",
 CellTags->"Levi-Civita tensor"],
Cell[75208, 2900, 907, 37, 74, "BeginEndQuestion"],
Cell[CellGroupData[{
Cell[76140, 2941, 1835, 73, 58, "BeginQuestion"],
Cell[77978, 3016, 1834, 61, 49, "NumberedEquation"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79849, 3082, 352, 15, 45, "BeginQuestion",
 CellTags->"Dirac gamma matrices"],
Cell[80204, 3099, 1093, 31, 109, "NumberedEquation"],
Cell[81300, 3132, 1653, 60, 70, "EndQuestion"]
}, Open  ]],
Cell[82968, 3195, 857, 33, 70, "BeginEndQuestion"],
Cell[83828, 3230, 2628, 99, 70, "BeginEndQuestion"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

