(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     18504,        563]
NotebookOptionsPosition[     16082,        483]
NotebookOutlinePosition[     17091,        518]
CellTagsIndexPosition[     16985,        512]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Quiz Generator", "Title",
 CellMargins->{{0, Inherited}, {Inherited, Inherited}},
 CellFrameMargins->{{54, 0}, {12, 12}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[GridBox[{
     {
      RowBox[{"Harry", " ", "Calkins"}], 
      RowBox[{"Paul", " ", "Wellin"}]},
     {
      RowBox[{"Wolfram", " ", "Research"}], 
      RowBox[{"Wolfram", " ", "Research"}]},
     {
      RowBox[{
       RowBox[{"harryc", "@", "wolfram"}], ".", "com"}], 
      RowBox[{
       RowBox[{"wellin", "@", "wolfram"}], ".", "com"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[14.]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], TraditionalForm]]],
 "\n"
}], "Subsubtitle",
 FontSize->16],

Cell["\<\
This basic notebook walks through the steps in creating a set of problems \
suitable for a homework assignment or test. The type of problems can be \
modified to create problem sets for any discipline or course.\
\>", "Text"],

Cell["The steps include the following:", "Text"],

Cell["\<\
create two notebooks, one each for the problems and the answers\
\>", "BulletedList"],

Cell["generate problems in factoring and their solutions", "BulletedList"],

Cell["write problems and solutions to notebooks", "BulletedList"],

Cell[TextData[{
 "In this particular notebook we will create a problem set with ten \
trinomials to factor. If you are interested in seeing or modifying any of the \
underlying program code, go ",
 ButtonBox["here",
  BaseStyle->"Hyperlink",
  ButtonData:>"Initializations"],
 "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Create notebooks", "Section"],

Cell["Create the quiz and solution notebooks.", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Button", "[", 
  RowBox[{"\"\<Create notebook templates\>\"", ",", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"nb1", "=", 
      RowBox[{"CreateDocument", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"TextCell", "[", 
           RowBox[{
           "\"\<Name____________________________             Hour_______\>\"",
             ",", "\"\<Subsection\>\""}], "]"}], ",", 
          RowBox[{"TextCell", "[", 
           RowBox[{
           "\"\<Solutions to Factor Problems.\>\"", ",", 
            "\"\<Subsubsection\>\""}], "]"}]}], "}"}], ",", 
        RowBox[{"ShowCellLabel", "\[Rule]", " ", "False"}], ",", 
        RowBox[{
        "NotebookFileName", "\[Rule]", " ", "\"\<Quiz Solutions\>\""}]}], 
       "]"}]}], ";", "\n", 
     RowBox[{"SelectionMove", "[", 
      RowBox[{"nb1", ",", "After", ",", "Notebook"}], "]"}], ";", "\n", 
     RowBox[{"nb2", "=", 
      RowBox[{"CreateDocument", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"TextCell", "[", 
           RowBox[{
           "\"\<Name____________________________             Hour_______\>\"",
             ",", "\"\<Subsection\>\""}], "]"}], ",", 
          RowBox[{"TextCell", "[", 
           RowBox[{
           "\"\<Factor the following expressions.\>\"", ",", 
            "\"\<Subsubsection\>\""}], "]"}]}], "}"}], ",", 
        RowBox[{"ShowCellLabel", "\[Rule]", " ", "False"}], ",", 
        RowBox[{
        "NotebookFileName", "\[Rule]", " ", "\"\<Quiz Problems\>\""}]}], 
       "]"}]}], ";", "\n", 
     RowBox[{"SelectionMove", "[", 
      RowBox[{"nb2", ",", "After", ",", "Notebook"}], "]"}], ";"}], ")"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 ButtonBox["\<\"Create notebook templates\"\>",
  Appearance->Automatic,
  ButtonFrame->"DialogBox",
  ButtonFunction:>($CellContext`nb1 = CreateDocument[{
       TextCell[
       "Name____________________________             Hour_______", 
        "Subsection"], 
       TextCell["Solutions to Factor Problems.", "Subsubsection"]}, 
      ShowCellLabel -> False, NotebookFileName -> "Quiz Solutions"]; 
   SelectionMove[$CellContext`nb1, After, Notebook]; $CellContext`nb2 = 
    CreateDocument[{
       TextCell[
       "Name____________________________             Hour_______", 
        "Subsection"], 
       TextCell["Factor the following expressions.", "Subsubsection"]}, 
      ShowCellLabel -> False, NotebookFileName -> "Quiz Problems"]; 
   SelectionMove[$CellContext`nb2, After, Notebook]; Null),
  Evaluator->Automatic,
  Method->"Preemptive"]], "Picture"]
}, {2}]]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate problems and answers", "Section"],

Cell[TextData[{
 "This function is used to generate the source for ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " trinomials to factor. The first argument to the function is a list of \
values to use for the parameters and the second argument is the number of \
problems to generate. Evaluating ",
 StyleBox["MakeProblems", "MR"],
 " with no arguments will generate 6 problems which factor to (",
 StyleBox["x-a",
  FontSlant->"Italic"],
 ") (",
 StyleBox["x - b",
  FontSlant->"Italic"],
 ") where ",
 StyleBox["a",
  FontSlant->"Italic"],
 " and ",
 StyleBox["b",
  FontSlant->"Italic"],
 " are taken from  the list {-5, -4, -3, -2, -1, 1, 2, 3, 4, 5}."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MakeProblems", "[", 
   RowBox[{"params_List", ",", "vars_List", ",", "n_Integer"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "tempvar", "}"}], ",", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"tempvar", "=", 
         RowBox[{"RandomChoice", "[", 
          RowBox[{"vars", ",", "1"}], "]"}]}], ";", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"var", "-", 
            RowBox[{
             RowBox[{"RandomSample", "[", 
              RowBox[{"params", ",", "1"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"var", "-", " ", 
            RowBox[{
             RowBox[{"RandomSample", "[", 
              RowBox[{"params", ",", "1"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], ")"}]}], "/.", 
         RowBox[{"var", "\[RuleDelayed]", "tempvar"}]}]}], ",", 
       RowBox[{"{", "n", "}"}]}], "]"}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.382881293049057*^9, 3.382881301618705*^9}, {
   3.382881345697707*^9, 3.3828814412072287`*^9}, {3.38288157452843*^9, 
   3.382881619350528*^9}, {3.38288189027085*^9, 3.382881896659444*^9}, 
   3.383293129113566*^9}],

Cell["\<\
This creates the source for 8 problems with parameters chosen from {-9, -8, \
-7, -6, -5, -4, -3, -2, -1, 1, 2, 3, 4, 5, 
 6, 7, 8, 9}.\
\>", "MathCaption",
 CellChangeTimes->{{3.382896319560614*^9, 3.382896377062849*^9}}],

Cell[BoxData[
 RowBox[{"MakeProblems", "[", 
  RowBox[{
   RowBox[{"DeleteCases", "[", 
    RowBox[{
     RowBox[{"Range", "[", 
      RowBox[{
       RowBox[{"-", "9"}], ",", "9"}], "]"}], ",", "0"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "8"}], "]"}]], "Input",
 CellChangeTimes->{
  3.3828807808443937`*^9, {3.3828814545766478`*^9, 3.382881496218342*^9}, {
   3.382896434704235*^9, 3.3828964386371937`*^9}, {3.383293136633893*^9, 
   3.383293143846451*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Write problems and answers to notebooks", "Section"],

Cell["\<\
Evaluate the following cell to define the source for the problems.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"sols", "=", 
  RowBox[{"MakeProblems", "[", 
   RowBox[{
    RowBox[{"DeleteCases", "[", 
     RowBox[{
      RowBox[{"Range", "[", 
       RowBox[{
        RowBox[{"-", "9"}], ",", "9"}], "]"}], ",", "0"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "r", ",", "s"}], "}"}], ",", "8"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.383293155920326*^9, 3.383293162965126*^9}}],

Cell[TextData[{
 "\nPress the ",
 StyleBox["Make Problems", "SR"],
 " button below to generate the quiz and solutions."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Button", "[", 
  RowBox[{"\"\<Make Problems\>\"", ",", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Unevaluated", "[", "sols", "]"}], "=!=", "sols"}], ",", 
     RowBox[{
      RowBox[{"NotebookLocate", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"EvaluationNotebook", "[", "]"}], ",", "\"\<MakeProbs\>\""}],
         "}"}], "]"}], ";", 
      RowBox[{"FrontEndExecute", "[", 
       RowBox[{"{", 
        RowBox[{"FrontEndToken", "[", 
         RowBox[{
          RowBox[{"FrontEnd`EvaluationNotebook", "[", "]"}], ",", 
          "\"\<EvaluateCells\>\""}], "]"}], "}"}], "]"}]}], ",", 
     RowBox[{"CreateDocument", "[", 
      RowBox[{
       RowBox[{"Cell", "[", 
        RowBox[{
        "\"\<You must first define the source problems with \
MakeProblems.\>\"", ",", "\"\<Text\>\"", ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", "18", 
         ",", 
         RowBox[{"FontColor", "\[Rule]", " ", "Red"}]}], "]"}], ",", 
       RowBox[{"WindowSize", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"450", ",", "100"}], "}"}]}]}], "]"}]}], "]"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 ButtonBox["\<\"Make Problems\"\>",
  Appearance->Automatic,
  ButtonFrame->"DialogBox",
  ButtonFunction:>If[
   Unevaluated[$CellContext`sols] =!= $CellContext`sols, NotebookLocate[{
       EvaluationNotebook[], "MakeProbs"}]; FrontEndExecute[{
       FrontEndToken[
        FrontEnd`EvaluationNotebook[], "EvaluateCells"]}], 
    CreateDocument[
     Cell[
     "You must first define the source problems with MakeProblems.", "Text", 
      FontFamily -> "Helvetica", 18, FontColor -> Red], 
     WindowSize -> {450, 100}]],
  Evaluator->Automatic,
  Method->"Preemptive"]], "Output"]
}, {2}]],

Cell["\<\
You can now save the notebooks in the usual way. If you wish to give the \
notebooks different names use SaveAs from the file menu.\
\>", "Text",
 CellChangeTimes->{{3.382895946814027*^9, 3.382896037014525*^9}}],

Cell[TextData[{
 "Problems? Have you made the notebooks? If not, go back to the Create \
notebooks section above and click the ",
 StyleBox["Create notebooks template", "SR"],
 " button."
}], "MathCaption"]
}, Closed]],

Cell[CellGroupData[{

Cell["Initializations", "Section",
 FontColor->GrayLevel[0.666667],
 CellTags->"Initializations"],

Cell[TextData[{
 "The following cells are intended to fill the quiz and solution notebooks \
and should not be evaluated directly. They are used by the ",
 StyleBox["Make Problems", "SR"],
 " button for filling the notebook. Evaluating these cells out of order can \
lead to undesirable results."
}], "Text",
 CellTags->"Initializations"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Grid", "[", 
   RowBox[{
    RowBox[{"Partition", "[", 
     RowBox[{
      RowBox[{"MapIndexed", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"StringForm", "[", 
          RowBox[{"\"\<``)  ``\>\"", ",", 
           RowBox[{"#2", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{"TraditionalForm", "[", 
            RowBox[{"Expand", "[", "#1", "]"}], "]"}]}], "]"}], "&"}], ",", 
        "sols"}], "]"}], ",", "2"}], "]"}], ",", 
    RowBox[{"ItemStyle", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontSize", "\[Rule]", " ", "14"}], ",", 
       RowBox[{"FontFamily", "\[Rule]", " ", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSlant", "\[Rule]", " ", "\"\<Italic\>\""}]}], "}"}]}], 
    ",", 
    RowBox[{"Spacings", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"15", ",", "10"}], "}"}]}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SelectionMove", "[", 
   RowBox[{
    RowBox[{"EvaluationNotebook", "[", "]"}], ",", "Previous", ",", "Cell"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FrontEndExecute", "[", 
   RowBox[{"{", 
    RowBox[{"FrontEndToken", "[", 
     RowBox[{
      RowBox[{"FrontEnd`EvaluationNotebook", "[", "]"}], ",", 
      "\"\<Copy\>\""}], "]"}], "}"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FrontEndExecute", "[", 
   RowBox[{"{", 
    RowBox[{"FrontEndToken", "[", 
     RowBox[{
      RowBox[{"FrontEnd`EvaluationNotebook", "[", "]"}], ",", 
      "\"\<Clear\>\""}], "]"}], "}"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FrontEndExecute", "[", 
   RowBox[{"{", 
    RowBox[{"FrontEndToken", "[", 
     RowBox[{"nb2", ",", "\"\<Paste\>\""}], "]"}], "}"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SelectionMove", "[", 
   RowBox[{
    RowBox[{"EvaluationNotebook", "[", "]"}], ",", "Next", ",", "Cell"}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FrontEndExecute", "[", 
   RowBox[{"{", 
    RowBox[{"FrontEndToken", "[", 
     RowBox[{
      RowBox[{"FrontEnd`EvaluationNotebook", "[", "]"}], ",", 
      "\"\<EvaluateCells\>\""}], "]"}], "}"}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.382879892717881*^9, 3.382879925910349*^9}, {
   3.382879978683601*^9, 3.382879998744322*^9}, 3.3828800562830477`*^9, 
   3.382880494369796*^9, {3.3828808817615147`*^9, 3.382880908118393*^9}, {
   3.382881010949081*^9, 3.3828810288528023`*^9}, {3.382897329122202*^9, 
   3.382897360543453*^9}},
 CellTags->{"MakeProbs", "Initializations"}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Grid", "[", 
   RowBox[{
    RowBox[{"Partition", "[", 
     RowBox[{
      RowBox[{"MapIndexed", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"StringForm", "[", 
          RowBox[{"\"\<``)  ``\>\"", ",", 
           RowBox[{"#2", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{"TraditionalForm", "[", "#1", "]"}]}], "]"}], "&"}], ",", 
        "sols"}], "]"}], ",", "2"}], "]"}], ",", 
    RowBox[{"ItemStyle", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"FontSize", "\[Rule]", " ", "14"}], ",", 
       RowBox[{"FontFamily", "\[Rule]", " ", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSlant", "\[Rule]", " ", "\"\<Italic\>\""}]}], "}"}]}], 
    ",", 
    RowBox[{"Spacings", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"15", ",", "10"}], "}"}]}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SelectionMove", "[", 
   RowBox[{
    RowBox[{"EvaluationNotebook", "[", "]"}], ",", "Previous", ",", "Cell", 
    ",", "1"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FrontEndExecute", "[", 
   RowBox[{"{", 
    RowBox[{"FrontEndToken", "[", 
     RowBox[{
      RowBox[{"FrontEnd`EvaluationNotebook", "[", "]"}], ",", 
      "\"\<Copy\>\""}], "]"}], "}"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FrontEndExecute", "[", 
   RowBox[{"{", 
    RowBox[{"FrontEndToken", "[", 
     RowBox[{
      RowBox[{"FrontEnd`EvaluationNotebook", "[", "]"}], ",", 
      "\"\<Clear\>\""}], "]"}], "}"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FrontEndExecute", "[", 
   RowBox[{"{", 
    RowBox[{"FrontEndToken", "[", 
     RowBox[{"nb1", ",", "\"\<Paste\>\""}], "]"}], "}"}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.3828803191440496`*^9, 3.382880373493977*^9}, 
   3.3828805094711227`*^9, {3.382897414162738*^9, 3.382897436394994*^9}},
 CellTags->"Initializations"]
}, Closed]]
},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Brackets",
WindowSize->{809, 688},
WindowMargins->{{196, Automatic}, {Automatic, 10}},
ShowSelection->True,
FrontEndVersion->"6.0 for Microsoft Windows (32-bit) (April 9, 2007)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "WEGSeminar.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Initializations"->{
  Cell[11061, 343, 97, 2, 36, "Section",
   CellTags->"Initializations"],
  Cell[11161, 347, 338, 7, 61, "Text",
   CellTags->"Initializations"],
  Cell[11502, 356, 2606, 69, 222, "Input",
   CellTags->{"MakeProbs", "Initializations"}],
  Cell[14111, 427, 1955, 53, 162, "Input",
   CellTags->"Initializations"]},
 "MakeProbs"->{
  Cell[11502, 356, 2606, 69, 222, "Input",
   CellTags->{"MakeProbs", "Initializations"}]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Initializations", 16540, 497},
 {"MakeProbs", 16870, 506}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[590, 23, 127, 2, 58, "Title"],
Cell[720, 27, 852, 27, 77, "Subsubtitle"],
Cell[1575, 56, 235, 4, 42, "Text"],
Cell[1813, 62, 48, 0, 23, "Text"],
Cell[1864, 64, 95, 2, 23, "BulletedList"],
Cell[1962, 68, 74, 0, 23, "BulletedList"],
Cell[2039, 70, 65, 0, 23, "BulletedList"],
Cell[2107, 72, 292, 8, 42, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2436, 85, 35, 0, 62, "Section"],
Cell[2474, 87, 62, 0, 39, "MathCaption"],
Cell[CellGroupData[{
Cell[2561, 91, 1708, 43, 282, "Input"],
Cell[4272, 136, 883, 19, 23, "Picture"]
}, {2}]]
}, Closed]],
Cell[CellGroupData[{
Cell[5201, 161, 48, 0, 36, "Section"],
Cell[5252, 163, 676, 21, 80, "Text"],
Cell[5931, 186, 1368, 35, 142, "Input",
 InitializationCell->True],
Cell[7302, 223, 232, 5, 66, "MathCaption"],
Cell[7537, 230, 503, 13, 42, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[8077, 248, 58, 0, 36, "Section"],
Cell[8138, 250, 90, 2, 23, "Text"],
Cell[8231, 254, 420, 12, 42, "Input"],
Cell[8654, 268, 131, 4, 42, "Text"],
Cell[CellGroupData[{
Cell[8810, 276, 1168, 31, 122, "Input"],
Cell[9981, 309, 601, 15, 49, "Output"]
}, {2}]],
Cell[10594, 327, 221, 4, 42, "Text"],
Cell[10818, 333, 206, 5, 58, "MathCaption"]
}, Closed]],
Cell[CellGroupData[{
Cell[11061, 343, 97, 2, 36, "Section",
 CellTags->"Initializations"],
Cell[11161, 347, 338, 7, 61, "Text",
 CellTags->"Initializations"],
Cell[11502, 356, 2606, 69, 222, "Input",
 CellTags->{"MakeProbs", "Initializations"}],
Cell[14111, 427, 1955, 53, 162, "Input",
 CellTags->"Initializations"]
}, Closed]]
}
]
*)

(* End of internal cache information *)
